Option Strict Off
Option Explicit On 
Imports System.Runtime.InteropServices


Module Header
	'----------------------------------------------------------------
    ' (C)2005 Blue Chip Technology Ltd.  All Rights Reserved.
	'----------------------------------------------------------------
	'
    '  FileName  : bluechip.vb                                     $
	'
	'  Release   :
	'
    '  Contents  : Constants and function prototypes needed by VB.NET
	'              application programmers using the PCI WDM Drivers.
	'
    '  History   : V1.00
    '              Based on code generated by the Visual Studio.NET   
    '              2003 Visual Basic 6.0 conversion wizard on the 
    '              VB project file "bluechip.bas".
    '  $Revision::                                                 $
	'  $Author::                                                   $
	'  $Modtime::                                                  $
	'  $History::                                                  $
	'
	'----------------------------------------------------------------

	'----------------------------------------------------------------
	' Define some driver specific types.
	'----------------------------------------------------------------
	
	'----------------------------------------------------------------
	' OVERLAPPED structure.  This is not needed as such but it is
	' defined here in order to make the BCT_HANDLE type that follows
	' the correct size.
	'----------------------------------------------------------------
	
	Structure OVERLAPPED
		Dim Internal As Integer
		Dim InternalHigh As Integer
		Dim Offset As Integer
		Dim OffsetHigh As Integer
		Dim hEvent As Integer ' This is an NT handle in reality but all we
	End Structure ' need to do is allocate it 4 bytes.
	
	
	'----------------------------------------------------------------
	' BCT_HANDLE structure
	'----------------------------------------------------------------
	
	Public Structure BCT_HANDLE
		Dim Handle As Integer
		Dim Overlap As OVERLAPPED
		Dim DeviceType As Integer
		Dim BoardType As Integer
		Dim nPort As Short
		Dim LastError As Integer
		Dim NextTime As Integer
	End Structure
	
	
    '----------------------------------------------------------------
    ' BCT_BOARD_ID structure
    '----------------------------------------------------------------
    ' In VB.NET, we cannot declare a dimensioned array from within
    ' the structure.  Instead, we use the 'MarshalAs Attribute' class
    ' to handle each array data.
    '----------------------------------------------------------------

	<StructLayout(LayoutKind.Sequential)> _
	Public Structure BCT_BOARD_ID

        Dim Handle As Integer
        Dim SerialNo As Integer
        <MarshalAs(UnmanagedType.ByValArray, SizeConst:=30, ArraySubType:=UnmanagedType.AsAny)> _
        Dim DevName() As Byte
        <MarshalAs(UnmanagedType.ByValArray, SizeConst:=30, ArraySubType:=UnmanagedType.AsAny)> _
        Dim Clock0Name() As Byte
        <MarshalAs(UnmanagedType.ByValArray, SizeConst:=30, ArraySubType:=UnmanagedType.AsAny)> _
        Dim Clock1Name() As Byte
        <MarshalAs(UnmanagedType.ByValArray, SizeConst:=30, ArraySubType:=UnmanagedType.AsAny)> _
        Dim Clock2Name() As Byte
        Dim hClock0 As BCT_HANDLE
        Dim hClock1 As BCT_HANDLE
        Dim hClock2 As BCT_HANDLE
        Dim Index As Integer
        Dim DeviceType As Integer

    End Structure

    '----------------------------------------------------------------
    ' BCT_BUFFER structure.  In Visual Basic if we declare the buffer
    ' as an array with no size attached to it and then try to ReDim
    ' the buffer then the pointers that get passed to the DLL and
    ' hence to the driver are complete nonsense and the application
    ' will start to use erroneous data.
    ' In order to get around this problem we can declare the buffer
    ' with a predefined length as we have here with the buffer being
    ' set to 16KB in size.  If a larger buffer is required then the
    ' value in the declaration of the buffer field should be changed
    ' as appropriate.
    ' It is not a problem if the length of the buffer specified in the
    ' length field is smaller than the declared array size as the DLL
    ' will work of the value specified in the length field.
    ' In VB.NET, we cannot declare a dimensioned array from within
    ' the structure.  Instead, we use the 'MarshalAs Attribute' class
    ' to handle each array data.
    '----------------------------------------------------------------
    Public Structure BCT_BUFFER
        Dim Length As Integer
        Dim Sema As Integer
        <MarshalAs(UnmanagedType.ByValArray, SizeConst:=16384, ArraySubType:=UnmanagedType.AsAny)> _
        Dim Buffer() As Byte
    End Structure

    '----------------------------------------------------------------
    ' Watchdog timer board data structures
    '----------------------------------------------------------------

    Public Structure BCT_WDT_SETDATA
        Dim IN0_High_3_3V As Byte
        Dim IN0_Low_3_3V As Byte
        Dim IN1_High_5V As Byte
        Dim IN1_Low_5V As Byte
        Dim IN2_High_12V As Byte
        Dim IN2_Low_12V As Byte
        Dim IN3_High As Byte
        Dim IN3_Low As Byte
        Dim IN4_High As Byte
        Dim IN4_Low As Byte
        Dim IN5_High_Minus12V As Byte
        Dim IN5_Low_Minus12V As Byte
        Dim IN6_High As Byte
        Dim IN6_Low As Byte
        Dim OverTempHigh As Byte
        Dim TempHysteresisLow As Byte
        Dim Fan1Count As Byte
        Dim Fan2count As Byte
        Dim Fan3count As Byte
        Dim FanRpm As Byte
    End Structure


    Public Structure BCT_WDT_READDATA
        Dim IN0_3_3V As Byte
        Dim IN1_5V As Byte
        Dim IN2_12V As Byte
        Dim IN3 As Byte
        Dim IN4 As Byte
        Dim IN5_Minus12V As Byte
        Dim IN6 As Byte
        Dim Temperature As Byte
        Dim Fan1Count As Byte
        Dim Fan2count As Byte
        Dim Fan3count As Byte
        Dim ExternalInput As Byte
        Dim InterruptStatus1 As Byte
        Dim InterruptStatus2 As Byte
    End Structure


    '----------------------------------------------------------------
    ' Function Prototypes.
    '----------------------------------------------------------------

    Public Declare Function BCTGetBoardId Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID, ByVal nDevType As Short, ByVal nBoard As Short) As Integer
    Public Declare Function BCTReleaseBoardId Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID) As Integer
    Public Declare Function BCTFindSerialNo Lib "BCDLL32.DLL" (ByVal nSerial As Integer, ByRef pBoardType As Short, ByRef pBoard As Short) As Integer
    Public Declare Function BCTFindBoardNo Lib "BCDLL32.DLL" (ByVal nSerial As Integer, ByRef pBoardType As Short, ByRef pBoard As Short) As Integer
    Public Declare Function BCTEnumerateBoards Lib "BCDLL32.DLL" (ByVal nIndex As Short, ByRef pBoardType As Short, ByRef pBoard As Short, ByRef nSerial As Integer) As Integer
    Public Declare Function BCTOpen Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByRef pBoardID As BCT_BOARD_ID, ByVal nDevType As Short, ByVal nDev As Short, ByVal nPort As Short) As Integer
    Public Declare Function BCTClose Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE) As Integer
    Public Declare Function BCTInit8255Modes Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID, ByVal nDev As Short, ByVal nMode As Short, ByVal nPortA As Short, ByVal nPortB As Short, ByVal nPortC As Short) As Integer
    Public Declare Function BCTInitPCIDio Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID, ByVal nDev As Short) As Integer
    Public Declare Function BCTInitIsoDigModes Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID, ByVal nDev As Short, ByVal nMode As Short, ByVal nPortA As Short, ByVal nPortB As Short, ByVal nPortC As Short) As Integer
    Public Declare Function BCTInitAOutModes Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID, ByVal nDev As Short, ByVal nChan0 As Short, ByVal nChan1 As Short, ByVal nChan2 As Short, ByVal nChan3 As Short) As Integer
    Public Declare Function BCTReadPort Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByRef nVal As Byte) As Integer
    Public Declare Function BCTReadPort16 Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByRef nVal As Short) As Integer
    Public Declare Function BCTReadPortAin Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByVal nChan As Byte, ByVal nGain As Byte, ByVal nMode As Byte, ByRef nVal As Short) As Integer
    Public Declare Function BCTWritePort Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByVal nVal As Byte) As Integer
    Public Declare Function BCTWritePort16 Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByVal nVal As UInt16) As Integer
    Public Declare Function BCTWriteBit Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByVal nBit As Byte, ByVal nVal As Byte) As Integer
    Public Declare Function BCTProgramCounter Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByVal nSource As Byte) As Integer
    Public Declare Function BCTInitPacer Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID) As Integer
    Public Declare Function BCTStartPacer Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID, ByVal nInterval As Integer) As Integer
    Public Declare Function BCTStopPacer Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID) As Integer
    Public Declare Function BCTAddPacerFunction Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID, ByVal nOperation As Short, ByRef pVal As Integer) As Integer
    Public Declare Function BCTAddPacerBlockIo Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByRef pBoardID As BCT_BOARD_ID, ByVal nOperation As Short, ByRef pBuffer1 As BCT_BUFFER, ByRef pBuffer2 As BCT_BUFFER, ByVal nBytes As Integer, ByVal nCount As Integer) As Integer
    Public Declare Function BCTWait Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByVal delay As Integer) As Integer
    Public Declare Function BCTInitHandle Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE) As Integer
    Public Declare Function BCTAllocate Lib "BCDLL32.DLL" (ByRef pBctBuf As BCT_BUFFER, ByVal Length As Integer) As Integer
    Public Declare Function BCTRelease Lib "BCDLL32.DLL" (ByRef pBctBuf As BCT_BUFFER) As Integer
    Public Declare Function BCTAcquireAPacer Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID) As Integer
    Public Declare Function BCTReleaseAPacer Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID) As Integer
    Public Declare Function BCTReadBlockAin Lib "BCDLL32.DLL" (ByRef pBoardID As BCT_BOARD_ID, ByRef pHandle As BCT_HANDLE, ByVal nChan As Byte, ByVal nGain As Byte, ByVal nMode As Byte, ByRef pBuffer As BCT_BUFFER, ByVal nSamples As Integer, ByVal nTime As Short) As Integer
    Public Declare Function BCTAutoCalAin Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByVal nGain As Byte, ByRef MeanZero As Short, ByRef MeanFsd As Short) As Integer
    Public Declare Sub BCTErr2Txt Lib "BCDLL32.DLL" (ByVal nCode As Integer, ByVal lpanTxt As String)
    Public Declare Function BCTSetWdt Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByRef pData As BCT_WDT_SETDATA) As Integer
    Public Declare Function BCTReadWdt Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByRef pData As BCT_WDT_READDATA) As Integer
    Public Declare Function BCTWatchdog Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByVal nAction As Short, ByRef pData As Byte) As Integer
    Public Declare Function BCTGetLastError Lib "BCDLL32.DLL" (ByRef pHandle As BCT_HANDLE, ByRef pErrCode As Integer) As Integer
    Public Declare Function BCTInitPCIRelay Lib "BCDLL32.DLL" (ByRef pBoardId As BCT_BOARD_ID, ByVal nDev As Integer) As Integer

    '----------------------------------------------------------------
    ' Windows NT constant definition.
    '----------------------------------------------------------------

    Public Const INFINITE As Integer = &HFFFFFFFF ' Max wait period


    '----------------------------------------------------------------
    ' Constant definitions for board types, ports, etc.
    '----------------------------------------------------------------

    Public Const UNKNOWN_BOARD As Short = 0 ' Board not supported
    Public Const DIP_24 As Short = 1 ' 24 Digital Inputs
    Public Const DOP_24 As Short = 2 ' 24 Digital Outputs
    Public Const DIO_48 As Short = 3 ' 24 digital inputs + 24 digital outputs
    Public Const PIO_96 As Short = 4 ' 96 programmable digital I/O lines
    Public Const RB_8 As Short = 5 ' 8 relay outputs
    Public Const PIO_48DB As Short = 6 ' 48 programmable digital I/O lines
    Public Const PIO_144P As Short = 7 ' 44 programmable digital I/O lines
    Public Const DCM_16 As Short = 8 ' 8 dig in + 8 dig out + 3 counters
    Public Const AIP_24 As Short = 9 ' 24 analogue inputs
    Public Const AOP_8 As Short = 10 ' 8 analogue outputs
    Public Const AIP_8D As Short = 11 ' 8 analog inputs + clock interrupts
    Public Const AOP_12D As Short = 12 ' 12 analog outputs with DMA & interrupts
    Public Const ADC_42 As Short = 13 ' 16 anin + 2 anout + 24 dig + interrupts
    Public Const ADC_44D As Short = 14 ' 16 anin + 4 anout + 24 dig + DMA + ints
    Public Const WD_1 As Short = 15 ' watchdog monitor and timer
    Public Const DIO_32D As Short = 16 ' 16 dig in + 16 dig out + 1 counter
    Public Const PCI_PIO As Short = 17 ' 48 programmable digital I/O lines on PCI
    Public Const PCI_DIO As Short = 18 ' 32 isolated digital I/O on PCI
    Public Const PCI_ADC As Short = 19 ' 16 anin + 4 anout + 24dig on PCI
    Public Const PCI_WDT As Short = 20 ' watchdog monitor and timer on PCI
    Public Const PCI_RLY As Short = 21 ' Relay board on PCI

    Public Const BCT_8255 As Short = 0
    Public Const BCT_8254 As Short = 1
    Public Const BCT_ISODIG As Short = 2
    Public Const BCT_AIN As Short = 3
    Public Const BCT_AOUT As Short = 4
    Public Const BCT_WDT As Short = 5
    Public Const BCT_RLY As Short = 6

    Public Const MODE_0 As Short = 0
    Public Const MODE_1 As Short = 1
    Public Const MODE_2 As Short = 2
    Public Const MODE_20 As Short = 3
    Public Const MODE_21 As Short = 4

    Public Const INPUT8 As Short = 0
    Public Const OUTPUT8 As Short = 1
    Public Const BIDI As Short = 2
    Public Const NOCARE As Short = 3
    Public Const ININ As Short = 4
    Public Const OUTOUT As Short = 5
    Public Const INOUT As Short = 6
    Public Const OUTIN As Short = 7
    'Global Const INPUT16 = 8
    'Global Const OUTPUT16 = 9

    Public Const NO_HANDLER As Short = 0
    Public Const READ_PACER As Short = 1
    Public Const BLOCK_SINGLE_READ As Short = 2
    Public Const BLOCK_DOUBLE_BUFFER_READ As Short = 3
    Public Const BLOCK_SINGLE_WRITE As Short = 4
    Public Const BLOCK_DOUBLE_BUFFER_WRITE As Short = 5
    Public Const BLOCK_REPEATED_WRITE As Short = 6

    Public Const BCT_WD_WRITE_TIMEOUT As Short = 0
    Public Const BCT_WD_REFRESH_TIMEOUT As Short = 1
    Public Const BCT_WD_WRITE_ENABLE_MASK As Short = 2
    Public Const BCT_WD_WRITE_OUTPUT_MASK As Short = 3

    '----------------------------------------------------------------
    ' Common driver / DLL bit definitions.
    '----------------------------------------------------------------

    Public Const P8254_CNTR_CTRL_MASK As Short = &HC0S
    Public Const P8254_CNTR_DATA_MASK As Short = &H3S
    Public Const P8254_CNTR_SHIFT As Short = &H6S

    Public Const P8254_COUNTER0 As Short = &H0S
    Public Const P8254_COUNTER1 As Short = &H40S
    Public Const P8254_COUNTER2 As Short = &H80S
    Public Const P8254_READBACK As Short = &HC0S

    Public Const P8254_LATCH As Short = &H0S
    Public Const P8254_LSB As Short = &H10S
    Public Const P8254_MSB As Short = &H20S
    Public Const P8254_16BITS As Short = &H30S

    Public Const P8254_MODE0 As Short = &H0S
    Public Const P8254_MODE1 As Short = &H2S
    Public Const P8254_MODE2 As Short = &H4S
    Public Const P8254_MODE3 As Short = &H6S
    Public Const P8254_MODE4 As Short = &H8S
    Public Const P8254_MODE5 As Short = &HAS

    Public Const P8254_BINARY_COUNTER As Short = &H0S
    Public Const P8254_BCD_COUNTER As Short = &H1S


    '----------------------------------------------------------------
    ' Interrupt direction is Bit 0
    '----------------------------------------------------------------

    Public Const BCT_CLK_INTERRUPT_MASK As Short = &H1S
    Public Const BCT_CLK_INTERRUPT_LOW As Short = &H0S
    Public Const BCT_CLK_INTERRUPT_HIGH As Short = &H1S


    '----------------------------------------------------------------
    ' Source is bits 1 and 2
    '----------------------------------------------------------------

    Public Const BCT_CLK_SRC_MASK As Short = &H6S
    Public Const BCT_CLK_SRC_SHIFT As Short = &H1S
    Public Const BCT_CLK_SRC_ONBOARD As Short = &H0S
    'Global Const BCT_CLK_SRC_PORT1 = &H2
    Public Const BCT_EXTERN_COUNTER_INPUT1 As Short = &H2S
    Public Const BCT_CLK_SRC_CHAIN As Short = &H4S
    'Global Const BCT_CLK_SRC_PORT2 = &H6
    Public Const BCT_EXTERN_COUNTER_INPUT2 As Short = &H6S


    '----------------------------------------------------------------
    ' Enable is bits 3 and 4
    '----------------------------------------------------------------

    Public Const BCT_CLK_ENABLE_MASK As Short = &HCS
    Public Const BCT_CLK_ENABLE_SHIFT As Short = &H3S
    Public Const BCT_CLK_ENABLED As Short = &H0S
    Public Const BCT_CLK_ENABLE_PORT1 As Short = &H4S
    Public Const BCT_CLK_ENABLE_PORT2 As Short = &H8S
    Public Const BCT_CLK_ENABLE_PORT3 As Short = &HCS


    '----------------------------------------------------------------
    ' Clear masks for PCIPIO Clock Control Registers
    '----------------------------------------------------------------

    Public Const PCIPIO_CTRLA_MASK_CLK0 As Short = &H43S
    Public Const PCIPIO_CTRLB_MASK_CLK0 As Short = &H30S
    Public Const PCIPIO_CTRLA_MASK_CLK1 As Short = &HCS
    Public Const PCIPIO_CTRLB_MASK_CLK1 As Short = &H4CS
    Public Const PCIPIO_CTRLA_MASK_CLK2 As Short = &H30S
    Public Const PCIPIO_CTRLB_MASK_CLK2 As Short = &H83S


    '----------------------------------------------------------------
    ' Clear masks for PCIDIO Clock Control Registers
    '----------------------------------------------------------------

    Public Const PCIDIO_CTRLA_MASK_CLK0 As Short = &H43S
    Public Const PCIDIO_CTRLB_MASK_CLK0 As Short = &H1S
    Public Const PCIDIO_CTRLA_MASK_CLK1 As Short = &HCS
    Public Const PCIDIO_CTRLB_MASK_CLK1 As Short = &H42S
    Public Const PCIDIO_CTRLA_MASK_CLK2 As Short = &H30S
    Public Const PCIDIO_CTRLB_MASK_CLK2 As Short = &H84S


    '----------------------------------------------------------------
    ' Clear masks for PCIADC Clock Control Registers (only 1)
    '----------------------------------------------------------------

    Public Const PCIADC_CTRL_MASK_CLK0 As Short = &H0S
    Public Const PCIADC_CTRL_MASK_CLK1 As Short = &H3S
    Public Const PCIADC_CTRL_MASK_CLK2 As Short = &HCS


    '----------------------------------------------------------------
    ' ADC - AIN Control Codes
    '----------------------------------------------------------------

    Public Const PCIADC_AIN_CHANNEL_MASK As Short = &HF0S
    Public Const PCIADC_AIN_CHANNEL_SHIFT As Short = 4
    Public Const PCIADC_AIN_GAIN_MASK As Short = &HCS
    Public Const PCIADC_AIN_GAIN_SHIFT As Short = 2
    Public Const PCIADC_AIN_MODE_MASK As Short = &H3S
    Public Const PCIADC_AIN_MODE_SHIFT As Short = 0

    Public Const PCIADC_AIN_GAIN_1 As Short = &H0S
    Public Const PCIADC_AIN_GAIN_10 As Short = &H1S
    Public Const PCIADC_AIN_GAIN_100 As Short = &H2S
    Public Const PCIADC_AIN_GAIN_1000 As Short = &H3S

    Public Const PCIADC_IN_GAIN1_SETTLE As Short = 23 ' Microseconds
    Public Const PCIADC_IN_GAIN10_SETTLE As Short = 24 ' Microseconds
    Public Const PCIADC_IN_GAIN100_SETTLE As Short = 100 ' Microseconds
    Public Const PCIADC_IN_GAIN1000_SETTLE As Short = 1000 ' Microseconds

    Public Const PCIADC_AIN_MODE_SINGLE As Short = &H0S
    Public Const PCIADC_AIN_MODE_DIFFERENTIAL As Short = &H1S
    Public Const PCIADC_AIN_MODE_CALIB_ZERO As Short = &H2S
    Public Const PCIADC_AIN_MODE_CALIB_FSD As Short = &H3S
    Public Const PCIADC_AIN_MULTI_CHANNEL As Short = &H80S

    Public Const PCIADC_AIN_BUSY As Short = &H1S
    Public Const PCIADC_AIN_FIFO_EMPTY As Short = &H2S
    Public Const PCIADC_AIN_FIFO_HF As Short = &H4S
    Public Const PCIADC_AIN_FIFO_FULL As Short = &H8S
    Public Const PCIADC_AIN_HFIFO_SIZE As Short = 1024 ' bytes

    Public Const PCIADC_AIN_AUTOSEL As Short = &H1S
    Public Const PCIADC_AIN_LEVEL_TRIGGER As Short = &H2S
    Public Const PCIADC_AIN_CONVERT_NONE As Short = &H3S ' AND to clear
    Public Const PCIADC_AIN_CONVERT_SOFTWARE As Short = &H4S ' or TO SET
    Public Const PCIADC_AIN_CONVERT_PC0 As Short = &H8S ' or TO SET
    Public Const PCIADC_AIN_CONVERT_PC3 As Short = &HCS ' or TO SET
    Public Const PCIADC_AIN_CONVERT_COUNTER0 As Short = &H10S ' or TO SET
    Public Const PCIADC_AIN_CONVERT_COUNTER1 As Short = &H14S ' or TO SET
    Public Const PCIADC_AIN_CONVERT_COUNTER2 As Short = &H18S ' or TO SET
    'Global Const PCIADC_AIN_CONVERT_NOTUSED = &H1C       ' or TO SET


    '----------------------------------------------------------------
    ' DLL Error Codes
    '----------------------------------------------------------------

    Public Const BCT_OK As Short = 0
    Public Const BCTERR_BOARD_BUSY As Short = 1
    Public Const BCTERR_BOARD_NOT_REQUESTED As Short = 2
    Public Const BCTERR_BOARD_ALREADY_REQUESTED As Short = 3
    Public Const BCTERR_NO_GLOBAL_MEMORY As Short = 4
    Public Const BCTERR_TOO_MANY_BOARDS As Short = 5
    Public Const BCTERR_GAINS_NOT_SUPPORTED As Short = 6
    Public Const BCTERR_INVALID_GAIN_VALUE As Short = 7
    Public Const BCTERR_NO_ANALOG_CHANNELS As Short = 8
    Public Const BCTERR_CHANNEL_NOT_ANALOG As Short = 9

    Public Const BCTERR_INVALID_RANGE As Short = 10
    Public Const BCTERR_NO_ANALOG_INPUTS As Short = 11
    Public Const BCTERR_CHANNEL_NOT_ANALOG_INPUT As Short = 12
    Public Const BCTERR_NULL_POINTER As Short = 13
    Public Const BCTERR_NO_ANALOG_OUTPUTS As Short = 14
    Public Const BCTERR_CHAN_NOT_ANALOG_OUTPUT As Short = 15
    Public Const BCTERR_VALUE_OUT_OF_RANGE As Short = 16
    Public Const BCTERR_ILLEGAL_NUM_CHANS As Short = 17
    Public Const BCTERR_NO_IRQ_AVAILABLE As Short = 18
    Public Const BCTERR_ILLEGAL_CHANS_IN_ARRAY As Short = 19

    Public Const BCTERR_ILLEGAL_NUM_SCANS As Short = 20
    Public Const BCTERR_LOST_DATA_IN_ISR As Short = 21
    Public Const BCTERR_ILLEGAL_FREQ As Short = 22
    Public Const BCTERR_NO_PROG_DIGITAL As Short = 23
    Public Const BCTERR_INVALID_CHARS As Short = 24
    Public Const BCTERR_INVALID_NUM_CHARS As Short = 25
    Public Const BCTERR_PORT_NOT_BIDIRECTIONAL As Short = 26
    Public Const BCTERR_NOT_DIGITAL_INPUT As Short = 27
    Public Const BCTERR_ILLEGAL_PORT As Short = 28
    Public Const BCTERR_PORT_NOT_INPUT As Short = 29

    Public Const BCTERR_ILLEGAL_BIT As Short = 30
    Public Const BCTERR_NOT_DIGITAL_OUTPUT As Short = 31
    Public Const BCTERR_ILLEGAL_DIGOUT_VALUE As Short = 32
    Public Const BCTERR_PORT_NOT_OUTPUT As Short = 33
    Public Const BCTERR_NO_COUNTERS As Short = 34
    Public Const BCTERR_INVALID_COUNTER As Short = 35
    Public Const BCTERR_INVALID_REF_FREQ As Short = 36
    Public Const BCTERR_INVALID_OUTPUT_FREQ As Short = 37
    Public Const BCTERR_NOT_WATCHDOG As Short = 38
    Public Const BCTERR_UNRECOGNISED_BOARD As Short = 39

    Public Const BCTERR_INVALID_BASEADDR As Short = 40
    Public Const BCTERR_INVALID_IRQ As Short = 41
    Public Const BCTERR_INVALID_DMACHAN As Short = 42
    Public Const BCTERR_NO_DATA As Short = 43
    Public Const BCTERR_STILL_ACQUIRING As Short = 44
    Public Const BCTERR_NO_DMA_AVAILABLE As Short = 45
    Public Const BCTERR_DMA_IN_USE As Short = 46
    Public Const BCTERR_BUFFER_TOO_SMALL As Short = 47
    Public Const BCTERR_INVALID_MODE_VALUE As Short = 48
    Public Const BCTERR_HARDWARE_MISSING As Short = 49

    Public Const BCTERR_UNSUPPORTED_OS As Short = 50
    Public Const BCTERR_GETSERIALNO_FAILED As Short = 51
    Public Const BCTERR_FAILED_RELEASEBOARDID As Short = 52
    Public Const BCTERR_INVALID_SERIALNO As Short = 53
    Public Const BCTERR_UNRECOGNISED_DEVICECODE As Short = 54
    Public Const BCTERR_UNRECOGNISED_PORTCODE As Short = 55
    Public Const BCTERR_UNRECOGNISED_DEVICE As Short = 56
    Public Const BCTERR_FAILEDCLOSE As Short = 57
    Public Const BCTERR_READPORT_FAILED As Short = 58
    Public Const BCTERR_WRITEPORT_FAILED As Short = 59

    Public Const BCTERR_INIT8255MODES_FAILED As Short = 60
    Public Const BCTERR_NTDRIVER_DEVICESOUTOFORDER As Short = 61
    Public Const BCTERR_DEVICECODENOTFOUND As Short = 62
    Public Const BCTERR_DEVICEOPEN As Short = 63
    Public Const BCTERR_INVALID8255MODE As Short = 64
    Public Const BCTERR_INVALIDIODIR As Short = 65
    Public Const BCTERR_INVALID_BITNO As Short = 66
    Public Const BCTERR_INVALID_BITSET As Short = 67
    Public Const BCTERR_WRITEBIT_FAILED As Short = 68
    Public Const BCTERR_INVALID_PACERCLOCK As Short = 69

    Public Const BCTERR_NOPACERCLOCK As Short = 70
    Public Const BCTERR_PACERCLOCKINUSE As Short = 71
    Public Const BCTERR_INITPACER_FAILED As Short = 72
    Public Const BCTERR_STOPPACER_FAILED As Short = 73
    Public Const BCTERR_ENABLEINTERUPT_FAILED As Short = 74
    Public Const BCTERR_INITCLOCK_FAILED As Short = 75
    Public Const BCTERR_UNEXPECTED_CLOCKNO As Short = 76
    Public Const BCTERR_UNSUPPORTED_BOARD As Short = 77
    Public Const BCTERR_ADDPACER_FAILED As Short = 78
    Public Const BCTERR_PACER_CLOCK_HANDLES_INUSE As Short = 79

    Public Const BCTERR_PACER_NOT_INITIALISED As Short = 80
    Public Const BCTERR_INVALID_INTERRUPT_INDEX As Short = 81
    Public Const BCTERR_FAILED_ENABLE_INTERRUPT As Short = 82
    Public Const BCTERR_FAILED_ADD_ACTION As Short = 83
    Public Const BCTERR_DISABLEINTERUPT_FAILED As Short = 84
    Public Const BCTERR_CANCELLED As Short = 85
    Public Const BCTERR_FAILED_PROGRAM_CNTRLCTRL As Short = 86
    Public Const BCTERR_INVALID_BYTECOUNT As Short = 87
    Public Const BCTERR_FAILED_MAP_BUFFER As Short = 88
    Public Const BCTERR_FAILED_LOCK_BUFFER As Short = 89

    Public Const BCTERR_FAILED_MAP_BUFFER_SYS As Short = 90
    Public Const BCTERR_INTERNAL_DRIVER_ERROR As Short = 91
    Public Const BCTERR_FAILED_CREATE_OVERLAP_EVENT As Short = 92
    Public Const BCTERR_FAILED_RESET_OVERLAP As Short = 93
    Public Const BCT_IO_PENDING As Short = 94
    Public Const BCTERR_WAIT_FAILED As Short = 95
    Public Const BCTERR_ALLOCATE_FAILED As Short = 96
    Public Const BCTERR_RELEASE_FAILED As Short = 97
    Public Const BCTERR_INVALID_IO_DIRECTION As Short = 98
    Public Const BCTERR_INIT_ISODIG_MODES_FAILED As Short = 99

    Public Const BCT_NOTIMPLEMENTED As Short = 100
    Public Const BCTERR_INVALID_DEVICE_NUMBER As Short = 101
    Public Const BCTERR_HANDLER_ABORTED As Short = 102
    Public Const BCTERR_FAILED_CLEAR_HANDLER As Short = 103
    Public Const BCTERR_UNSUPPORTED_8255_MODE As Short = 104
    Public Const BCTERR_UNSUPPORTED_A_DIRECTION As Short = 105
    Public Const BCTERR_UNSUPPORTED_B_DIRECTION As Short = 106
    Public Const BCTERR_UNSUPPORTED_C_DIRECTION As Short = 107
    Public Const BCTERR_UNSUPPORTED_ISODIG_MODE As Short = 108
    Public Const BCTERR_BLOCKIO_NOT_SUPPORTED As Short = 109

    Public Const BCTERR_ILLEGAL_COMBINATION As Short = 110
    Public Const BCTERR_MISSING_OPTION As Short = 111
    Public Const BCTERR_INITAOUTMODES_FAILED As Short = 112
    Public Const BCTERR_INVALID_CHANNEL_NUMBER As Short = 113
    Public Const BCTERR_INPUT_CONVERSION_TIMEOUT As Short = 114
    Public Const BCTERR_FIFO_ERROR As Short = 115
    Public Const BCTERR_AUTOSEL_NOT_SUPPORTED As Short = 116
    Public Const BCTERR_INVALID_SAMPLE_FREQ As Short = 117
    Public Const BCTERR_READBLOCK_FAILED As Short = 118
    Public Const BCTERR_PACER_CLOCK_HANDLE_INUSE As Short = 119

    Public Const BCTERR_FIFO_OVERFLOW As Short = 120
    Public Const BCTERR_AUTOCAL_NOT_SUPPORTED As Short = 121
    Public Const BCTERR_AUTOCAL_FAILED As Short = 122
    Public Const BCTERR_INVALID_COUNTER_VALUE As Short = 123
    Public Const BCTERR_INVALID_COUNTER_INPUT As Short = 124
    Public Const BCTERR_SETWDT_FAILED As Short = 125
    Public Const BCTERR_READWDT_FAILED As Short = 126
    Public Const BCTERR_WDTACCESS_TOOSOON As Short = 127
    Public Const BCTERR_ACCESS_WDT_FAILED As Short = 128
    Public Const BCTERR_INVALID_WDT_OPERATION As Short = 129

    Public Const BCTWARN_OUTPUT_VALUES_CLIPPED As Short = 200

    Public Const BCT_RUNNING As Short = 300
    Public Const BCT_FINISHED As Short = 301
    Public Const BCT_IDLE As Short = 302
    Public Const BCT_OVERRUN As Short = 303

    Public Const BCTERR_PCI_BIOS_NOT_PRESENT As Short = 401
    Public Const BCTERR_PCI_BOARD_NOT_FOUND As Short = 402
    Public Const BCTERR_PCI_ISR_NOT_AVAIL As Short = 403
    Public Const BCTERR_PCI_ISR_FUNCTION_ACTIVE As Short = 404
    Public Const BCTERR_PCI_INVALID_CLKSRC As Short = 405
    Public Const BCTERR_PCI_INVALID_CLKTYPE As Short = 406


    '----------------------------------------------------------------
    ' Interrupt handler definitions
    '----------------------------------------------------------------

    Public Const MAX_INTERRUPTS As Short = 8
    Public Const MAX_INTERRUPT_ACTIONS As Short = 5

    Public Const PCIPIO_MAX_INTERRUPTS As Short = 7
    Public Const PCIPIO_INTERRUPT_MASK As Short = &H7FS
    Public Const PCIPIO_INT_AC0 As Short = 0
    Public Const PCIPIO_INT_AC3 As Short = 1
    Public Const PCIPIO_INT_BC0 As Short = 2
    Public Const PCIPIO_INT_BC3 As Short = 3
    Public Const PCIPIO_INT_TIMER0 As Short = 4
    Public Const PCIPIO_INT_TIMER1 As Short = 5
    Public Const PCIPIO_INT_TIMER2 As Short = 6

    Public Const PCIDIO_MAX_INTERRUPTS As Short = 5
    Public Const PCIDIO_INTERRUPT_MASK As Short = &H1FS
    Public Const PCIDIO_INT_ISOLOW As Short = 0
    Public Const PCIDIO_INT_ISOHIGH As Short = 1
    Public Const PCIDIO_INT_TIMER0 As Short = 2
    Public Const PCIDIO_INT_TIMER1 As Short = 3
    Public Const PCIDIO_INT_TIMER2 As Short = 4

    Public Const PCIRLY_MAX_INTERRUPTS As Short = 5
    Public Const PCIRLY_INTERRUPT_MASK As Short = &H1FS
    Public Const PCIRLY_INT_ISOLOW As Short = 0
    Public Const PCIRLY_INT_ISOHIGH As Short = 1
    Public Const PCIRLY_INT_TIMER0 As Short = 2
    Public Const PCIRLY_INT_TIMER1 As Short = 3
    Public Const PCIRLY_INT_TIMER2 As Short = 4

    Public Const PCIADC_MAX_INTERRUPTS As Short = 8
    Public Const PCIADC_INTERRUPT_MASK As Short = &HFFS
    Public Const PCIADC_INT_PC0 As Short = 0
    Public Const PCIADC_INT_PC3 As Short = 1
    Public Const PCIADC_INT_TIMER0 As Short = 2
    Public Const PCIADC_INT_TIMER1 As Short = 3
    Public Const PCIADC_INT_TIMER2 As Short = 4
    Public Const PCIADC_INT_ADC_NOT_BUSY As Short = 5
    Public Const PCIADC_INT_FIFO_NOT_EMPTY As Short = 6
    Public Const PCIADC_INT_FIFO_HALF_FULL As Short = 7

    Public Const PCIWDT_MAX_INTERRUPTS As Short = 3
    Public Const PCIWDT_INTERRUPT_MASK As Short = &HFS
    Public Const PCIWDT_ENA_WATCHDOG As Short = 0
    Public Const PCIWDT_INT_EXTERNAL As Short = 1
    Public Const PCIWDT_LM78 As Short = 2
    Public Const PCIWDT_WATCHDOG As Short = 3


    '----------------------------------------------------------------
    ' We get to an individual port on a device using the following
    ' naming conventions:
    '
    '  Board   The Physical Board itself - this has both a BoardType
    '          and a BoardNo
    '
    '  Device  A particular Logical component - e.g. an 8255 chip or
    '          the Analog Output Channels
    '          DeviceType
    '          DeviceNo (there may be more than one on the board)
    '
    '  Port    The lowest level unit - in general a Driver Device
    '          corresponds to one of these where they are separately
    '          addressable
    '----------------------------------------------------------------

    '----------------------------------------------------------------
    ' Supported Board Type Codes
    '----------------------------------------------------------------

    '----------------------------------------------------------------
    ' PCI Data acquisition board componants.
    '----------------------------------------------------------------

    Public Const BCT_PORT_A As Short = 0
    Public Const BCT_PORT_B As Short = 1
    Public Const BCT_PORT_C As Short = 2
    Public Const BCT_PORT_ISO As Short = 2
    Public Const BCT_CLK_0 As Short = 0
    Public Const BCT_CLK_1 As Short = 1
    Public Const BCT_CLK_2 As Short = 2
    Public Const ISO_DIG_LOW8 As Short = 0
    Public Const ISO_DIG_HIGH8 As Short = 1
    Public Const ISO_DIG_ALL16 As Short = 2
    Public Const BCT_CHAN_0 As Short = 0
    Public Const BCT_CHAN_1 As Short = 1
    Public Const BCT_CHAN_2 As Short = 2
    Public Const BCT_CHAN_3 As Short = 3
    Public Const BCT_RLY_RLY_OUT As Short = 0
    Public Const BCT_RLY_OPTO_IN As Short = 2

    '----------------------------------------------------------------
    ' Analogue output modes
    '----------------------------------------------------------------

    Public Const BCT_AOUT_VOLTAGE As Short = &H1S
    Public Const BCT_AOUT_CURRENT As Short = &H2S


    '----------------------------------------------------------------
    ' Indecies and constants for Pacers.
    '----------------------------------------------------------------

    Public Const PACER_STATUS As Short = 0 ' We return the status here as well
    Public Const PACER_OP As Short = 0 ' What sort of Pacer To Add
    Public Const PACER_SKIP_INTERRUPTS As Short = 1 ' How many Pacer interrupts to skip between ops
    Public Const PACER_CLOCK_ID As Short = 2 ' Which Board has the Pacer Clock
    Public Const PACER_BUFFER_1 As Short = 3 ' Win32 Ptrs to Buffers,
    Public Const PACER_BUFFER_2 As Short = 4 ' WARNING, assumes a pointer is 32 bits long!
    Public Const PACER_BUFFER_COUNT As Short = 5 ' Number of bytes in a buffer


    '----------------------------------------------------------------
    '  Both DLL and Driver remember what sort of Board we are
    '----------------------------------------------------------------

    Public Const DEVICE_TYPE_PCIPIO As Short = 41
    Public Const DEVICE_TYPE_PCIDIO As Short = 42
    Public Const DEVICE_TYPE_PCIADC As Short = 43
    Public Const DEVICE_TYPE_PCIWDT As Short = 44
    Public Const DEVICE_TYPE_PCIRLY As Short = 45

    Public Const DEVICE_TYPE_8254 As Short = 51
    Public Const DEVICE_TYPE_8255 As Short = 52
    Public Const DEVICE_TYPE_ISODIG As Short = 53
    Public Const DEVICE_TYPE_AIN As Short = 54
    Public Const DEVICE_TYPE_AOUT As Short = 55
    Public Const DEVICE_TYPE_WDT As Short = 56
    Public Const DEVICE_TYPE_RLY As Short = 57

    '----------------------------------------------------------------
    ' End of listing.
    '----------------------------------------------------------------
End Module
