VERSION 5.00
Begin VB.Form AdcInOutMain 
   Caption         =   "PCI-ADC IO Test"
   ClientHeight    =   3570
   ClientLeft      =   60
   ClientTop       =   345
   ClientWidth     =   4800
   LinkTopic       =   "Form1"
   ScaleHeight     =   3570
   ScaleWidth      =   4800
   StartUpPosition =   3  'Windows Default
   Begin VB.TextBox Status 
      Height          =   1575
      Left            =   120
      MultiLine       =   -1  'True
      ScrollBars      =   2  'Vertical
      TabIndex        =   6
      Top             =   1920
      Width           =   4575
   End
   Begin VB.CommandButton ReadPort 
      Caption         =   "Read from port B"
      Height          =   615
      Left            =   2520
      TabIndex        =   5
      Top             =   1200
      Width           =   2175
   End
   Begin VB.CommandButton WritePort 
      Caption         =   "Write to port B"
      Height          =   615
      Left            =   120
      TabIndex        =   4
      Top             =   1200
      Width           =   2175
   End
   Begin VB.TextBox InVal 
      Height          =   375
      Left            =   1680
      TabIndex        =   3
      Top             =   600
      Width           =   3015
   End
   Begin VB.TextBox OutVal 
      Height          =   375
      Left            =   1680
      TabIndex        =   1
      Text            =   "00"
      Top             =   120
      Width           =   3015
   End
   Begin VB.Label Label2 
      Caption         =   "Value read"
      Height          =   375
      Left            =   120
      TabIndex        =   2
      Top             =   600
      Width           =   975
   End
   Begin VB.Label Label1 
      Caption         =   "Value to write (hex)"
      Height          =   255
      Left            =   120
      TabIndex        =   0
      Top             =   120
      Width           =   1455
   End
End
Attribute VB_Name = "AdcInOutMain"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
' --------------------------------------------------------------
' Declare the variables needed for accessing the PCI-ADC and for
' handling the error codes that are returned.
' --------------------------------------------------------------
Dim nStatus As Long
Dim szErrorText As String
Dim nPciAdcPortBHandle As BCT_HANDLE
Dim pPciAdcBoardId As BCT_BOARD_ID

'---------------------------------------------------------------
' OutputMessage - Adds a message to the status box
'
' Input  : szErr - Error message to add to text box called Status
' Return : None
'---------------------------------------------------------------
Private Sub OutputMessage(szErr As String)
    Status.Text = szErr + Chr$(13) + Chr$(10) + Status.Text
End Sub

' --------------------------------------------------------------
' Form_Load - Initialise the handles and the board ID structures
' --------------------------------------------------------------

Private Sub Form_Load()
    ' Re-initialise the space for the error handler
    szErrorText = Space(120)

    '---------------------------------------------------------------
    ' Start by initialising the four handles that we require
    '---------------------------------------------------------------
    OutputMessage ("Initialising handles for use by the IO tests")
    nStatus = BCTInitHandle(nPciAdcPortBHandle)
    If nStatus <> BCT_OK Then
        Call BCTErr2Txt(nStatus, szErrorText)
        OutputMessage ("BCTInitHandle returned: " + szErrorText)
    End If
    
    '---------------------------------------------------------------
    ' Next get the driver to fill in the board ID structure for the
    ' PCI-ADC
    '---------------------------------------------------------------
    OutputMessage ("Setting up the board ID structure")
    nStatus = BCTGetBoardId(pPciAdcBoardId, PCI_ADC, 0)
    If nStatus <> BCT_OK Then
        Call BCTErr2Txt(nStatus, szErrorText)
        OutputMessage ("BCTGetBoardId returned: " + szErrorText)
    End If
    
    '---------------------------------------------------------------
    ' Set port A nd C to be input and port B to be output
    '---------------------------------------------------------------
    OutputMessage ("Setting the PCI-ADC 8255 port directions")
    nStatus = BCTInit8255Modes(pPciAdcBoardId, 0, MODE_0, INPUT8, OUTPUT8, ININ)
    If nStatus <> BCT_OK Then
        Call BCTErr2Txt(nStatus, szErrorText)
        OutputMessage ("BCTInit8255Modes returned: " + szErrorText)
    End If
    
    '---------------------------------------------------------------
    ' Open the handle for the IO
    '---------------------------------------------------------------
    OutputMessage ("Opening the handles")
    nStatus = BCTOpen(nPciAdcPortBHandle, pPciAdcBoardId, BCT_8255, 0, BCT_PORT_B)
    If nStatus <> BCT_OK Then
        Call BCTErr2Txt(nStatus, szErrorText)
        OutputMessage ("BCTOpen returned: " + szErrorText)
    End If
End Sub
'---------------------------------------------------------------
' Form_Unload - Close the handle and release the board id
'               structure.
'---------------------------------------------------------------
Private Sub Form_Unload(Cancel As Integer)

    '---------------------------------------------------------------
    ' Make sure that the handles are closed
    '---------------------------------------------------------------
    nStatus = BCTClose(nPciAdcPortBHandle)

    '---------------------------------------------------------------
    ' Release the board ID
    '---------------------------------------------------------------
    nStatus = BCTReleaseBoardId(pPciAdcBoardId)
End Sub

' --------------------------------------------------------------
' ReadPort_Click - Read the value from port B
' --------------------------------------------------------------
Private Sub ReadPort_Click()
    ' Re-initialise the space for the error handler
    szErrorText = Space(120)
    
    '---------------------------------------------------------------
    ' As with all IO operations that the driver executes there is
    ' the possibility that there is already an operation within the
    ' system that hasn't been completed.  In order to handle this
    ' the driver will return BCT_IO_PENDING.  If it does then we can
    ' either specify that it waits a fixed period of time to see if
    ' it can complete the operation or we can make it wait until
    ' the operation has completed by specifying the appropriate time
    ' to BCTWait
    '---------------------------------------------------------------
    OutputMessage ("Reading back 8255 port B")
    nStatus = BCTReadPort(nPciAdcPortBHandle, nVal)
    If nStatus = BCT_IO_PENDING Then
        OutputMessage ("BCTReadPort returned BCT_IO_PENDING")
        nStatus = BCTWait(nPciAdcPortBHandle, INFINITE)
    End If
    If (nStatus <> BCT_OK) And (nStatus <> BCT_IO_PENDING) Then
        Call BCTErr2Txt(nStatus, szErrorText)
        OutputMessage ("BCTReadPort returned: " + szErrorText)
        InVal.Text = "Error"
    Else
        InVal.Text = "&H" + Hex(nVal)
    End If
End Sub

' --------------------------------------------------------------
' WritePort_Click - Send a value to port B within the 8255.
' --------------------------------------------------------------
Private Sub WritePort_Click()
    ' Re-initialise the space for the error handler
    szErrorText = Space(120)
    
    '---------------------------------------------------------------
    ' As with all IO operations that the driver executes there is
    ' the possibility that there is already an operation within the
    ' system that hasn't been completed.  In order to handle this
    ' the driver will return BCT_IO_PENDING.  If it does then we can
    ' either specify that it waits a fixed period of time to see if
    ' it can complete the operation or we can make it wait until
    ' the operation has completed by specifying the appropriate time
    ' to BCTWait
    '---------------------------------------------------------------
    OutputMessage ("Writing to 8255 port B")
    nStatus = BCTWritePort(nPciAdcPortBHandle, Val("&H" + OutVal.Text))
    If nStatus = BCT_IO_PENDING Then
        OutputMessage ("BCTWritePort returned BCT_IO_PENDING")
        nStatus = BCTWait(nPciAdcPortBHandle, INFINITE)
    End If
    If (nStatus <> BCT_OK) And (nStatus <> BCT_IO_PENDING) Then
        Call BCTErr2Txt(nStatus, szErrorText)
        OutputMessage ("BCTWritePort returned: " + szErrorText)
    End If
End Sub
