Attribute VB_Name = "Header"
'----------------------------------------------------------------
' (C)2000 Blue Chip Technology Ltd.  All Rights Reserved.
'----------------------------------------------------------------
'
'  FileName  : $Workfile::                                     $
'
'  Release   :
'
'  Contents  : Constants and function prototypes needed by VB
'              application programmers using the PCI WDM Drivers.
'
'  History   :
'  $Revision::                                                 $
'  $Author::                                                   $
'  $Modtime::                                                  $
'  $History::                                                  $
'
'----------------------------------------------------------------

'----------------------------------------------------------------
' Define some driver specific types.
'----------------------------------------------------------------

'----------------------------------------------------------------
' OVERLAPPED structure.  This is not needed as such but it is
' defined here in order to make the BCT_HANDLE type that follows
' the correct size.
'----------------------------------------------------------------

Type OVERLAPPED
    Internal As Long
    InternalHigh As Long
    Offset As Long
    OffsetHigh As Long
    hEvent As Long   ' This is an NT handle in reality but all we
End Type             ' need to do is allocate it 4 bytes.


'----------------------------------------------------------------
' BCT_HANDLE structure
'----------------------------------------------------------------

Public Type BCT_HANDLE
    Handle As Long
    Overlap As OVERLAPPED
    DeviceType As Long
    BoardType As Long
    nPort As Integer
    LastError As Long
    NextTime As Long
End Type


'----------------------------------------------------------------
' BCT_BOARD_ID structure
'----------------------------------------------------------------

Public Type BCT_BOARD_ID
    Handle As Long
    SerialNo As Long
    DevName(29) As Byte
    Clock0Name(29) As Byte
    Clock1Name(29) As Byte
    Clock2Name(29) As Byte
    hClock0 As BCT_HANDLE
    hClock1 As BCT_HANDLE
    hClock2 As BCT_HANDLE
    Index As Long
    DeviceType As Long
End Type


'----------------------------------------------------------------
' BCT_BUFFER structure.  In Visual Basic if we declare the buffer
' as an array with no size attached to it and then try to ReDim
' the buffer then the pointers that get passed to the DLL and
' hence to the driver are complete nonsense and the application
' will start to use erroneous data.
' In order to get around this problem we can declare the buffer
' with a predefined length as we have here with the buffer being
' set to 16KB in size.  If a larger buffer is required then the
' value in the declaration of the buffer field should be changed
' as appropriate.
' It is not a problem if the length of the buffer specified in the
' length field is smaller than the declared array size as the DLL
' will work of the value specified in the length field.
'----------------------------------------------------------------
 
Public Type BCT_BUFFER
    Length As Long
    Sema As Long
    Buffer(16384) As Byte
End Type
                             

'----------------------------------------------------------------
' Watchdog timer board data structures
'----------------------------------------------------------------

Public Type BCT_WDT_SETDATA
    IN0_High_3_3V As Byte
    IN0_Low_3_3V As Byte
    IN1_High_5V As Byte
    IN1_Low_5V As Byte
    IN2_High_12V As Byte
    IN2_Low_12V As Byte
    IN3_High As Byte
    IN3_Low As Byte
    IN4_High As Byte
    IN4_Low As Byte
    IN5_High_Minus12V As Byte
    IN5_Low_Minus12V As Byte
    IN6_High As Byte
    IN6_Low As Byte
    OverTempHigh As Byte
    TempHysteresisLow As Byte
    Fan1Count As Byte
    Fan2count As Byte
    Fan3count As Byte
    FanRpm As Byte
End Type


Public Type BCT_WDT_READDATA
    IN0_3_3V As Byte
    IN1_5V As Byte
    IN2_12V As Byte
    IN3 As Byte
    IN4 As Byte
    IN5_Minus12V As Byte
    IN6 As Byte
    Temperature As Byte
    Fan1Count As Byte
    Fan2count As Byte
    Fan3count As Byte
    ExternalInput As Byte
    InterruptStatus1 As Byte
    InterruptStatus2 As Byte
End Type
    
    
'----------------------------------------------------------------
' Function Prototypes.
'----------------------------------------------------------------

Declare Function BCTGetBoardId Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID, ByVal nDevType As Integer, ByVal nBoard As Integer) As Long
Declare Function BCTReleaseBoardId Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID) As Long
Declare Function BCTFindSerialNo Lib "BCDLL32.DLL" (ByVal nSerial As Long, pBoardType As Integer, pBoard As Integer) As Long
Declare Function BCTFindBoardNo Lib "BCDLL32.DLL" (ByVal nSerial As Long, pBoardType As Integer, pBoard As Integer) As Long
Declare Function BCTEnumerateBoards Lib "BCDLL32.DLL" (ByVal nIndex As Integer, pBoardType As Integer, pBoard As Integer, nSerial As Long) As Long
Declare Function BCTOpen Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, pBoardID As BCT_BOARD_ID, ByVal nDevType As Integer, ByVal nDev As Integer, ByVal nPort As Integer) As Long
Declare Function BCTClose Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE) As Long
Declare Function BCTInit8255Modes Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID, ByVal nDev As Integer, ByVal nMode As Integer, ByVal nPortA As Integer, ByVal nPortB As Integer, ByVal nPortC As Integer) As Long
Declare Function BCTInitPCIDio Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID, ByVal nDev As Integer) As Long
Declare Function BCTInitIsoDigModes Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID, ByVal nDev As Integer, ByVal nMode As Integer, ByVal nPortA As Integer, ByVal nPortB As Integer, ByVal nPortC As Integer) As Long
Declare Function BCTInitAOutModes Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID, ByVal nDev As Integer, ByVal nChan0 As Integer, ByVal nChan1 As Integer, ByVal nChan2 As Integer, ByVal nChan3 As Integer) As Long
Declare Function BCTReadPort Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, nVal As Byte) As Long
Declare Function BCTReadPort16 Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, nVal As Integer) As Long
Declare Function BCTReadPortAin Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, ByVal nChan As Byte, ByVal nGain As Byte, ByVal nMode As Byte, nVal As Integer) As Long
Declare Function BCTWritePort Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, ByVal nVal As Byte) As Long
Declare Function BCTWritePort16 Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, ByVal nVal As Integer) As Long
Declare Function BCTWriteBit Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, ByVal nBit As Byte, ByVal nVal As Byte) As Long
Declare Function BCTProgramCounter Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, ByVal nSource As Byte) As Long
Declare Function BCTInitPacer Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID) As Long
Declare Function BCTStartPacer Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID, ByVal nInterval As Long) As Long
Declare Function BCTStopPacer Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID) As Long
Declare Function BCTAddPacerFunction Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID, ByVal nOperation As Integer, pVal As Long) As Long
Declare Function BCTAddPacerBlockIo Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, pBoardID As BCT_BOARD_ID, ByVal nOperation As Integer, pBuffer1 As BCT_BUFFER, pBuffer2 As BCT_BUFFER, ByVal nBytes As Long, ByVal nCount As Long) As Long
Declare Function BCTWait Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, ByVal delay As Long) As Long
Declare Function BCTInitHandle Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE) As Long
Declare Function BCTAllocate Lib "BCDLL32.DLL" (pBctBuf As BCT_BUFFER, ByVal Length As Long) As Long
Declare Function BCTRelease Lib "BCDLL32.DLL" (pBctBuf As BCT_BUFFER) As Long
Declare Function BCTAcquireAPacer Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID) As Long
Declare Function BCTReleaseAPacer Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID) As Long
Declare Function BCTReadBlockAin Lib "BCDLL32.DLL" (pBoardID As BCT_BOARD_ID, pHandle As BCT_HANDLE, ByVal nChan As Byte, ByVal nGain As Byte, ByVal nMode As Byte, pBuffer As BCT_BUFFER, ByVal nSamples As Long, ByVal nTime As Integer) As Long
Declare Function BCTAutoCalAin Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, ByVal nGain As Byte, MeanZero As Integer, MeanFsd As Integer) As Long
Declare Sub BCTErr2Txt Lib "BCDLL32.DLL" (ByVal nCode As Long, ByVal lpanTxt As String)
Declare Function BCTSetWdt Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, pData As BCT_WDT_SETDATA) As Long
Declare Function BCTReadWdt Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, pData As BCT_WDT_READDATA) As Long
Declare Function BCTWatchdog Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, ByVal nAction As Integer, pData As Byte) As Long
Declare Function BCTGetLastError Lib "BCDLL32.DLL" (pHandle As BCT_HANDLE, pErrCode As Long) As Long


'----------------------------------------------------------------
' Windows NT constant definition.
'----------------------------------------------------------------

Global Const INFINITE = &HFFFFFFFF  ' Max wait period


'----------------------------------------------------------------
' Constant definitions for board types, ports, etc.
'----------------------------------------------------------------

Global Const UNKNOWN_BOARD = 0  ' Board not supported
Global Const DIP_24 = 1         ' 24 Digital Inputs
Global Const DOP_24 = 2         ' 24 Digital Outputs
Global Const DIO_48 = 3         ' 24 digital inputs + 24 digital outputs
Global Const PIO_96 = 4         ' 96 programmable digital I/O lines
Global Const RB_8 = 5           ' 8 relay outputs
Global Const PIO_48DB = 6       ' 48 programmable digital I/O lines
Global Const PIO_144P = 7       ' 44 programmable digital I/O lines
Global Const DCM_16 = 8         ' 8 dig in + 8 dig out + 3 counters
Global Const AIP_24 = 9         ' 24 analogue inputs
Global Const AOP_8 = 10         ' 8 analogue outputs
Global Const AIP_8D = 11        ' 8 analog inputs + clock interrupts
Global Const AOP_12D = 12       ' 12 analog outputs with DMA & interrupts
Global Const ADC_42 = 13        ' 16 anin + 2 anout + 24 dig + interrupts
Global Const ADC_44D = 14       ' 16 anin + 4 anout + 24 dig + DMA + ints
Global Const WD_1 = 15          ' watchdog monitor and timer
Global Const DIO_32D = 16       ' 16 dig in + 16 dig out + 1 counter
Global Const PCI_PIO = 17       ' 48 programmable digital I/O lines on PCI
Global Const PCI_DIO = 18       ' 32 isolated digital I/O on PCI
Global Const PCI_ADC = 19       ' 16 anin + 4 anout + 24dig on PCI
Global Const PCI_WDT = 20       ' watchdog monitor and timer on PCI

Global Const BCT_8255 = 0
Global Const BCT_8254 = 1
Global Const BCT_ISODIG = 2
Global Const BCT_AIN = 3
Global Const BCT_AOUT = 4
Global Const BCT_WDT = 5

Global Const MODE_0 = 0
Global Const MODE_1 = 1
Global Const MODE_2 = 2
Global Const MODE_20 = 3
Global Const MODE_21 = 4

Global Const INPUT8 = 0
Global Const OUTPUT8 = 1
Global Const BIDI = 2
Global Const NOCARE = 3
Global Const ININ = 4
Global Const OUTOUT = 5
Global Const INOUT = 6
Global Const OUTIN = 7
'Global Const INPUT16 = 8
'Global Const OUTPUT16 = 9

Global Const NO_HANDLER = 0
Global Const READ_PACER = 1
Global Const BLOCK_SINGLE_READ = 2
Global Const BLOCK_DOUBLE_BUFFER_READ = 3
Global Const BLOCK_SINGLE_WRITE = 4
Global Const BLOCK_DOUBLE_BUFFER_WRITE = 5
Global Const BLOCK_REPEATED_WRITE = 6

Global Const BCT_WD_WRITE_TIMEOUT = 0
Global Const BCT_WD_REFRESH_TIMEOUT = 1
Global Const BCT_WD_WRITE_ENABLE_MASK = 2
Global Const BCT_WD_WRITE_OUTPUT_MASK = 3


'----------------------------------------------------------------
' Common driver / DLL bit definitions.
'----------------------------------------------------------------

Global Const P8254_CNTR_CTRL_MASK = &HC0
Global Const P8254_CNTR_DATA_MASK = &H3
Global Const P8254_CNTR_SHIFT = &H6

Global Const P8254_COUNTER0 = &H0
Global Const P8254_COUNTER1 = &H40
Global Const P8254_COUNTER2 = &H80
Global Const P8254_READBACK = &HC0

Global Const P8254_LATCH = &H0
Global Const P8254_LSB = &H10
Global Const P8254_MSB = &H20
Global Const P8254_16BITS = &H30

Global Const P8254_MODE0 = &H0
Global Const P8254_MODE1 = &H2
Global Const P8254_MODE2 = &H4
Global Const P8254_MODE3 = &H6
Global Const P8254_MODE4 = &H8
Global Const P8254_MODE5 = &HA
        
Global Const P8254_BINARY_COUNTER = &H0
Global Const P8254_BCD_COUNTER = &H1


'----------------------------------------------------------------
' Interrupt direction is Bit 0
'----------------------------------------------------------------

Global Const BCT_CLK_INTERRUPT_MASK = &H1
Global Const BCT_CLK_INTERRUPT_LOW = &H0
Global Const BCT_CLK_INTERRUPT_HIGH = &H1


'----------------------------------------------------------------
' Source is bits 1 and 2
'----------------------------------------------------------------

Global Const BCT_CLK_SRC_MASK = &H6
Global Const BCT_CLK_SRC_SHIFT = &H1
Global Const BCT_CLK_SRC_ONBOARD = &H0
'Global Const BCT_CLK_SRC_PORT1 = &H2
Global Const BCT_EXTERN_COUNTER_INPUT1 = &H2
Global Const BCT_CLK_SRC_CHAIN = &H4
'Global Const BCT_CLK_SRC_PORT2 = &H6
Global Const BCT_EXTERN_COUNTER_INPUT2 = &H6


'----------------------------------------------------------------
' Enable is bits 3 and 4
'----------------------------------------------------------------

Global Const BCT_CLK_ENABLE_MASK = &HC
Global Const BCT_CLK_ENABLE_SHIFT = &H3
Global Const BCT_CLK_ENABLED = &H0
Global Const BCT_CLK_ENABLE_PORT1 = &H4
Global Const BCT_CLK_ENABLE_PORT2 = &H8
Global Const BCT_CLK_ENABLE_PORT3 = &HC


'----------------------------------------------------------------
' Clear masks for PCIPIO Clock Control Registers
'----------------------------------------------------------------

Global Const PCIPIO_CTRLA_MASK_CLK0 = &H43
Global Const PCIPIO_CTRLB_MASK_CLK0 = &H30
Global Const PCIPIO_CTRLA_MASK_CLK1 = &HC
Global Const PCIPIO_CTRLB_MASK_CLK1 = &H4C
Global Const PCIPIO_CTRLA_MASK_CLK2 = &H30
Global Const PCIPIO_CTRLB_MASK_CLK2 = &H83


'----------------------------------------------------------------
' Clear masks for PCIDIO Clock Control Registers
'----------------------------------------------------------------

Global Const PCIDIO_CTRLA_MASK_CLK0 = &H43
Global Const PCIDIO_CTRLB_MASK_CLK0 = &H1
Global Const PCIDIO_CTRLA_MASK_CLK1 = &HC
Global Const PCIDIO_CTRLB_MASK_CLK1 = &H42
Global Const PCIDIO_CTRLA_MASK_CLK2 = &H30
Global Const PCIDIO_CTRLB_MASK_CLK2 = &H84


'----------------------------------------------------------------
' Clear masks for PCIADC Clock Control Registers (only 1)
'----------------------------------------------------------------

Global Const PCIADC_CTRL_MASK_CLK0 = &H0
Global Const PCIADC_CTRL_MASK_CLK1 = &H3
Global Const PCIADC_CTRL_MASK_CLK2 = &HC


'----------------------------------------------------------------
' ADC - AIN Control Codes
'----------------------------------------------------------------

Global Const PCIADC_AIN_CHANNEL_MASK = &HF0
Global Const PCIADC_AIN_CHANNEL_SHIFT = 4
Global Const PCIADC_AIN_GAIN_MASK = &HC
Global Const PCIADC_AIN_GAIN_SHIFT = 2
Global Const PCIADC_AIN_MODE_MASK = &H3
Global Const PCIADC_AIN_MODE_SHIFT = 0

Global Const PCIADC_AIN_GAIN_1 = &H0
Global Const PCIADC_AIN_GAIN_10 = &H1
Global Const PCIADC_AIN_GAIN_100 = &H2
Global Const PCIADC_AIN_GAIN_1000 = &H3

Global Const PCIADC_IN_GAIN1_SETTLE = 23            ' Microseconds
Global Const PCIADC_IN_GAIN10_SETTLE = 24           ' Microseconds
Global Const PCIADC_IN_GAIN100_SETTLE = 100         ' Microseconds
Global Const PCIADC_IN_GAIN1000_SETTLE = 1000       ' Microseconds
        
Global Const PCIADC_AIN_MODE_SINGLE = &H0
Global Const PCIADC_AIN_MODE_DIFFERENTIAL = &H1
Global Const PCIADC_AIN_MODE_CALIB_ZERO = &H2
Global Const PCIADC_AIN_MODE_CALIB_FSD = &H3
Global Const PCIADC_AIN_MULTI_CHANNEL = &H80

Global Const PCIADC_AIN_BUSY = &H1
Global Const PCIADC_AIN_FIFO_EMPTY = &H2
Global Const PCIADC_AIN_FIFO_HF = &H4
Global Const PCIADC_AIN_FIFO_FULL = &H8
Global Const PCIADC_AIN_HFIFO_SIZE = 1024           ' bytes

Global Const PCIADC_AIN_AUTOSEL = &H1
Global Const PCIADC_AIN_LEVEL_TRIGGER = &H2
Global Const PCIADC_AIN_CONVERT_NONE = &H3           ' AND to clear
Global Const PCIADC_AIN_CONVERT_SOFTWARE = &H4       ' or TO SET
Global Const PCIADC_AIN_CONVERT_PC0 = &H8            ' or TO SET
Global Const PCIADC_AIN_CONVERT_PC3 = &HC            ' or TO SET
Global Const PCIADC_AIN_CONVERT_COUNTER0 = &H10      ' or TO SET
Global Const PCIADC_AIN_CONVERT_COUNTER1 = &H14      ' or TO SET
Global Const PCIADC_AIN_CONVERT_COUNTER2 = &H18      ' or TO SET
'Global Const PCIADC_AIN_CONVERT_NOTUSED = &H1C       ' or TO SET


'----------------------------------------------------------------
' DLL Error Codes
'----------------------------------------------------------------

Global Const BCT_OK = 0
Global Const BCTERR_BOARD_BUSY = 1
Global Const BCTERR_BOARD_NOT_REQUESTED = 2
Global Const BCTERR_BOARD_ALREADY_REQUESTED = 3
Global Const BCTERR_NO_GLOBAL_MEMORY = 4
Global Const BCTERR_TOO_MANY_BOARDS = 5
Global Const BCTERR_GAINS_NOT_SUPPORTED = 6
Global Const BCTERR_INVALID_GAIN_VALUE = 7
Global Const BCTERR_NO_ANALOG_CHANNELS = 8
Global Const BCTERR_CHANNEL_NOT_ANALOG = 9

Global Const BCTERR_INVALID_RANGE = 10
Global Const BCTERR_NO_ANALOG_INPUTS = 11
Global Const BCTERR_CHANNEL_NOT_ANALOG_INPUT = 12
Global Const BCTERR_NULL_POINTER = 13
Global Const BCTERR_NO_ANALOG_OUTPUTS = 14
Global Const BCTERR_CHAN_NOT_ANALOG_OUTPUT = 15
Global Const BCTERR_VALUE_OUT_OF_RANGE = 16
Global Const BCTERR_ILLEGAL_NUM_CHANS = 17
Global Const BCTERR_NO_IRQ_AVAILABLE = 18
Global Const BCTERR_ILLEGAL_CHANS_IN_ARRAY = 19

Global Const BCTERR_ILLEGAL_NUM_SCANS = 20
Global Const BCTERR_LOST_DATA_IN_ISR = 21
Global Const BCTERR_ILLEGAL_FREQ = 22
Global Const BCTERR_NO_PROG_DIGITAL = 23
Global Const BCTERR_INVALID_CHARS = 24
Global Const BCTERR_INVALID_NUM_CHARS = 25
Global Const BCTERR_PORT_NOT_BIDIRECTIONAL = 26
Global Const BCTERR_NOT_DIGITAL_INPUT = 27
Global Const BCTERR_ILLEGAL_PORT = 28
Global Const BCTERR_PORT_NOT_INPUT = 29

Global Const BCTERR_ILLEGAL_BIT = 30
Global Const BCTERR_NOT_DIGITAL_OUTPUT = 31
Global Const BCTERR_ILLEGAL_DIGOUT_VALUE = 32
Global Const BCTERR_PORT_NOT_OUTPUT = 33
Global Const BCTERR_NO_COUNTERS = 34
Global Const BCTERR_INVALID_COUNTER = 35
Global Const BCTERR_INVALID_REF_FREQ = 36
Global Const BCTERR_INVALID_OUTPUT_FREQ = 37
Global Const BCTERR_NOT_WATCHDOG = 38
Global Const BCTERR_UNRECOGNISED_BOARD = 39

Global Const BCTERR_INVALID_BASEADDR = 40
Global Const BCTERR_INVALID_IRQ = 41
Global Const BCTERR_INVALID_DMACHAN = 42
Global Const BCTERR_NO_DATA = 43
Global Const BCTERR_STILL_ACQUIRING = 44
Global Const BCTERR_NO_DMA_AVAILABLE = 45
Global Const BCTERR_DMA_IN_USE = 46
Global Const BCTERR_BUFFER_TOO_SMALL = 47
Global Const BCTERR_INVALID_MODE_VALUE = 48
Global Const BCTERR_HARDWARE_MISSING = 49

Global Const BCTERR_UNSUPPORTED_OS = 50
Global Const BCTERR_GETSERIALNO_FAILED = 51
Global Const BCTERR_FAILED_RELEASEBOARDID = 52
Global Const BCTERR_INVALID_SERIALNO = 53
Global Const BCTERR_UNRECOGNISED_DEVICECODE = 54
Global Const BCTERR_UNRECOGNISED_PORTCODE = 55
Global Const BCTERR_UNRECOGNISED_DEVICE = 56
Global Const BCTERR_FAILEDCLOSE = 57
Global Const BCTERR_READPORT_FAILED = 58
Global Const BCTERR_WRITEPORT_FAILED = 59

Global Const BCTERR_INIT8255MODES_FAILED = 60
Global Const BCTERR_NTDRIVER_DEVICESOUTOFORDER = 61
Global Const BCTERR_DEVICECODENOTFOUND = 62
Global Const BCTERR_DEVICEOPEN = 63
Global Const BCTERR_INVALID8255MODE = 64
Global Const BCTERR_INVALIDIODIR = 65
Global Const BCTERR_INVALID_BITNO = 66
Global Const BCTERR_INVALID_BITSET = 67
Global Const BCTERR_WRITEBIT_FAILED = 68
Global Const BCTERR_INVALID_PACERCLOCK = 69

Global Const BCTERR_NOPACERCLOCK = 70
Global Const BCTERR_PACERCLOCKINUSE = 71
Global Const BCTERR_INITPACER_FAILED = 72
Global Const BCTERR_STOPPACER_FAILED = 73
Global Const BCTERR_ENABLEINTERUPT_FAILED = 74
Global Const BCTERR_INITCLOCK_FAILED = 75
Global Const BCTERR_UNEXPECTED_CLOCKNO = 76
Global Const BCTERR_UNSUPPORTED_BOARD = 77
Global Const BCTERR_ADDPACER_FAILED = 78
Global Const BCTERR_PACER_CLOCK_HANDLES_INUSE = 79

Global Const BCTERR_PACER_NOT_INITIALISED = 80
Global Const BCTERR_INVALID_INTERRUPT_INDEX = 81
Global Const BCTERR_FAILED_ENABLE_INTERRUPT = 82
Global Const BCTERR_FAILED_ADD_ACTION = 83
Global Const BCTERR_DISABLEINTERUPT_FAILED = 84
Global Const BCTERR_CANCELLED = 85
Global Const BCTERR_FAILED_PROGRAM_CNTRLCTRL = 86
Global Const BCTERR_INVALID_BYTECOUNT = 87
Global Const BCTERR_FAILED_MAP_BUFFER = 88
Global Const BCTERR_FAILED_LOCK_BUFFER = 89

Global Const BCTERR_FAILED_MAP_BUFFER_SYS = 90
Global Const BCTERR_INTERNAL_DRIVER_ERROR = 91
Global Const BCTERR_FAILED_CREATE_OVERLAP_EVENT = 92
Global Const BCTERR_FAILED_RESET_OVERLAP = 93
Global Const BCT_IO_PENDING = 94
Global Const BCTERR_WAIT_FAILED = 95
Global Const BCTERR_ALLOCATE_FAILED = 96
Global Const BCTERR_RELEASE_FAILED = 97
Global Const BCTERR_INVALID_IO_DIRECTION = 98
Global Const BCTERR_INIT_ISODIG_MODES_FAILED = 99

Global Const BCT_NOTIMPLEMENTED = 100
Global Const BCTERR_INVALID_DEVICE_NUMBER = 101
Global Const BCTERR_HANDLER_ABORTED = 102
Global Const BCTERR_FAILED_CLEAR_HANDLER = 103
Global Const BCTERR_UNSUPPORTED_8255_MODE = 104
Global Const BCTERR_UNSUPPORTED_A_DIRECTION = 105
Global Const BCTERR_UNSUPPORTED_B_DIRECTION = 106
Global Const BCTERR_UNSUPPORTED_C_DIRECTION = 107
Global Const BCTERR_UNSUPPORTED_ISODIG_MODE = 108
Global Const BCTERR_BLOCKIO_NOT_SUPPORTED = 109

Global Const BCTERR_ILLEGAL_COMBINATION = 110
Global Const BCTERR_MISSING_OPTION = 111
Global Const BCTERR_INITAOUTMODES_FAILED = 112
Global Const BCTERR_INVALID_CHANNEL_NUMBER = 113
Global Const BCTERR_INPUT_CONVERSION_TIMEOUT = 114
Global Const BCTERR_FIFO_ERROR = 115
Global Const BCTERR_AUTOSEL_NOT_SUPPORTED = 116
Global Const BCTERR_INVALID_SAMPLE_FREQ = 117
Global Const BCTERR_READBLOCK_FAILED = 118
Global Const BCTERR_PACER_CLOCK_HANDLE_INUSE = 119

Global Const BCTERR_FIFO_OVERFLOW = 120
Global Const BCTERR_AUTOCAL_NOT_SUPPORTED = 121
Global Const BCTERR_AUTOCAL_FAILED = 122
Global Const BCTERR_INVALID_COUNTER_VALUE = 123
Global Const BCTERR_INVALID_COUNTER_INPUT = 124
Global Const BCTERR_SETWDT_FAILED = 125
Global Const BCTERR_READWDT_FAILED = 126
Global Const BCTERR_WDTACCESS_TOOSOON = 127
Global Const BCTERR_ACCESS_WDT_FAILED = 128
Global Const BCTERR_INVALID_WDT_OPERATION = 129

Global Const BCTWARN_OUTPUT_VALUES_CLIPPED = 200

Global Const BCT_RUNNING = 300
Global Const BCT_FINISHED = 301
Global Const BCT_IDLE = 302
Global Const BCT_OVERRUN = 303

Global Const BCTERR_PCI_BIOS_NOT_PRESENT = 401
Global Const BCTERR_PCI_BOARD_NOT_FOUND = 402
Global Const BCTERR_PCI_ISR_NOT_AVAIL = 403
Global Const BCTERR_PCI_ISR_FUNCTION_ACTIVE = 404
Global Const BCTERR_PCI_INVALID_CLKSRC = 405
Global Const BCTERR_PCI_INVALID_CLKTYPE = 406


'----------------------------------------------------------------
' Interrupt handler definitions
'----------------------------------------------------------------

Global Const MAX_INTERRUPTS = 8
Global Const MAX_INTERRUPT_ACTIONS = 5

Global Const PCIPIO_MAX_INTERRUPTS = 7
Global Const PCIPIO_INTERRUPT_MASK = &H7F
Global Const PCIPIO_INT_AC0 = 0
Global Const PCIPIO_INT_AC3 = 1
Global Const PCIPIO_INT_BC0 = 2
Global Const PCIPIO_INT_BC3 = 3
Global Const PCIPIO_INT_TIMER0 = 4
Global Const PCIPIO_INT_TIMER1 = 5
Global Const PCIPIO_INT_TIMER2 = 6

Global Const PCIDIO_MAX_INTERRUPTS = 5
Global Const PCIDIO_INTERRUPT_MASK = &H1F
Global Const PCIDIO_INT_ISOLOW = 0
Global Const PCIDIO_INT_ISOHIGH = 1
Global Const PCIDIO_INT_TIMER0 = 2
Global Const PCIDIO_INT_TIMER1 = 3
Global Const PCIDIO_INT_TIMER2 = 4

Global Const PCIADC_MAX_INTERRUPTS = 8
Global Const PCIADC_INTERRUPT_MASK = &HFF
Global Const PCIADC_INT_PC0 = 0
Global Const PCIADC_INT_PC3 = 1
Global Const PCIADC_INT_TIMER0 = 2
Global Const PCIADC_INT_TIMER1 = 3
Global Const PCIADC_INT_TIMER2 = 4
Global Const PCIADC_INT_ADC_NOT_BUSY = 5
Global Const PCIADC_INT_FIFO_NOT_EMPTY = 6
Global Const PCIADC_INT_FIFO_HALF_FULL = 7

Global Const PCIWDT_MAX_INTERRUPTS = 3
Global Const PCIWDT_INTERRUPT_MASK = &HF
Global Const PCIWDT_ENA_WATCHDOG = 0
Global Const PCIWDT_INT_EXTERNAL = 1
Global Const PCIWDT_LM78 = 2
Global Const PCIWDT_WATCHDOG = 3


'----------------------------------------------------------------
' We get to an individual port on a device using the following
' naming conventions:
'
'  Board   The Physical Board itself - this has both a BoardType
'          and a BoardNo
'
'  Device  A particular Logical component - e.g. an 8255 chip or
'          the Analog Output Channels
'          DeviceType
'          DeviceNo (there may be more than one on the board)
'
'  Port    The lowest level unit - in general a Driver Device
'          corresponds to one of these where they are separately
'          addressable
'----------------------------------------------------------------

'----------------------------------------------------------------
' Supported Board Type Codes
'----------------------------------------------------------------

'----------------------------------------------------------------
' PCI Data acquisition board componants.
'----------------------------------------------------------------

Global Const BCT_PORT_A = 0
Global Const BCT_PORT_B = 1
Global Const BCT_PORT_C = 2
Global Const BCT_PORT_ISO = 2
Global Const BCT_CLK_0 = 0
Global Const BCT_CLK_1 = 1
Global Const BCT_CLK_2 = 2
Global Const ISO_DIG_LOW8 = 0
Global Const ISO_DIG_HIGH8 = 1
Global Const ISO_DIG_ALL16 = 2
Global Const BCT_CHAN_0 = 0
Global Const BCT_CHAN_1 = 1
Global Const BCT_CHAN_2 = 2
Global Const BCT_CHAN_3 = 3


'----------------------------------------------------------------
' Analogue output modes
'----------------------------------------------------------------

Global Const BCT_AOUT_VOLTAGE = &H1
Global Const BCT_AOUT_CURRENT = &H2


'----------------------------------------------------------------
' Indecies and constants for Pacers.
'----------------------------------------------------------------

Global Const PACER_STATUS = 0          ' We return the status here as well
Global Const PACER_OP = 0              ' What sort of Pacer To Add
Global Const PACER_SKIP_INTERRUPTS = 1 ' How many Pacer interrupts to skip between ops
Global Const PACER_CLOCK_ID = 2        ' Which Board has the Pacer Clock
Global Const PACER_BUFFER_1 = 3        ' Win32 Ptrs to Buffers,
Global Const PACER_BUFFER_2 = 4        ' WARNING, assumes a pointer is 32 bits long!
Global Const PACER_BUFFER_COUNT = 5    ' Number of bytes in a buffer


'----------------------------------------------------------------
'  Both DLL and Driver remember what sort of Board we are
'----------------------------------------------------------------

Global Const DEVICE_TYPE_PCIPIO = 41
Global Const DEVICE_TYPE_PCIDIO = 42
Global Const DEVICE_TYPE_PCIADC = 43
Global Const DEVICE_TYPE_PCIWDT = 44

Global Const DEVICE_TYPE_8254 = 51
Global Const DEVICE_TYPE_8255 = 52
Global Const DEVICE_TYPE_ISODIG = 53
Global Const DEVICE_TYPE_AIN = 54
Global Const DEVICE_TYPE_AOUT = 55
Global Const DEVICE_TYPE_WDT = 56

'----------------------------------------------------------------
' End of listing.
'----------------------------------------------------------------

