VERSION 5.00
Begin VB.Form diotest 
   Caption         =   "PCI-DIO Test Program"
   ClientHeight    =   3255
   ClientLeft      =   60
   ClientTop       =   345
   ClientWidth     =   5895
   LinkTopic       =   "Form1"
   ScaleHeight     =   3255
   ScaleWidth      =   5895
   StartUpPosition =   3  'Windows Default
   Begin VB.TextBox Status 
      Height          =   1455
      Left            =   120
      Locked          =   -1  'True
      MultiLine       =   -1  'True
      TabIndex        =   4
      Top             =   1680
      Width           =   5655
   End
   Begin VB.CommandButton Read 
      Caption         =   "&Read"
      Height          =   495
      Left            =   3120
      TabIndex        =   3
      Top             =   960
      Width           =   2175
   End
   Begin VB.CommandButton Write 
      Caption         =   "&Write"
      Height          =   495
      Left            =   480
      TabIndex        =   2
      Top             =   960
      Width           =   2175
   End
   Begin VB.TextBox InpVal 
      Alignment       =   1  'Right Justify
      Height          =   375
      Left            =   3360
      Locked          =   -1  'True
      TabIndex        =   1
      Top             =   360
      Width           =   1695
   End
   Begin VB.TextBox OutVal 
      Alignment       =   1  'Right Justify
      Height          =   375
      Left            =   720
      TabIndex        =   0
      Text            =   "0000"
      Top             =   360
      Width           =   1695
   End
   Begin VB.Label Label2 
      Alignment       =   2  'Center
      Caption         =   "Input Value (Hex)"
      Height          =   255
      Left            =   3120
      TabIndex        =   6
      Top             =   120
      Width           =   2175
   End
   Begin VB.Label Label1 
      Alignment       =   2  'Center
      Caption         =   "Output Value (Hex)"
      Height          =   255
      Left            =   480
      TabIndex        =   5
      Top             =   120
      Width           =   2175
   End
End
Attribute VB_Name = "diotest"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
'----------------------------------------------------------------
' (C)2000 Blue Chip Technology Ltd.  All Rights Reserved.
'----------------------------------------------------------------
'
'  FileName  : $Workfile::                                     $
'
'  Release   : 1.00
'
'  Contents  : This file contains the sample application for
'              reading and writing values to the PCI-DIO using
'              the new BCTInitPCIDio function
'
'  History   :
'  $Revision::                                                 $
'  $Author::                                                   $
'  $Modtime::                                                  $
'  $History::                                                  $
'
'----------------------------------------------------------------
Dim nStatus As Long
Dim szErrorText As String
Dim szText As String
Dim nPciDioHandle As BCT_HANDLE
Dim pPciDioBoardId As BCT_BOARD_ID

'---------------------------------------------------------------
' OutputMessage - Adds a message to the status box
'
' Input  : szErr - Error message to add to text box called Status
' Return : None
'---------------------------------------------------------------
Private Sub OutputMessage(szErr As String)
    Status.Text = szErr + Chr$(13) + Chr$(10) + Status.Text
End Sub


'---------------------------------------------------------------
' Form_Load - Initialise a board ID structure for the PCI-DIO
'             and initialise and open a handle for a pacer
'
' Input  : None
' Return : None
'---------------------------------------------------------------

Private Sub Form_Load()

szErrorText = Space(120)

    '---------------------------------------------------------------
    ' Start by initialising a handle
    '---------------------------------------------------------------
    OutputMessage ("Initialising a handle for use by the PCI-DIO")
    nStatus = BCTInitHandle(nPciDioHandle)
    If nStatus <> BCT_OK Then
        Call BCTErr2Txt(nStatus, szErrorText)
        OutputMessage ("BCTInitHandle returned: " + szErrorText)
    End If
    
    '---------------------------------------------------------------
    ' Next get the driver to fill in the board ID structure for the
    ' PCI-DIO
    '---------------------------------------------------------------
    OutputMessage ("Setting up the board ID structure")
    nStatus = BCTGetBoardId(pPciDioBoardId, PCI_DIO, 0)
    If nStatus <> BCT_OK Then
        Call BCTErr2Txt(nStatus, szErrorText)
        OutputMessage ("BCTGetBoardId returned: " + szErrorText)
    End If
    
    '---------------------------------------------------------------
    ' Initialise the isolated digital IO lines.
    '---------------------------------------------------------------
    nStatus = BCTInitPCIDio(pPciDioBoardId, 0) ' Only one board
    If nStatus <> BCT_OK Then
        Call BCTErr2Txt(nStatus, szErrorText)
        OutputMessage ("BCTInitPCIDio returned: " + szErrorText)
    End If
    
    '---------------------------------------------------------------
    ' Finally open the handle
    '---------------------------------------------------------------
    OutputMessage ("Opening the handle")
    nStatus = BCTOpen(nPciDioHandle, pPciDioBoardId, BCT_ISODIG, 0, BCT_PORT_ISO)
    If nStatus <> BCT_OK Then
        Call BCTErr2Txt(nStatus, szErrorText)
        OutputMessage ("BCTOpen returned: " + szErrorText)
    End If

End Sub

'---------------------------------------------------------------
' Form_Unload - Close the handle and release the board id
'               structure.  No error handling here as we aren't
'               allowed access to the form as it is in the
'               process of being destroyed.
'
' Input  : None
' Return : None
'---------------------------------------------------------------
Private Sub Form_Unload(Cancel As Integer)

    '---------------------------------------------------------------
    ' Reset the output port to 0000 prior to exiting to leave it in
    ' a known state
    '---------------------------------------------------------------
    nStatus = BCTWritePort16(nPciDioHandle, &H0)
    
    '---------------------------------------------------------------
    ' Make sure that the handle is closed
    '---------------------------------------------------------------
    nStatus = BCTClose(nPciDioHandle)

    '---------------------------------------------------------------
    ' Release the board ID
    '---------------------------------------------------------------
    nStatus = BCTReleaseBoardId(pPciDioBoardId)
    
End Sub

'---------------------------------------------------------------
' Read_Click - Read the 16bit value back from the input port on
'              the PCI-DIO and display it in the InpVal text box.
'
' Input  : None
' Output : None
'---------------------------------------------------------------

Private Sub Read_Click()

Dim nVal As Integer
szErrorText = Space(120)

    '---------------------------------------------------------------
    ' Read the value from the input on the PCI-DIO
    ' As with all IO operations that the driver executes there is
    ' the possibility that there is already an operation within the
    ' system that hasn't been completed.  In order to handle this
    ' the driver will return BCT_IO_PENDING.  If it does then we can
    ' either specify that it waits a fixed period of time to see if
    ' it can complete the operation or we can make it wait until
    ' the operation has completed by specifying the appropriate time
    ' to BCTWait
    '---------------------------------------------------------------
    OutputMessage ("About to read from input port")
    nStatus = BCTReadPort16(nPciDioHandle, nVal)
    If nStatus = BCT_IO_PENDING Then
        nStatus = BCTWait(nPciDioHandle, INFINITE)
    End If
    If (nStatus <> BCT_OK) And (nStatus <> BCT_IO_PENDING) Then
        Call BCTErr2Txt(nSatus, szErrorText)
        OutputMessage ("BCTReadPort16: " + szErrorText)
    Else
        InpVal.Text = Hex(nVal)
    End If

End Sub

'---------------------------------------------------------------
' Write_Click - Output the value in the OutVal text box to the
'               16bit output port on the PCI-DIO
'
' Input  : None
' Output : None
'---------------------------------------------------------------

Private Sub Write_Click()

szErrorText = Space(120)

    '---------------------------------------------------------------
    ' Write the value to the output on the PCI-DIO
    ' As with all IO operations that the driver executes there is
    ' the possibility that there is already an operation within the
    ' system that hasn't been completed.  In order to handle this
    ' the driver will return BCT_IO_PENDING.  If it does then we can
    ' either specify that it waits a fixed period of time to see if
    ' it can complete the operation or we can make it wait until
    ' the operation has completed by specifying the appropriate time
    ' to BCTWait
    '---------------------------------------------------------------
    OutputMessage ("About to write to output port")
    nStatus = BCTWritePort16(nPciDioHandle, CStr("&H" + OutVal.Text))
    If nStatus = BCT_IO_PENDING Then
        nStatus = BCTWait(nPciDioHandle, INFINITE)
    End If
    If (nStatus <> BCT_OK) And (nStatus <> BCT_IO_PENDING) Then
        Call BCTErr2Txt(nSatus, szErrorText)
        OutputMessage ("BCTWritePort16: " + szErrorText)
    End If

End Sub
