/* ---------------------------------------------------------- */
/* (C)2000 Blue Chip Technology Ltd.  All Rights Reserved.    */
/* ---------------------------------------------------------- */
/*                                                            */
/*  FileName  : $WorkFile::                                 $ */
/*                                                            */
/*  Release   : 1.00                                          */
/*                                                            */
/*  Contents  : This file contains the functions for the C    */
/*              based console mode application that will      */
/*              give the index number and board type from a   */
/*              given board serial number or will list all of */
/*              the boards in the system.                     */
/*                                                            */
/*  History   :                                               */
/*  $Revision::                                             $ */
/*  $Author::                                               $ */
/*  $Modtime::                                              $ */
/*  $History::                                              $ */
/*                                                            */
/* ---------------------------------------------------------- */

/* ---------------------------------------------------------- */
/* Standard Windows console mode include files.               */
/* ---------------------------------------------------------- */

#include <windows.h>
#include <winioctl.h>
#include <time.h>
#include <stdio.h>
#include <conio.h>
#include <string.h>


/* ---------------------------------------------------------- */
/* Application specific include files.                        */
/* ---------------------------------------------------------- */

#include "bluechip.h"


/* ---------------------------------------------------------- */
/* Program name and version number strings.                   */
/* ---------------------------------------------------------- */

#define PROGNAME  "PCI Data Acquisition Card Serial Number Tests v"
#define VERSION   "1.00.00"
#define COPYRIGHT "(C)2000 Blue Chip Technology Ltd."
#define RIGHTS    "All rights reserved"


/* ---------------------------------------------------------- */
/* Define keystrokes.                                         */
/* ---------------------------------------------------------- */

#define	ESC 0x1b


/* ---------------------------------------------------------- */
/* Local function prototypes.                                 */
/* ---------------------------------------------------------- */

void GetBoardNum(void);
void ListBoards(void);


/* ---------------------------------------------------------- */
/* Main function.                                             */
/*                                                            */
/* Input  : None                                              */
/* Return : Error code if problems.                           */
/* ---------------------------------------------------------- */

int main(void)
{
	char cSelection;

	// Display the program header
	printf("%s%s\n%s\n%s\n", PROGNAME, VERSION, COPYRIGHT, RIGHTS);

	// Display a menu and wait for a keypress
	do
	{
		printf("\n\n");
		printf("Please select a test:\n");
		printf("\t   1)  Determine board type and index from serial number\n");
		printf("\t   2)  List all boards in system\n");
		printf("\t<ESC> Exit\n");
		cSelection = _getch();
		switch (cSelection)
		{
			case '1':
				GetBoardNum();
				break;
			case '2':
				ListBoards();
				break;
		}
	} while (cSelection != ESC);
}


/* ---------------------------------------------------------- */
/* Local function implementations.                            */
/* ---------------------------------------------------------- */

/* ---------------------------------------------------------- */
/* GetBoardNum - Ask the user for a serial number and find    */
/*               the board type and its index number.         */
/*                                                            */
/* Input  : None                                              */
/* Return : None                                              */
/* ---------------------------------------------------------- */

void GetBoardNum(void)
{
	BCT_DWORD dwSerialNumber;
	BCT_BOARDTYPE nBoardType;
	BCT_WORD wBoardNo;
	BCT_DWORD dwStatus;
	char szErrorText[120];

	// Get the serial number from the user
	printf("Please enter board serial number: ");
	scanf_s("%x", &dwSerialNumber);

	// Make a call to BCTFindBoardNo to get the details for
	// the board specified
	dwStatus = BCTFindBoardNo(dwSerialNumber, &nBoardType, &wBoardNo);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTFindBoardNo returned: %s\n", szErrorText);
	}
	else
	{
		printf("Found board of type: ");
		switch (nBoardType)
		{
			case PCI_PIO:
				printf("PCI-PIO");
				break;
			case PCI_DIO:
				printf("PCI-DIO");
				break;
			case PCI_ADC:
				printf("PCI-ADC");
				break;
			case PCI_WDT:
				printf("PCI-WDT");
				break;
			case PCI_RLY:
				printf("PCI-RLY");
			break;
			default:
				printf("UNKNOWN %d", nBoardType);
				break;
		}
		printf(" board no. %d\n", wBoardNo);
	}
}


/* ---------------------------------------------------------- */
/* ListBoards - List all the boards in the system.            */
/*                                                            */
/* Input  : None                                              */
/* Return : None                                              */
/* ---------------------------------------------------------- */

void ListBoards(void)
{
	BCT_DWORD dwSerialNumber;
	BCT_BOARDTYPE nBoardType;
	BCT_WORD wBoardNo;
	BCT_DWORD dwStatus;
	BCT_WORD wIndex = 0;

	// Cycle in a loop until we find that we have no more boards
	// in the system
	do
	{
		dwStatus = BCTEnumerateBoards(wIndex, &nBoardType, &wBoardNo, &dwSerialNumber);
		if (dwStatus == BCT_OK)
		{
			printf("Board %d: ", wIndex);
			switch (nBoardType)
			{
				case PCI_PIO:
					printf("PCI-PIO");
					break;
				case PCI_DIO:
					printf("PCI-DIO");
					break;
				case PCI_ADC:
					printf("PCI-ADC");
					break;
				case PCI_WDT:
					printf("PCI-WDT");
					break;
				case PCI_RLY:
					printf("PCI-RLY");
					break;
				default:
					printf("UNKNOWN %d", nBoardType);
					break;
			}
			printf(" serial number %8x index %d\n", dwSerialNumber, wBoardNo);
		}

		// Move onto the next board
		wIndex++;
	} while (dwStatus != BCTERR_PCI_BOARD_NOT_FOUND);
}


/* ---------------------------------------------------------- */
/* End of listing.                                            */
/* ---------------------------------------------------------- */
