/* ---------------------------------------------------------- */
/* (C)2000 Blue Chip Technology Ltd.  All Rights Reserved.    */
/* ---------------------------------------------------------- */
/*                                                            */
/*  FileName  : $WorkFile::                                 $ */
/*                                                            */
/*  Release   : 1.00                                          */
/*                                                            */
/*  Contents  : This file contains the functions for the C    */
/*              based console mode application that will      */
/*              count off the first external input to         */
/*              counter 1 on a PCI-PIO.                       */
/*                                                            */
/*  History   :                                               */
/*  $Revision::                                             $ */
/*  $Author::                                               $ */
/*  $Modtime::                                              $ */
/*  $History::                                              $ */
/*                                                            */
/* ---------------------------------------------------------- */

/* ---------------------------------------------------------- */
/* Standard Windows console mode include files.               */
/* ---------------------------------------------------------- */

#include <windows.h>
#include <winioctl.h>
#include <time.h>
#include <stdio.h>
#include <conio.h>
#include <string.h>


/* ---------------------------------------------------------- */
/* Application specific include files.                        */
/* ---------------------------------------------------------- */

#include "bluechip.h"


/* ---------------------------------------------------------- */
/* Program name and version number strings.                   */
/* ---------------------------------------------------------- */

#define PROGNAME  "PCI Data Acquisition PCI-ADC Counter Test v"
#define VERSION   "1.00.00"
#define COPYRIGHT "(C)2000 Blue Chip Technology Ltd."
#define RIGHTS    "All rights reserved"


/* ---------------------------------------------------------- */
/* Handles and board ID structures.                           */
/* ---------------------------------------------------------- */

BCT_HANDLE nPciAdcHandle;
BCT_BOARD_ID pPciAdcBoardId;


/* ---------------------------------------------------------- */
/* Local function prototypes.                                 */
/* ---------------------------------------------------------- */

void Initialise(void);
void Deinitialise(void);


/* ---------------------------------------------------------- */
/* Main function.                                             */
/*                                                            */
/* Input  : None                                              */
/* Return : Error code if problems.                           */
/* ---------------------------------------------------------- */

int main(void)
{
	BCT_DWORD dwStatus;
	char szErrorText[120];
	BCT_WORD wVal;

	// Display the program header
	printf("%s%s\n%s\n%s\n", PROGNAME, VERSION, COPYRIGHT, RIGHTS);

	// Initialise the handles and the board ID structure.
	Initialise();

	// Program the counter to start counting
	dwStatus = BCTProgramCounter(&nPciAdcHandle, BCT_EXTERN_COUNTER_INPUT1);
	if (dwStatus == BCT_IO_PENDING)
	{
		dwStatus = BCTWait(&nPciAdcHandle, INFINITE);
	}
	if (dwStatus != BCT_OK && dwStatus != BCT_IO_PENDING)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTProgramCounter returned: %s\n", szErrorText);
	}
		
	// Get and display the count and wait for a keypress to
	// terminate
	printf("Spinning on counter 1, external input 1.  Press a key to exit\n");
	do
	{
		dwStatus = BCTReadPort16(&nPciAdcHandle, &wVal);
		if (dwStatus == BCT_IO_PENDING)
		{
			dwStatus = BCTWait(&nPciAdcHandle, INFINITE);
		}
		if (dwStatus != BCT_OK && dwStatus != BCT_IO_PENDING)
		{
			BCTErr2Txt(dwStatus, szErrorText);
			printf("BCTReadPort16: %s\n", szErrorText);
		}
		else
		{
			printf("Counter val: 0x%.4x\r", wVal);
		}
	} while (!_kbhit());

	// We are done so close the handles and release the board ID
	Deinitialise();
}


/* ---------------------------------------------------------- */
/* Local function implementations.                            */
/* ---------------------------------------------------------- */

/* ---------------------------------------------------------- */
/* Initialise - Initialise the board id structure and the     */
/*              handles that we are going to use.             */
/*                                                            */
/* Input  : None                                              */
/* Return : None                                              */
/* ---------------------------------------------------------- */

void Initialise(void)
{
	BCT_DWORD dwStatus;
	char szErrorText[120];

	// Initialise a handle
	dwStatus = BCTInitHandle(&nPciAdcHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTInitHandle returned: %s\n", szErrorText);
	}

	// Get the driver to fill out the board ID structure
	dwStatus = BCTGetBoardId(&pPciAdcBoardId, PCI_ADC, 0);
	if (dwStatus != BCT_OK)
	{

		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTGetBoardId returned: %s\n", szErrorText);
	}

	// Open the handle that will be used by the pacer
	dwStatus = BCTOpen(&nPciAdcHandle, &pPciAdcBoardId, BCT_8254, 0, 1);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTOpen returned: %s\n", szErrorText);
	}
}


/* ---------------------------------------------------------- */
/* Deinitialise - Close the board id structure and the        */
/*                handles that we have been using.            */
/*                                                            */
/* Input  : None                                              */
/* Return : None                                              */
/* ---------------------------------------------------------- */

void Deinitialise(void)
{
	BCT_DWORD dwStatus;
	char szErrorText[120];

	// Close the handle
	dwStatus = BCTClose(&nPciAdcHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTClose returned: %s\n", szErrorText);
	}

	// Release the board ID structure
	dwStatus = BCTReleaseBoardId(&pPciAdcBoardId);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTReleaseBoardId returned: %s\n", szErrorText);
	}
}


/* ---------------------------------------------------------- */
/* End of listing.                                            */
/* ---------------------------------------------------------- */
