/*
	Blue Chip Technology	Win32 Dynamic Link Library

	bctypes.h		Platform independent data types PLUS error codes
					plus common Driver/DLL definitions

	Version History :

	0.1		DSB	22/10/97	Initial code
*/

#ifndef __BCTYPES_H__
#define __BCTYPES_H__

#define DllExport	__declspec( dllexport )

typedef char			BCT_INT8;
typedef short			BCT_INT16;
typedef long			BCT_INT32;
typedef unsigned char	BCT_BYTE;
typedef unsigned short	BCT_WORD;
typedef unsigned long	BCT_DWORD;
typedef BCT_BYTE *		BCT_PBYTEBUFFER;

//	Common Driver/DLL Bit Definitions
#define P8254_CNTR_CTRL MASK	0xC0
#define P8254_CNTR_DATA MASK	0x03
#define P8254_CNTR_SHIFT		0x06

#define P8254_COUNTER0			0x00
#define P8254_COUNTER1			0x40
#define P8254_COUNTER2			0x80
#define P8254_READBACK			0xc0

#define P8254_LATCH				0x00
#define P8254_LSB				0x10
#define P8254_MSB				0x20
#define P8254_16BITS			0x30

#define P8254_MODE0				0x00
#define P8254_MODE1				0x02
#define P8254_MODE2				0x04
#define P8254_MODE3				0x06
#define P8254_MODE4				0x08
#define P8254_MODE5				0x0a
	
#define P8254_BINARY_COUNTER	0x00
#define P8254_BCD_COUNTER		0x01

//	Interrupt direction is Bit 0
#define BCT_CLK_INTERRUPT_MASK		0x01
#define BCT_CLK_INTERRUPT_LOW		0x00
#define BCT_CLK_INTERRUPT_HIGH		0x01

//	Source is bits 1 and 2
#define BCT_CLK_SRC_MASK			0x06
#define BCT_CLK_SRC_SHIFT			0x01
#define BCT_CLK_SRC_ONBOARD			0x00
//#define BCT_CLK_SRC_PORT1			0x02
#define BCT_EXTERN_COUNTER_INPUT1	0x02
#define BCT_CLK_SRC_CHAIN			0x04
//#define BCT_CLK_SRC_PORT2			0x06
#define BCT_EXTERN_COUNTER_INPUT2	0x06

//	Enable is bits 3 and 4
#define BCT_CLK_ENABLE_MASK			0x0c
#define BCT_CLK_ENABLE_SHIFT		0x03
#define BCT_CLK_ENABLED				0x00
#define BCT_CLK_ENABLE_PORT1		0x04
#define BCT_CLK_ENABLE_PORT2		0x08
#define BCT_CLK_ENABLE_PORT3		0x0c

//	clear masks for PCIPIO Clock Control Registers
#define PCIPIO_CTRLA_MASK_CLK0		0x43
#define PCIPIO_CTRLB_MASK_CLK0		0x30
#define PCIPIO_CTRLA_MASK_CLK1		0x0c
#define PCIPIO_CTRLB_MASK_CLK1		0x4c
#define PCIPIO_CTRLA_MASK_CLK2		0x30
#define PCIPIO_CTRLB_MASK_CLK2		0x83

//	clear masks for PCIDIO Clock Control Registers
#define PCIDIO_CTRLA_MASK_CLK0		0x43
#define PCIDIO_CTRLB_MASK_CLK0		0x01
#define PCIDIO_CTRLA_MASK_CLK1		0x0c
#define PCIDIO_CTRLB_MASK_CLK1		0x42
#define PCIDIO_CTRLA_MASK_CLK2		0x30
#define PCIDIO_CTRLB_MASK_CLK2		0x84

//	clear masks for PCIADC Clock Control Registers (only 1)
#define PCIADC_CTRL_MASK_CLK0		0x00
#define PCIADC_CTRL_MASK_CLK1		0x03
#define PCIADC_CTRL_MASK_CLK2		0x0c

//	ADC - AIN Control Codes
#define PCIADC_AIN_CHANNEL_MASK			0xf0
#define PCIADC_AIN_CHANNEL_SHIFT		4
#define PCIADC_AIN_GAIN_MASK			0x0c
#define PCIADC_AIN_GAIN_SHIFT			2
#define PCIADC_AIN_MODE_MASK			0x03
#define PCIADC_AIN_MODE_SHIFT			0

#define PCIADC_AIN_GAIN_1				0x00
#define PCIADC_AIN_GAIN_10				0x01
#define PCIADC_AIN_GAIN_100				0x02
#define PCIADC_AIN_GAIN_1000			0x03

#define PCIADC_IN_GAIN1_SETTLE			23		// microseconds
#define PCIADC_IN_GAIN10_SETTLE			24		// microseconds
#define PCIADC_IN_GAIN100_SETTLE		100		// microseconds
#define PCIADC_IN_GAIN1000_SETTLE		1000	// microseconds
	
#define PCIADC_AIN_MODE_SINGLE			0x00
#define PCIADC_AIN_MODE_DIFFERENTIAL	0x01
#define PCIADC_AIN_MODE_CALIB_ZERO		0x02
#define PCIADC_AIN_MODE_CALIB_FSD		0x03
#define PCIADC_AIN_MULTI_CHANNEL		0x80	// used by user apps

#define PCIADC_AIN_BUSY					0x01
#define PCIADC_AIN_FIFO_EMPTY			0x02
#define PCIADC_AIN_FIFO_HF				0x04
#define PCIADC_AIN_FIFO_FULL			0x08
#define PCIADC_AIN_HFIFO_SIZE			1024	// bytes

#define PCIADC_AIN_AUTOSEL				0x01
#define PCIADC_AIN_LEVEL_TRIGGER		0x02
#define PCIADC_AIN_CONVERT_NONE			0x03	// AND to clear
#define PCIADC_AIN_CONVERT_SOFTWARE		0x04	// or TO SET
#define PCIADC_AIN_CONVERT_PC0			0x08	// or TO SET
#define PCIADC_AIN_CONVERT_PC3			0x0c	// or TO SET
#define PCIADC_AIN_CONVERT_COUNTER0		0x10	// or TO SET
#define PCIADC_AIN_CONVERT_COUNTER1		0x14	// or TO SET
#define PCIADC_AIN_CONVERT_COUNTER2		0x18	// or TO SET
//#define PCIADC_AIN_CONVERT_NOTUSED		0x1c	// or TO SET

//	DLL Error Codes
#define BCT_OK                                   0
#define BCTERR_BOARD_BUSY                        1
#define BCTERR_BOARD_NOT_REQUESTED               2
#define BCTERR_BOARD_ALREADY_REQUESTED           3
#define BCTERR_NO_GLOBAL_MEMORY                  4
#define BCTERR_TOO_MANY_BOARDS                   5
#define BCTERR_GAINS_NOT_SUPPORTED               6
#define BCTERR_INVALID_GAIN_VALUE                7
#define BCTERR_NO_ANALOG_CHANNELS                8
#define BCTERR_CHANNEL_NOT_ANALOG                9

#define BCTERR_INVALID_RANGE                    10
#define BCTERR_NO_ANALOG_INPUTS                 11
#define BCTERR_CHANNEL_NOT_ANALOG_INPUT         12
#define BCTERR_NULL_POINTER                     13
#define BCTERR_NO_ANALOG_OUTPUTS                14
#define BCTERR_CHAN_NOT_ANALOG_OUTPUT           15
#define BCTERR_VALUE_OUT_OF_RANGE               16
#define BCTERR_ILLEGAL_NUM_CHANS                17
#define BCTERR_NO_IRQ_AVAILABLE                 18
#define BCTERR_ILLEGAL_CHANS_IN_ARRAY           19

#define BCTERR_ILLEGAL_NUM_SCANS                20
#define BCTERR_LOST_DATA_IN_ISR                 21
#define BCTERR_ILLEGAL_FREQ                     22
#define BCTERR_NO_PROG_DIGITAL                  23
#define BCTERR_INVALID_CHARS                    24
#define BCTERR_INVALID_NUM_CHARS                25
#define BCTERR_PORT_NOT_BIDIRECTIONAL           26
#define BCTERR_NOT_DIGITAL_INPUT                27
#define BCTERR_ILLEGAL_PORT                     28
#define BCTERR_PORT_NOT_INPUT                   29

#define BCTERR_ILLEGAL_BIT                      30
#define BCTERR_NOT_DIGITAL_OUTPUT               31
#define BCTERR_ILLEGAL_DIGOUT_VALUE             32
#define BCTERR_PORT_NOT_OUTPUT                  33
#define BCTERR_NO_COUNTERS                      34
#define BCTERR_INVALID_COUNTER                  35
#define BCTERR_INVALID_REF_FREQ                 36
#define BCTERR_INVALID_OUTPUT_FREQ              37
#define BCTERR_NOT_WATCHDOG                     38
#define BCTERR_UNRECOGNISED_BOARD               39

#define BCTERR_INVALID_BASEADDR                 40
#define BCTERR_INVALID_IRQ                      41
#define BCTERR_INVALID_DMACHAN                  42
#define BCTERR_NO_DATA                          43
#define BCTERR_STILL_ACQUIRING                  44
#define BCTERR_NO_DMA_AVAILABLE                 45
#define BCTERR_DMA_IN_USE                       46
#define BCTERR_BUFFER_TOO_SMALL					47
#define BCTERR_INVALID_MODE_VALUE               48
#define BCTERR_HARDWARE_MISSING                 49

#define BCTERR_UNSUPPORTED_OS					50
#define BCTERR_GETSERIALNO_FAILED				51
#define BCTERR_FAILED_RELEASEBOARDID			52
#define BCTERR_INVALID_SERIALNO					53
#define BCTERR_UNRECOGNISED_DEVICECODE			54
#define BCTERR_UNRECOGNISED_PORTCODE			55
#define BCTERR_UNRECOGNISED_DEVICE				56
#define BCTERR_FAILEDCLOSE						57
#define BCTERR_READPORT_FAILED					58
#define BCTERR_WRITEPORT_FAILED					59
#define BCTERR_INIT8255MODES_FAILED				60
#define BCTERR_NTDRIVER_DEVICESOUTOFORDER		61
#define BCTERR_DEVICECODENOTFOUND				62
#define BCTERR_DEVICEOPEN						63
#define BCTERR_INVALID8255MODE					64
#define BCTERR_INVALIDIODIR						65
#define BCTERR_INVALID_BITNO					66
#define BCTERR_INVALID_BITSET					67
#define BCTERR_WRITEBIT_FAILED					68
#define BCTERR_INVALID_PACERCLOCK				69
#define BCTERR_NOPACERCLOCK						70
#define BCTERR_PACERCLOCKINUSE					71
#define BCTERR_INITPACER_FAILED					72
#define BCTERR_STOPPACER_FAILED					73
#define BCTERR_ENABLEINTERUPT_FAILED			74
#define BCTERR_INITCLOCK_FAILED					75
#define BCTERR_UNEXPECTED_CLOCKNO				76
#define BCTERR_UNSUPPORTED_BOARD				77
#define BCTERR_ADDPACER_FAILED					78
#define BCTERR_PACER_CLOCK_HANDLES_INUSE		79
#define BCTERR_PACER_NOT_INITIALISED			80
#define BCTERR_INVALID_INTERRUPT_INDEX			81
#define BCTERR_FAILED_ENABLE_INTERRUPT			82
#define BCTERR_FAILED_ADD_ACTION				83
#define BCTERR_DISABLEINTERUPT_FAILED			84
#define BCTERR_CANCELLED						85
#define BCTERR_FAILED_PROGRAM_CNTRLCTRL			86
#define BCTERR_INVALID_BYTECOUNT				87
#define BCTERR_FAILED_MAP_BUFFER				88
#define BCTERR_FAILED_LOCK_BUFFER				89
#define BCTERR_FAILED_MAP_BUFFER_SYS			90
#define BCTERR_INTERNAL_DRIVER_ERROR			91
#define BCTERR_FAILED_CREATE_OVERLAP_EVENT		92
#define BCTERR_FAILED_RESET_OVERLAP				93
#define BCT_IO_PENDING							94
#define BCTERR_WAIT_FAILED						95
#define BCTERR_ALLOCATE_FAILED					96
#define BCTERR_RELEASE_FAILED					97
#define BCTERR_INVALID_IO_DIRECTION				98
#define BCTERR_INIT_ISODIG_MODES_FAILED			99
#define BCT_NOTIMPLEMENTED                      100
#define BCTERR_INVALID_DEVICE_NUMBER			101
#define BCTERR_HANDLER_ABORTED					102
#define BCTERR_FAILED_CLEAR_HANDLER				103
#define BCTERR_UNSUPPORTED_8255_MODE			104
#define BCTERR_UNSUPPORTED_A_DIRECTION			105
#define BCTERR_UNSUPPORTED_B_DIRECTION			106
#define BCTERR_UNSUPPORTED_C_DIRECTION			107
#define BCTERR_UNSUPPORTED_ISODIG_MODE			108
#define BCTERR_BLOCKIO_NOT_SUPPORTED			109
#define BCTERR_ILLEGAL_COMBINATION				110
#define BCTERR_MISSING_OPTION					111
#define BCTERR_INITAOUTMODES_FAILED				112
#define BCTERR_INVALID_CHANNEL_NUMBER			113
#define BCTERR_INPUT_CONVERSION_TIMEOUT			114
#define BCTERR_FIFO_ERROR						115
#define BCTERR_AUTOSEL_NOT_SUPPORTED			116
#define BCTERR_INVALID_SAMPLE_FREQ				117
#define BCTERR_READBLOCK_FAILED					118
#define BCTERR_PACER_CLOCK_HANDLE_INUSE			119
#define BCTERR_FIFO_OVERFLOW					120
#define BCTERR_AUTOCAL_NOT_SUPPORTED			121
#define BCTERR_AUTOCAL_FAILED					122
#define BCTERR_INVALID_COUNTER_VALUE			123
#define BCTERR_INVALID_COUNTER_INPUT			124
#define BCTERR_SETWDT_FAILED					125
#define BCTERR_READWDT_FAILED					126
#define BCTERR_WDTACCESS_TOOSOON				127
#define BCTERR_ACCESS_WDT_FAILED				128
#define BCTERR_INVALID_WDT_OPERATION			129

#define BCTWARN_OUTPUT_VALUES_CLIPPED           200
#define BCT_RUNNING                             300
#define BCT_FINISHED                            301
#define BCT_IDLE                                302
#define BCT_OVERRUN                             303

#define BCTERR_PCI_BIOS_NOT_PRESENT				401
#define BCTERR_PCI_BOARD_NOT_FOUND				402
#define BCTERR_PCI_ISR_NOT_AVAIL				403
#define BCTERR_PCI_ISR_FUNCTION_ACTIVE			404
#define BCTERR_PCI_INVALID_CLKSRC				405
#define BCTERR_PCI_INVALID_CLKTYPE				406

//	Interrupt handler definitions
#define MAX_INTERRUPTS				8
#define MAX_INTERRUPT_ACTIONS		5

#define PCIPIO_MAX_INTERRUPTS		7
#define PCIPIO_INTERRUPT_MASK		0x7f
#define PCIPIO_INT_AC0				0
#define PCIPIO_INT_AC3				1
#define PCIPIO_INT_BC0				2
#define PCIPIO_INT_BC3				3
#define PCIPIO_INT_TIMER0			4
#define PCIPIO_INT_TIMER1			5
#define PCIPIO_INT_TIMER2			6

#define PCIDIO_MAX_INTERRUPTS		5
#define PCIDIO_INTERRUPT_MASK		0x1f
#define PCIDIO_INT_ISOLOW			0
#define PCIDIO_INT_ISOHIGH			1
#define PCIDIO_INT_TIMER0			2
#define PCIDIO_INT_TIMER1			3
#define PCIDIO_INT_TIMER2			4

#define PCIADC_MAX_INTERRUPTS		8
#define PCIADC_INTERRUPT_MASK		0xff
#define PCIADC_INT_PC0				0
#define PCIADC_INT_PC3				1
#define PCIADC_INT_TIMER0			2
#define PCIADC_INT_TIMER1			3
#define PCIADC_INT_TIMER2			4
#define PCIADC_INT_ADC_NOT_BUSY		5
#define PCIADC_INT_FIFO_NOT_EMPTY	6
#define PCIADC_INT_FIFO_HALF_FULL	7

#define PCIWDT_MAX_INTERRUPTS		3
#define PCIWDT_INTERRUPT_MASK		0x0f
#define PCIWDT_ENA_WATCHDOG			0
#define PCIWDT_INT_EXTERNAL			1
#define PCIWDT_INT_LM78				2
#define PCIWDT_INT_WATCHDOG			3

/*	We get to an individual port on a device using the following naming conventions:

	Board		The Physical Board itself - this has both a 
				BoardType and a 
				BoardNo
	
	Device		A particular Logical component - e.g. an 8255 chip or the Analog Output Channels
				DeviceType
				DeviceNo (there may be more than one on the board

	Port		The lowest level unit - in general a Driver Device corresponds to one
				of these where they are separately addressable
*/
//	Supported Board DeviceType Codes
typedef enum {
	UNKNOWN_BOARD,  // Board not supported
	DIP_24,         //  24 Digital Inputs
	DOP_24,         //  24 Digital Outputs
	DIO_48,         //  24 digital inputs + 24 digital outputs
	PIO_96,         //  96 programmable digital I/O lines
	RB_8,           //   8 relay outputs
	PIO_48DB,       //  48 programmable digital I/O lines
	PIO_144P,       // 144 programmable digital I/O lines
	DCM_16,         //   8 dig in + 8 dig out + 3 counters
	AIP_24,         //  24 analogue inputs
	AOP_8,          //   8 analogue outputs
	AIP_8D,         //   8 analog inputs + clock interrupts
	AOP_12D,        //  12 analog outputs with DMA & interrupts
	ADC_42,         //  16 anin + 2 anout + 24 dig + interrupts
	ADC_44D,        //  16 anin + 4 anout + 24 dig + DMA + ints
	WD_1,           // watchdog monitor and timer
	DIO_32D,        //  16 dig in, 16 dig out, one counter
	PCI_PIO,	    // 48 digital I/O + clock
	PCI_DIO,		
	PCI_ADC,
	PCI_WDT
} BCT_BOARDTYPE;

typedef enum {
	BCT_8255,
	BCT_8254,
	BCT_ISODIG,
	BCT_AIN,
	BCT_AOUT,
	BCT_WDT
} BCT_DEVICETYPE;

#define BCT_PORT_A			0
#define BCT_PORT_B			1
#define BCT_PORT_C			2
#define BCT_PORT_ISO		2
#define BCT_CLK_0			0
#define BCT_CLK_1			1
#define BCT_CLK_2			2
#define ISO_DIG_LOW8		0
#define ISO_DIG_HIGH8		1
#define ISO_DIG_ALL16		2
#define BCT_CHAN_0			0
#define BCT_CHAN_1			1
#define BCT_CHAN_2			2
#define BCT_CHAN_3			3

#define BCT_AOUT_VOLTAGE		0x01
#define BCT_AOUT_CURRENT		0x02

typedef enum {
	MODE_0,		// All ports on the PIO are mode 0
	MODE_1,		// Ports A & B are mode 1 IO ports with C as control
	MODE_2,		// Port A is bi-directional IO with C as control
	MODE_20,	// Ports A and C are mode 2 as MODE_2 but port B is used as mode 0 IO.
	MODE_21		// Ports A and C are mode 2 as MODE_2 but port B is used as mode 1.
} BCT_8255_MODES;

#if !defined(__BCT_COINS__)
typedef enum {
	INPUT,		// Port is input
	OUTPUT,		// Port is output
	BIDI,		// Port is bi-directional (i.e. mode 2)
	NOCARE,		// Port is not used in application - dont care how setup
	ININ,		// Port C is all input
	OUTOUT,		// Port C is all output
	INOUT,		// Port C Upper nibble is input, lower output
	OUTIN,		// Port C Upper nibble is output, lower input
//	INPUT16,	// PCIDIO In 16 Bit mode Input
//	OUTPUT16	// PCIDIO In 16 Bit mode Output
} BCT_DIRECTIONS;
#endif
typedef enum {
	NO_HANDLER,
	READ_PACER,
	BLOCK_SINGLE_READ,
	BLOCK_DOUBLE_BUFFER_READ,
	BLOCK_SINGLE_WRITE,
	BLOCK_DOUBLE_BUFFER_WRITE,
	BLOCK_REPEATED_WRITE
} BCT_HANDLER;

typedef struct _BCT_WDT_SETDATA {
	BCT_BYTE		IN0_High_3_3V;
	BCT_BYTE		IN0_Low_3_3V;
	BCT_BYTE		IN1_High_5V;
	BCT_BYTE		IN1_Low_5V;
	BCT_BYTE		IN2_High_12V;
	BCT_BYTE		IN2_Low_12V;
	BCT_BYTE		IN3_High;
	BCT_BYTE		IN3_Low;
	BCT_BYTE		IN4_High;
	BCT_BYTE		IN4_Low;
	BCT_BYTE		IN5_High_Minus12V;
	BCT_BYTE		IN5_Low_Minus12V;
	BCT_BYTE		IN6_High;
	BCT_BYTE		IN6_Low;
	BCT_BYTE		OverTempHigh;
	BCT_BYTE		TempHysteresisLow;
	BCT_BYTE		Fan1Count;
	BCT_BYTE		Fan2Count;
	BCT_BYTE		Fan3Count;
	BCT_BYTE		FanRpm;
} BCT_WDT_SETDATA, *PBCT_WDT_SETDATA;

typedef struct _BCT_WDT_READDATA {
	BCT_BYTE		IN0_3_3V;
	BCT_BYTE		IN1_5V;
	BCT_BYTE		IN2_12V;
	BCT_BYTE		IN3;
	BCT_BYTE		IN4;
	BCT_BYTE		IN5_Minus12V;
	BCT_BYTE		IN6;
	BCT_BYTE		Temperature;
	BCT_BYTE		Fan1Count;
	BCT_BYTE		Fan2Count;
	BCT_BYTE		Fan3Count;
	BCT_BYTE		ExternalInput;
	BCT_BYTE		InterruptStatus1;
	BCT_BYTE		InterruptStatus2;
} BCT_WDT_READDATA, *PBCT_WDT_READDATA;

#if !defined (__NT_DRIVER__)
typedef struct _BCT_HANDLE {
	HANDLE			Handle;
	OVERLAPPED		Overlap;
	BCT_DWORD		DeviceType;
	BCT_DWORD		BoardType;
	BCT_WORD		nPort;
	BCT_DWORD		LastError;
	clock_t			NextTime;
} BCT_HANDLE, *PBCT_HANDLE;

typedef struct _BCT_BOARD_ID {
	HANDLE			Handle;
	BCT_DWORD		SerialNo;
    char			DevName[30];
    char			Clock0Name[30];
    char			Clock1Name[30];
    char			Clock2Name[30];
	BCT_HANDLE		hClock0;
	BCT_HANDLE		hClock1;
	BCT_HANDLE		hClock2;
	BCT_DWORD		Index;
	BCT_DWORD		DeviceType;
} BCT_BOARD_ID;
#endif

typedef struct _BCT_BUFFER {
	ULONG				Length;
	volatile ULONG		Sema;
	BCT_BYTE			Buffer[];
} BCT_BUFFER, *PBCT_BUFFER;

/*	Index's for Pacer Commands

	The first two of these are constant, the others may vary?
*/
#define PACER_STATUS					0	//	we return the Status here as well
#define PACER_OP						0	//	what sort of Pacer To Add
#define PACER_SKIP_INTERRUPTS			1	//	how many Pacer interrupts to skip between ops
#define PACER_CLOCK_ID					2	//	which Board has the Pacer Clock
#define PACER_BUFFER_1					3	//	Win32 Ptrs to Buffers, 
#define PACER_BUFFER_2					4	//	WARNING, assumes a pointer is 32 bits long!
#define PACER_BUFFER_COUNT				5	//	#bytes in a buffer

//	Both DLL and Driver remember what sort of Board we are
#define DEVICE_TYPE_PCIPIO			41
#define DEVICE_TYPE_PCIDIO			42
#define DEVICE_TYPE_PCIADC			43
#define DEVICE_TYPE_PCIWDT			44

#define DEVICE_TYPE_8254			51
#define DEVICE_TYPE_8255			52
#define DEVICE_TYPE_ISODIG			53
#define DEVICE_TYPE_AIN				54
#define DEVICE_TYPE_AOUT			55
#define DEVICE_TYPE_WDT				56

//	Supported Watchdog Operations
typedef enum {
	BCT_WD_WRITE_TIMEOUT,
	BCT_WD_REFRESH_TIMEOUT,
	BCT_WD_WRITE_ENABLE_MASK,
	BCT_WD_WRITE_OUTPUT_MASK,
	BCT_WD_RESET_BOARD
} WATCHDOG_OPERATION;

#endif
