/* ---------------------------------------------------------- */
/* (C)2000 Blue Chip Technology Ltd.  All Rights Reserved.    */
/* ---------------------------------------------------------- */
/*                                                            */
/*  FileName  : $WorkFile::                                 $ */
/*                                                            */
/*  Release   : 1.00                                          */
/*                                                            */
/*  Contents  : This file contains the functions for the C    */
/*              based console mode application that will      */
/*              test the PCI-PIO input and output functions   */
/*              using the pacer and by direct calls.          */
/*                                                            */
/*  History   :                                               */
/*  $Revision::                                             $ */
/*  $Author::                                               $ */
/*  $Modtime::                                              $ */
/*  $History::                                              $ */
/*                                                            */
/* ---------------------------------------------------------- */

/* ---------------------------------------------------------- */
/* Standard Windows console mode include files.               */
/* ---------------------------------------------------------- */

#include <windows.h>
//#include <winioctl.h>
#include <time.h>
#include <stdio.h>
#include <conio.h>
#include <string.h>


/* ---------------------------------------------------------- */
/* Application specific include files.                        */
/* ---------------------------------------------------------- */

#include "bluechip.h"


/* ---------------------------------------------------------- */
/* Program name and version number strings.                   */
/* ---------------------------------------------------------- */

#define PROGNAME  "PCI Data Acquisition PCI-PIO Test Program v"
#define VERSION   "1.00.00"
#define COPYRIGHT "(C)2000 Blue Chip Technology Ltd."
#define RIGHTS    "All rights reserved"


/* ---------------------------------------------------------- */
/* Handles and board ID structures.                           */
/* ---------------------------------------------------------- */

BCT_HANDLE nPciPio0PortAHandle;
BCT_HANDLE nPciPio0PortBHandle;
BCT_HANDLE nPciPio1PortAHandle;
BCT_HANDLE nPciPio0PortCHandle;
BCT_BOARD_ID pPciPioBoardId;
PBCT_BUFFER pPioBuffer;


/* ---------------------------------------------------------- */
/* Define keystrokes.                                         */
/* ---------------------------------------------------------- */

#define	ESC 0x1B


/* ---------------------------------------------------------- */
/* Local function prototypes.                                 */
/* ---------------------------------------------------------- */

void Initialise(void);
void Deinitialise(void);
void DirectIO(void);
void PacerIO(void);


/* ---------------------------------------------------------- */
/* Main function.                                             */
/*                                                            */
/* Input  : None                                              */
/* Return : Error code if problems.                           */
/* ---------------------------------------------------------- */

int main(void)
{
	char cSelection;

	// Display the program header
	printf("%s%s\n%s\n%s\n", PROGNAME, VERSION, COPYRIGHT, RIGHTS);

	// Initialise the handles and the board ID structure.
	Initialise();

	// Display a menu and wait for a keypress
	do
	{
		printf("\n\n");
		printf("Please select a test:\n");
		printf("\t   1)  Perform direct IO loopback test\n");
		printf("\t   2)  Perform pacer controlled IO loopback test\n");
		printf("\t<ESC> Exit\n");
		cSelection = _getch();
		switch (cSelection)
		{
			case '1':
				DirectIO();
				break;
			case '2':
				PacerIO();
				break;
		}
	} while (cSelection != ESC);

	
	// We are done so close the handles and release the board ID
	Deinitialise();
}


/* ---------------------------------------------------------- */
/* Local function implementations.                            */
/* ---------------------------------------------------------- */

/* ---------------------------------------------------------- */
/* Initialise - Initialise the board id structure and the     */
/*              handles that we are going to use.             */
/*                                                            */
/* Input  : None                                              */
/* Return : None                                              */
/* ---------------------------------------------------------- */

void Initialise(void)
{
	BCT_DWORD dwStatus;
	char szErrorText[120];
	int nIndex;

	// Initialise the four handles we are going to use
	dwStatus = BCTInitHandle(&nPciPio0PortAHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTInitHandle returned: %s\n", szErrorText);
	}
	dwStatus = BCTInitHandle(&nPciPio0PortBHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTInitHandle returned: %s\n", szErrorText);
	}
	dwStatus = BCTInitHandle(&nPciPio1PortAHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTInitHandle returned: %s\n", szErrorText);
	}
	dwStatus = BCTInitHandle(&nPciPio0PortCHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTInitHandle returned: %s\n", szErrorText);
	}

	// Get the driver to fill out the board ID structure
	dwStatus = BCTGetBoardId(&pPciPioBoardId, PCI_PIO, 0);
	if (dwStatus != BCT_OK)
	{

		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTGetBoardId returned: %s\n", szErrorText);
	}

	// The loopback connector that we use with this test is 
	// configured that PIO 0 port A is looped back to PIO 0
	// port B and PIO 1 port A is looped back to PIO 0 port C.
	// As such set the port directions up to do output on both
	// port 'A's and input on one port 'B's and one 'C'.  
	dwStatus = BCTInit8255Modes(&pPciPioBoardId, 0, MODE_0, OUTPUT, INPUT, ININ);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTInit8255Modes returned: %s\n", szErrorText);
	}
	dwStatus = BCTInit8255Modes(&pPciPioBoardId, 1, MODE_0, OUTPUT, INPUT, NOCARE);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTInit8255Modes returned: %s\n", szErrorText);
	}

	// Open the handles that will be used by the IO calls we will make
	dwStatus = BCTOpen(&nPciPio0PortAHandle, &pPciPioBoardId, BCT_8255, 0, BCT_PORT_A);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTOpen returned: %s\n", szErrorText);
	}
	dwStatus = BCTOpen(&nPciPio0PortBHandle, &pPciPioBoardId, BCT_8255, 0, BCT_PORT_B);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTOpen returned: %s\n", szErrorText);
	}
	dwStatus = BCTOpen(&nPciPio1PortAHandle, &pPciPioBoardId, BCT_8255, 1, BCT_PORT_A);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTOpen returned: %s\n", szErrorText);
	}
	dwStatus = BCTOpen(&nPciPio0PortCHandle, &pPciPioBoardId, BCT_8255, 0, BCT_PORT_C);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTOpen returned: %s\n", szErrorText);
	}

	// Allocate some space and fill in the buffer structure so that we 
	// have data for the paced output
	dwStatus = BCTAllocate(&pPioBuffer, 256);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTAllocate returned: %s\n", szErrorText);
	}
	for (nIndex = 0; nIndex < 256; nIndex++)
	{
		pPioBuffer -> Buffer[nIndex] = nIndex;
	}
}


/* ---------------------------------------------------------- */
/* Deinitialise - Close the board id structure and the        */
/*                handles that we have been using.            */
/*                                                            */
/* Input  : None                                              */
/* Return : None                                              */
/* ---------------------------------------------------------- */

void Deinitialise(void)
{
	BCT_DWORD dwStatus;
	char szErrorText[120];

	// Make sure that the memory we have been using for the pacer
	// is released
	dwStatus = BCTRelease(&pPioBuffer);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTRelease returned: %s\n", szErrorText);
	}

	// Close the handles
	dwStatus = BCTClose(&nPciPio0PortAHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTClose returned: %s\n", szErrorText);
	}
	dwStatus = BCTClose(&nPciPio0PortBHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTClose returned: %s\n", szErrorText);
	}
	dwStatus = BCTClose(&nPciPio1PortAHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTClose returned: %s\n", szErrorText);
	}
	dwStatus = BCTClose(&nPciPio0PortCHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTClose returned: %s\n", szErrorText);
	}

	// Release the board ID structure
	dwStatus = BCTReleaseBoardId(&pPciPioBoardId);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTReleaseBoardId returned: %s\n", szErrorText);
	}
}


/* ---------------------------------------------------------- */
/* DirectIO - Perform the loopback test using PIO 0 port A    */
/*            and B using direct IO calls.                    */
/*                                                            */
/* Input  : None                                              */
/* Return : None                                              */
/* ---------------------------------------------------------- */

void DirectIO(void)
{
	BCT_BYTE nOutVal;
	BCT_BYTE nInVal;
	BCT_DWORD dwStatus;
	long int LIoutval;
	char szErrorText[120];

	fflush ( stdin ); //flush keyboard buffer 

	// Get a value from the user to output to the PIO
	do
	{
		printf("Please enter a value in hex to output to PIO 0 port A: ");
		scanf_s("%x", &LIoutval);
		nOutVal = (BCT_BYTE) LIoutval;
	} while (nOutVal < 0x00 && nOutVal > 0xFF);

	// Output the value to PIO 0 port A
	dwStatus = BCTWritePort(&nPciPio0PortAHandle, nOutVal);
	if (dwStatus == BCT_IO_PENDING)
	{
		dwStatus = BCTWait(&nPciPio0PortAHandle, INFINITE);
	}
	if ((dwStatus != BCT_OK) && (dwStatus != BCT_IO_PENDING))
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTWritePort returned: %s\n", szErrorText);
	}

	// Read it back to ensure that we got what we were expecting
	dwStatus = BCTReadPort(&nPciPio0PortBHandle, &nInVal);
	if (dwStatus == BCT_IO_PENDING)
	{
		dwStatus = BCTWait(&nPciPio0PortBHandle, INFINITE);
	}
	if ((dwStatus != BCT_OK) && (dwStatus != BCT_IO_PENDING))
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTReadPort returned: %s\n", szErrorText);
	}

	// Comapre the values
	printf("Output 0x%.2x, read back 0x%.2x. %s\n", nOutVal, nInVal, nOutVal == nInVal ? "CORRECT" : "INCORRECT");
}

/* ---------------------------------------------------------- */
/* PacerIO - Perform the loopback test using PIO 1 port A and */
/*       PIO C using the pacer to drive data from the buffer  */
/*           to the output.                                   */
/*                                                            */
/* Input  : None                                              */
/* Return : None                                              */
/* ---------------------------------------------------------- */

void PacerIO(void)
{
	BCT_BYTE nInVal;
	BCT_DWORD dwStatus;
	char szErrorText[120];
	char cDummy;

	// Tell the user what is going on.
	printf("Starting pacer...press any key to exit\n");

	// Initialise a pacer
	dwStatus = BCTInitPacer(&pPciPioBoardId);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTInitPacer returned: %s\n", szErrorText);
	}

	// Add an event to the pacers event list
	dwStatus = BCTAddPacerBlockIo(&nPciPio1PortAHandle, &pPciPioBoardId, BLOCK_REPEATED_WRITE, pPioBuffer, NULL, 256, 0);
	if ((dwStatus != BCT_OK) && (dwStatus != BCT_IO_PENDING))
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTAddPacerBlockIo returned: %s\n", szErrorText);
	}

	// Start the pacer itself
	dwStatus = BCTStartPacer(&pPciPioBoardId, 30);    // Update at 30ms interval
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTStartPacer returned: %s\n", szErrorText);
	}

	// Spin in a loop until the user presses a key
	while (!_kbhit())
	{
		dwStatus = BCTReadPort(&nPciPio0PortCHandle, &nInVal);
		if (dwStatus == BCT_IO_PENDING)
		{
			dwStatus = BCTWait(&nPciPio0PortCHandle, INFINITE);
		}
		if ((dwStatus != BCT_OK) && (dwStatus != BCT_IO_PENDING))
		{
			BCTErr2Txt(dwStatus, szErrorText);
			printf("BCTReadPort returned: %s\n", szErrorText);
		}

		// Display the value we have read back
		printf("Value read from PIO 0 port C: 0x%.2x\r", nInVal);
	}
	cDummy = _getch();             // Throw away the dummy keypress
	printf("\n");

	// Stop the pacer before we exit
	dwStatus = BCTStopPacer(&pPciPioBoardId);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTStopPacer returned: %s\n", szErrorText);
	}
}


/* ---------------------------------------------------------- */
/* End of listing.                                            */
/* ---------------------------------------------------------- */
