/* ---------------------------------------------------------- */
/* (C)2000 Blue Chip Technology Ltd.  All Rights Reserved.    */
/* ---------------------------------------------------------- */
/*                                                            */
/*  FileName  : $WorkFile::                                 $ */
/*                                                            */
/*  Release   : 1.00.00                                       */
/*                                                            */
/*  Contents  : This file contains the functions for the C    */
/*              based console mode application that will      */
/*              perform direct controller or pacer driven     */
/*               											  */
/*                                                            */
/*  History   :                                               */
/*  $Revision::                                             $ */
/*  $Author::   D Robinson                                  $ */
/*  $Modtime::                                              $ */
/*  $History::                                              $ */
/*                                                            */
/* ---------------------------------------------------------- */

/* ---------------------------------------------------------- */
/* Standard Windows console mode include files.               */
/* ---------------------------------------------------------- */

#include <windows.h>
#include <winioctl.h>
#include <time.h>
#include <stdio.h>
#include <conio.h>
#include <string.h>


/* ---------------------------------------------------------- */
/* Application specific include files.                        */
/* ---------------------------------------------------------- */

#include "bluechip.h"


/* ---------------------------------------------------------- */
/* Program name and version number strings.                   */
/* ---------------------------------------------------------- */

#define PROGNAME  "PCI Relay Test v"
#define VERSION   "1.00.00"
#define COPYRIGHT "(C)2000 Blue Chip Technology Ltd."
#define RIGHTS    "All rights reserved"


/* ---------------------------------------------------------- */
/* Handles and board ID structures.                           */
/* ---------------------------------------------------------- */

BCT_HANDLE nPciRelay8bitRELAYoutHandle;
BCT_HANDLE nPciRelay16bitOPTOinHandle;
BCT_BOARD_ID pPciRelayBoardId;
PBCT_BUFFER pPciRelayBuffer;
/* ---------------------------------------------------------- */
/* Define keystrokes.                                         */
/* ---------------------------------------------------------- */

#define	ESC 0x1B

/* ---------------------------------------------------------- */
/* Local function prototypes.                                 */
/* ---------------------------------------------------------- */

void Initialise(void);
void Deinitialise(void);
void DirectIO(void);
void PacerIO(void);

/* ---------------------------------------------------------- */
/* Main function.                                             */
/*                                                            */
/* Input  : None                                              */
/* Return : Error code if problems.                           */
/* ---------------------------------------------------------- */

int main(void)
{
	char cSelection;

	// Display the program header
	printf("%s%s\n%s\n%s\n", PROGNAME, VERSION, COPYRIGHT, RIGHTS);

	// Initialise the handles and the board ID structure.
	Initialise();
	// Display a menu and wait for a keypress
	do
	{
		fflush ( stdin ); //flush keyboard buffer 
		printf("\n\n");
		printf("Please select a test:\n");
		printf("\t   1)  Perform direct IO loopback test\n");
		printf("\t   2)  Perform pacer controlled IO loopback test\n");
		printf("\t<ESC> Exit\n");
		cSelection = _getch();
		switch (cSelection)
		{
			case '1':
				DirectIO();
				break;
			case '2':
				PacerIO();
				break;
		}
	} while (cSelection != ESC);

	// We are done so close the handles and release the board ID
	Deinitialise();
}


/* ---------------------------------------------------------- */
/* Local function implementations.                            */
/* ---------------------------------------------------------- */

/* ---------------------------------------------------------- */
/* Initialise - Initialise the board id structure and the     */
/*              handles that we are going to use.             */
/*                                                            */
/* Input  : None                                              */
/* Return : None                                              */
/* ---------------------------------------------------------- */

void Initialise(void)
{
	BCT_DWORD dwStatus;
	char szErrorText[120];

	// Initialise a handle to relay outputs on relay card
	dwStatus = BCTInitHandle(&nPciRelay8bitRELAYoutHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTInitHandle returned: %s\n", szErrorText);
	}

	// Initialise a handle to OPTO isolated inputs on relay card
	dwStatus = BCTInitHandle(&nPciRelay16bitOPTOinHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTInitHandle returned: %s\n", szErrorText);
	}

	// Get the driver to fill out the board ID structure
	dwStatus = BCTGetBoardId(&pPciRelayBoardId, PCI_RLY, 0);
	if (dwStatus != BCT_OK)
	{

		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTGetBoardId returned: %s\n", szErrorText);
	}

	// Initialise the PCI-RLY.  Calling this function sets up one 8 bit port for the 
	// PCI-RLY relay outputs and one 16bit port for the PCI-RLY opto isolated inputs.
	// This function just requires a board ID structure and a board index number.

	dwStatus = BCTInitPCIRelay(&pPciRelayBoardId, 0);     // We only have 1 board
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTInitPciRelay returned: %s\n", szErrorText);
	}

	// Open the handle to the PCI-RLY relay outputs
	dwStatus = BCTOpen(&nPciRelay8bitRELAYoutHandle, &pPciRelayBoardId, BCT_RLY, 0, BCT_RLY_RLY_OUT);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTOpen returned: %s\n", szErrorText);
	}

	// Open the handle to the PCI-RLY opto isolated inputs
	dwStatus = BCTOpen(&nPciRelay16bitOPTOinHandle, &pPciRelayBoardId, BCT_RLY, 0, BCT_RLY_OPTO_IN);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTOpen returned: %s\n", szErrorText);
	}
}

/* ---------------------------------------------------------- */
/* Deinitialise - Close the board id structure and the        */
/*                handles that we have been using.            */
/*                                                            */
/* Input  : None                                              */
/* Return : None                                              */
/* ---------------------------------------------------------- */

void Deinitialise(void)
{
	BCT_DWORD dwStatus;
	char szErrorText[120];

	// Make sure that the outputs are all zeroed before exit
	dwStatus = BCTWritePort(&nPciRelay8bitRELAYoutHandle, 0x00);
	if (dwStatus == BCT_IO_PENDING)
	{
		dwStatus = BCTWait(&nPciRelay8bitRELAYoutHandle, INFINITE);
	}
	if ((dwStatus != BCT_OK) && (dwStatus != BCT_IO_PENDING))
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTWritePort8 returned: %s\n", szErrorText);
	}

	// Close the handle
	dwStatus = BCTClose(&nPciRelay8bitRELAYoutHandle);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTClose returned: %s\n", szErrorText);
	}

	// Release the board ID structure
	dwStatus = BCTReleaseBoardId(&pPciRelayBoardId);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTReleaseBoardId returned: %s\n", szErrorText);
	}
}


/* ---------------------------------------------------------- */
/* DirectIO - Perform the loopback test using direct IO calls */
/*                                                            */
/* Input  : None                                              */
/* Return : None                                              */
/* ---------------------------------------------------------- */

void DirectIO(void)
{
	BCT_DWORD dwStatus;
	char szErrorText[120];
	BCT_BYTE wOutVal = 0;
	long int LIoutval = 0;
	BCT_WORD wInVal = 0;
	char cKey;
	int upperlowerflag = 0; //used to determine if the 8 bit output of the card is looped
	char cSelection;		//into the upper or lower 8 bits of the 16 bit input.

	fflush ( stdin ); //flush keyboard buffer 

	do
	{
		printf("\n");
		printf("Which 8 bits are you looping back into?:\n");
		printf("\t   1)  Upper 8 bits\n");
		printf("\t   2)  Lower 8 bits\n");
		cSelection = _getch();
		switch (cSelection)
		{
			case '1':
				upperlowerflag = 1;
				break;
			case '2':
				upperlowerflag = 0;
				break;
		}
	} while (cSelection != '1' && cSelection != '2');


	// Get a value from the user to output to the RLY
	do
	{
		printf("Please enter an 8bit value in hex to output to the PCI-Relay: ");
		scanf_s("%x", &LIoutval);
		wOutVal = (BCT_BYTE) LIoutval; // This is required to keep VC++ 2005 runtime happy as scanf straight in to wOutVal causes buffer corruption.
	} while (wOutVal < 0x00 && wOutVal > 0xFF);

	// Output the value to PCI-Relay
	dwStatus = BCTWritePort(&nPciRelay8bitRELAYoutHandle, wOutVal);
	if (dwStatus == BCT_IO_PENDING)
	{
		dwStatus = BCTWait(&nPciRelay8bitRELAYoutHandle, INFINITE);
	}
	if ((dwStatus != BCT_OK) && (dwStatus != BCT_IO_PENDING))
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTWritePort8 returned: %s\n", szErrorText);
	}

	// In order to ensure that the value propogates through correctly
	// we need to ensure that we wait for 2.4ms before we read the
	// value back on the input.  This is to give the PCI-RLY time to 
	// serially propogate the output value to all of the output pins
	// and the Relay contacts to operate.
	// To make life simple we can just wait for a keystroke

	printf("Press a key to read back value\n");
	cKey = _getch();

	// Read all 16 bits back back to ensure that we got what we were expecting
	dwStatus = BCTReadPort16(&nPciRelay16bitOPTOinHandle, &wInVal);
	if (dwStatus == BCT_IO_PENDING)
	{
		dwStatus = BCTWait(&nPciRelay16bitOPTOinHandle, INFINITE);
	}
	if ((dwStatus != BCT_OK) && (dwStatus != BCT_IO_PENDING))
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTReadPort16 returned: %s\n", szErrorText);
	}

	if(upperlowerflag == 1)
	{
		wInVal = wInVal >> 8;
	}
	// Comapre the values
	printf("Output 0x%.2x, read back 0x%.4x. %s\n", wOutVal, wInVal, wOutVal == wInVal ? "CORRECT" : "INCORRECT");
}

/* ---------------------------------------------------------- */
/* PacerIO - Perform the loopback test using the PCI-RLY      */
/*           under pacer control.                             */
/*                                                            */
/* Input  : None                                              */
/* Return : None                                              */
/* ---------------------------------------------------------- */

void PacerIO(void)
{
	BCT_DWORD dwStatus;
	char szErrorText[120];
	BCT_WORD wInVal;
	char cDummy;
	int nIndex;

	// Allocate some space for the output buffer and pre-load some values
	dwStatus = BCTAllocate(&pPciRelayBuffer, 512);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTAllocate returned: %s\n", szErrorText);
	}
	for (nIndex = 0; nIndex < 512; nIndex+=2)
	{
		pPciRelayBuffer -> Buffer[nIndex] = (nIndex % 4) ? 0x55 : 0xAA;
		pPciRelayBuffer -> Buffer[nIndex + 1] = (nIndex % 4) ? 0x55 : 0xAA;
	}

	// Tell the user what is going on.
	printf("Starting pacer...press any key to exit\n");

	// Initialise a pacer
	dwStatus = BCTInitPacer(&pPciRelayBoardId);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTInitPacer returned: %s\n", szErrorText);
	}

	// Add an event to the pacers event list
	dwStatus = BCTAddPacerBlockIo(&nPciRelay8bitRELAYoutHandle, &pPciRelayBoardId, BLOCK_REPEATED_WRITE, pPciRelayBuffer, NULL, 512, 0);
	if ((dwStatus != BCT_OK) && (dwStatus != BCT_IO_PENDING))
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTAddPacerBlockIo returned: %s\n", szErrorText);
	}

	// Start the pacer itself
	dwStatus = BCTStartPacer(&pPciRelayBoardId, 500);    // Update at 2.5s interval
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTStartPacer returned: %s\n", szErrorText);
	}

	// Spin in a loop until the user presses a key
	while (!_kbhit())
	{
		dwStatus = BCTReadPort16(&nPciRelay16bitOPTOinHandle, &wInVal);
		if (dwStatus == BCT_IO_PENDING)
		{
			dwStatus = BCTWait(&nPciRelay16bitOPTOinHandle, INFINITE);
		}
		if ((dwStatus != BCT_OK) && (dwStatus != BCT_IO_PENDING))
		{
			BCTErr2Txt(dwStatus, szErrorText);
			printf("BCTReadPort returned: %s\n", szErrorText);
		}
		// Display the value we have read back
		printf("Value read from PCI-Relay: 0x%.4x\r", wInVal);
		Sleep(1); //drobinson



	}
	cDummy = _getch();             // Throw away the dummy keypress
	printf("\n");

	// Stop the pacer before we exit
	dwStatus = BCTStopPacer(&pPciRelayBoardId);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTStopPacer returned: %s\n", szErrorText);
	}

	// Release the memory we used for the buffer
	dwStatus = BCTRelease(&pPciRelayBuffer);
	if (dwStatus != BCT_OK)
	{
		BCTErr2Txt(dwStatus, szErrorText);
		printf("BCTRelease returned: %s\n", szErrorText);
	}
}


/* ---------------------------------------------------------- */
/* End of listing.                                            */
/* ---------------------------------------------------------- */
