/*
	Blue Chip Technology	Win32 Dynamic Link Library

	testdll.c			Source for dll test program

	Version History :

	0.1		DSB	01/12/97	Initial code
*/

#include <windows.h>
#include <winioctl.h>

#include <stdio.h>
#include <string.h>
#include <conio.h>
#include <math.h>
#include <time.h>

#include "bluechip.h"

BCT_DWORD		Status;
BCT_BOARD_ID	nBoardId, nBoardId2;
BCT_HANDLE		nHandle;
BCT_HANDLE		nHandle2;
char			errtxt[120];
BCT_BYTE		bValOut, bValIn, bValIn2;
BCT_DWORD		dwVal;
PBCT_BUFFER		pBuffer1, pBuffer2;
BCT_WORD		BoardNo = 0;
BCT_WORD		wValIn;
BCT_BYTE		LIoutval;
BCT_WORD		dLIoutval;


BCT_BYTE UnTwist(BCT_BYTE Bits)
{
	// Untwist
	int i;
	BCT_BYTE	t1;

	t1	= 0;
	for(i=0; i<8; i++) {
		if(Bits & (1<<i)) {
			t1 |= (1<<(7-i));
		}
	}
	return t1;
}

BCT_WORD UnTwist16(BCT_WORD Bits)
{
	// Untwist but don't invert
	int i;
	BCT_WORD	t1;

	t1	= 0;
	for(i=0; i<=16; i++) {
		if(Bits & (1<<i)) {
			t1 |= (1<<(15-i));
		}
	}
	return t1;
}

void ATest()
{
	BCT_BYTE	Val;
	BCT_DWORD	LastError;

	
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}
	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, OUTPUT, INPUT, ININ);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitISOModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}
	Status = BCTReadPort(&nHandle, &Val);
	if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		Status	= BCTGetLastError(&nHandle, &LastError);
		printf("BCTReadPort failed with Status=%s, LastErr=%d\n", 
				errtxt, LastError);
	}

	Status = BCTWritePort(&nHandle2, Val);
	if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle2, INFINITE);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		Status	= BCTGetLastError(&nHandle2, &LastError);
		printf("BCTWritePort failed with Status=%s, LastErr=%d\n", 
				errtxt, LastError);
	}

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}
	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}


void TestWdt()
{
	BCT_BYTE	Val;
	BOOL		Done = FALSE;
	int			reply;
	BCT_WDT_READDATA	ReadData;
	BCT_WDT_SETDATA		SetData;

	
	Status = BCTGetBoardId(&nBoardId, PCI_WDT, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_WDT, 0, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	while(!Done) {
		printf("Read Inputs             1\n");
		printf("Write Limits            2\n");
		printf("Write WDT Timer Count   3\n");
		printf("Refresh WDT Timer Count 4\n");
		printf("Write WDT Mask          5\n");
		printf("Write WDT Outputs       6\n");
		printf("Reset WDT               7\n");
		printf("                       99 - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: 
				Status = BCTReadWdt(&nHandle, &ReadData);
				if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
				if(Status != BCT_OK) {
					BCTErr2Txt(Status, errtxt);
					printf("BCTReadWdt failed with Status=%s\n", errtxt);
					return;
				}
				printf("IN0_3_3V=%#x, IN1_5V=%#x, IN2_12V=%#x, IN3=%#x, IN4=%#x, IN5_Minus12V=%#x\n",
						ReadData.IN0_3_3V, ReadData.IN1_5V, ReadData.IN2_12V, ReadData.IN3, ReadData.IN4, ReadData.IN5_Minus12V);
				printf("IN6=%#x, Temperature=%#x, Fan1Count=%#x\n", 
						ReadData.IN6, ReadData.Temperature, ReadData.Fan1Count);
				printf("Fan2Count=%#x, Fan3Count=%#x, ExternalInput=%#x\n", 
						ReadData.Fan2Count, ReadData.Fan3Count, ReadData.ExternalInput);
				printf("IntStatus1=%#x, IntStatus2=%#x\n", 
						ReadData.InterruptStatus1, ReadData.InterruptStatus2);
			break;
			
			case 2:
				SetData.IN0_High_3_3V		= 0x12;
				SetData.IN0_Low_3_3V		= 0x12;
				SetData.IN1_High_5V			= 0x12;
				SetData.IN1_Low_5V			= 0x12;
				SetData.IN2_High_12V		= 0x12;
				SetData.IN2_Low_12V			= 0x12;
				SetData.IN3_High			= 0x12;
				SetData.IN3_Low				= 0x12;
				SetData.IN4_High			= 0x12;
				SetData.IN4_Low				= 0x12;
				SetData.IN5_High_Minus12V	= 0x12;
				SetData.IN5_Low_Minus12V	= 0x12;
				SetData.IN6_High			= 0x12;
				SetData.IN6_Low				= 0x12;
				SetData.OverTempHigh		= 0x12;
				SetData.TempHysteresisLow	= 0x12;
				SetData.Fan1Count			= 0x12;
				SetData.Fan2Count			= 0x12;
				SetData.Fan3Count			= 0x12;
				SetData.FanRpm				= 0x50;
				
				printf("Enter Fan1 CountLimit(Hex)\n");
				scanf_s("%x", &Val);
				printf("Setting Fan1 Count to %#x\n", Val);
				SetData.Fan1Count			= Val;

				Status = BCTSetWdt(&nHandle, &SetData);
				if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
				if(Status != BCT_OK) {
					BCTErr2Txt(Status, errtxt);
					printf("BCTSetWdt failed with Status=%s\n", errtxt);
					return;
				}
			break;

			case 3:
				printf("Enter WD Timer Value (Hex)\n");
				scanf_s("%x", &Val);
				printf("Setting Timer val to %#x\n", Val);
				Status = BCTWatchdog(&nHandle, BCT_WD_WRITE_TIMEOUT, &Val);
				if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
				if(Status != BCT_OK) {
					BCTErr2Txt(Status, errtxt);
					printf("BCTWatchdog failed with Status=%s\n", errtxt);
					return;
				}
			break;

			case 4:
				printf("Resetting Timer\n");
				Status = BCTWatchdog(&nHandle, BCT_WD_REFRESH_TIMEOUT, &Val);
				if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
				if(Status != BCT_OK) {
					BCTErr2Txt(Status, errtxt);
					printf("BCTWatchdog failed with Status=%s\n", errtxt);
					return;
				}
			break;

			case 5:
				printf("Enter WD Enable Mask (Hex)\n");
				scanf_s("%x", &Val);
				printf("Setting Mask to %#x\n", Val);
				Status = BCTWatchdog(&nHandle, BCT_WD_WRITE_ENABLE_MASK, &Val);
				if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
				if(Status != BCT_OK) {
					BCTErr2Txt(Status, errtxt);
					printf("BCTWatchdog failed with Status=%s\n", errtxt);
					return;
				}
			break;

			case 6:
				printf("Enter WD OutputMask (Hex)\n");
				scanf_s("%x", &Val);
				printf("Setting Output to %#x\n", Val);
				Status = BCTWatchdog(&nHandle, BCT_WD_WRITE_OUTPUT_MASK, &Val);
				if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
				if(Status != BCT_OK) {
					BCTErr2Txt(Status, errtxt);
					printf("BCTWatchdog failed with Status=%s\n", errtxt);
					return;
				}
			break;

			case 7:
				Status = BCTWatchdog(&nHandle, BCT_WD_RESET_BOARD, &Val);
				if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
				if(Status != BCT_OK) {
					BCTErr2Txt(Status, errtxt);
					printf("BCTWatchdog failed with Status=%s\n", errtxt);
					return;
				}
			break;

			case 99: Done = TRUE;				break;
		}
	}
	
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}


void OutAdc8255(BCT_WORD Port)
{
	BCT_BYTE Val;

	Status = BCTGetBoardId(&nBoardId, PCI_ADC, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	if(Port == BCT_PORT_A) {
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, OUTPUT, INPUT, ININ);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}
	else 	if(Port == BCT_PORT_B) {
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, OUTPUT, ININ);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, INPUT, OUTOUT);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, Port);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Byte Output On 8255 Port %d\n\n", Port);
	while(1) {
		printf("Enter number in hex to write, 0x99 to stop\n");
		scanf_s("%x", &Val);
		if(Val == 0x99) {
			break;
		}
		Status = BCTWritePort(&nHandle, Val);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void OutPio00(BCT_WORD Port)
{
	BCT_BYTE Val;

	Status = BCTGetBoardId(&nBoardId, PCI_PIO, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	if(Port == BCT_PORT_A) {
		//	Set Port A to output, B to input
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, OUTPUT, INPUT, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		//	Set Port B to output, A to INPUT
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, OUTPUT, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, Port);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Byte Output On 8255 Port %d\n\n", Port);
	while(1) {
		printf("Enter number in hex to write, 0x99 to stop\n");
		scanf_s("%x", &Val);
		if(Val == 0x99) {
			break;
		}
		Status = BCTWritePort(&nHandle, Val);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void OutPio11(BCT_WORD BoardNo, BCT_WORD Port)
{
	BCT_BYTE Val;

	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	if(Port == BCT_PORT_A) {
		//	Set Port A to output
		Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, OUTPUT, NOCARE, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		//	Set Port B to output
		Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, NOCARE, OUTPUT, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 1, Port);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Byte Output On 8255 Port %d\n\n", Port);
	while(1) {
		printf("Enter number in hex to write, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Val = (BCT_BYTE) LIoutval;
		if(Val == 0x99) {
			break;
		}
		Status = BCTWritePort(&nHandle, Val);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void DioOutA()
{
	BCT_BYTE	Val;

	Status = BCTGetBoardId(&nBoardId, PCI_DIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Set Port A(low 8 bit) to output
	Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, OUTPUT, NOCARE, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitISOModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Byte Output On ISO Port A\n\n");
	while(1) {
		printf("Enter value in hex to set, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Val = (BCT_BYTE) LIoutval;
		if(Val == 0x99) {
			break;
		}
		Status = BCTWritePort(&nHandle, Val);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWritePort failed with Status=%s\n", errtxt);
			break;
		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void RLYOutA()
{
	BCT_BYTE	Val;

	Status = BCTGetBoardId(&nBoardId, PCI_RLY, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPCIRelay(&nBoardId, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPCIRelay failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_RLY, 0, BCT_RLY_RLY_OUT);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Byte Output On BCT_RLY\n\n");
	while(1) {
		printf("Enter value in hex to set, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Val = (BCT_BYTE) LIoutval;
		if(Val == 0x99) {
			break;
		}
		Status = BCTWritePort(&nHandle, Val);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWritePort failed with Status=%s\n", errtxt);
			break;
		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void DioOutB()
{
	BCT_BYTE	bVal;

	Status = BCTGetBoardId(&nBoardId, PCI_DIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Set Port B(High bit) to output
	Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, NOCARE, OUTPUT, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitISOModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Output On ISO Port B\n\n");
	while(1) {
		printf("Enter val to write, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		bVal = (BCT_BYTE) LIoutval;
		if(bVal == 0x99) {
			break;
		}
		Status = BCTWritePort(&nHandle, bVal);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWrite failed with Status=%s\n", errtxt);
			break;
		}

	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void DioOutC()
{
	BCT_WORD	wVal;

	Status = BCTGetBoardId(&nBoardId, PCI_DIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Set Port C(16 bit) to output
	Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, NOCARE, NOCARE, OUTPUT);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitISOModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_C);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Output On ISO Port C\n\n");
	while(1) {
		printf("Enter val to write, 0x99 to stop\n");
		scanf_s("%x", &dLIoutval);
		wVal = (BCT_WORD) dLIoutval;
		if(wVal == 0x99) {
			break;
		}
		printf("writing value: %d", wVal);
		Status = BCTWritePort16(&nHandle, wVal);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWritePort16 failed with Status=%s\n", errtxt);
			break;
		}

	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void DioBitsA()
{
	BCT_BYTE	Mask;

	Status = BCTGetBoardId(&nBoardId, PCI_DIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Set Port A(low 8 bit) to output
	Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, OUTPUT, NOCARE, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitISOModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Bitwise Output On ISO Port A\n\n");
	while(1) {
		printf("Enter bit number in hex to set, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Mask = (BCT_BYTE) LIoutval;
		printf("Mask=%#x\n", Mask);
		if(Mask == 0x99) {
			break;
		}
		Status = BCTWriteBit(&nHandle, Mask, 1);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}

		printf("Enter bit number in hex to clear, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Mask = (BCT_BYTE) LIoutval;
		printf("Mask=%#x\n", Mask);
		if(Mask == 0x99) {
			break;
		}
		Status = BCTWriteBit(&nHandle, Mask, 0);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void DioBitsB()
{
	BCT_BYTE	Mask;

	Status = BCTGetBoardId(&nBoardId, PCI_DIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Set Port B(High bit) to output
	Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, NOCARE, OUTPUT, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitISOModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Bitwise Output On ISO Port B\n\n");
	while(1) {
		printf("Enter bit number in hex to set, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Mask = (BCT_BYTE) LIoutval;
		printf("Mask=%#x\n", Mask);
		if(Mask == 0x99) {
			break;
		}
		Status = BCTWriteBit(&nHandle, Mask, 1);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}

		printf("Enter bit number in hex to clear, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Mask = (BCT_BYTE) LIoutval;
		printf("Mask=%#x\n", Mask);
		if(Mask == 0x99) {
			break;
		}
		Status = BCTWriteBit(&nHandle, Mask, 0);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void DioBitsC()
{
	BCT_BYTE	Mask;

	Status = BCTGetBoardId(&nBoardId, PCI_DIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Set Port C(16 bit) to output
	Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, NOCARE, NOCARE, OUTPUT);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitISOModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_C);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Bitwise Output On ISO Port C\n\n");
	while(1) {
		printf("Enter bit number in hex to set, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Mask = (BCT_BYTE) LIoutval;
		printf("Mask=%#x\n", Mask);
		if(Mask == 0x99) {
			break;
		}
		Status = BCTWriteBit(&nHandle, Mask, 1);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}

		printf("Enter bit number in hex to clear, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Mask = (BCT_BYTE) LIoutval;
		printf("Mask=%#x\n", Mask);
		if(Mask == 0x99) {
			break;
		}
		Status = BCTWriteBit(&nHandle, Mask, 0);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void RelayBits()
{
	BCT_BYTE	Mask;
	long int LIoutval = 0;

	Status = BCTGetBoardId(&nBoardId, PCI_RLY, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPCIRelay(&nBoardId, 0);
	if(Status != BCT_OK) 
	{
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitIsoDigModes failed with Status=%s\n", errtxt);
		return;
	}

	// Assume that the Ports have been properly initialised by the Loop
	Status = BCTOpen(&nHandle, &nBoardId, BCT_RLY, 0, BCT_RLY_RLY_OUT);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Bitwise Output On BCT_RLY_RLY_OUT\n\n");
	while(1) {
		printf("Enter bit number in hex to set, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Mask = (BCT_BYTE) LIoutval; // This is required to keep VC++ 2005 runtime happy as scanf straight in to wOutVal causes buffer corruption.

		printf("Mask=%#x\n", Mask);
		if(Mask == 0x99) {
			break;
		}
		Status = BCTWriteBit(&nHandle, Mask, 1);
		
		if(Status == BCT_IO_PENDING)
		{
			Status = BCTWait(&nHandle, INFINITE);
		}
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) 
		{
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}

		printf("Enter bit number in hex to clear, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Mask = (BCT_BYTE) LIoutval; // This is required to keep VC++ 2005 runtime happy as scanf straight in to wOutVal causes buffer corruption.
		printf("Mask=%#x\n", Mask);
		if(Mask == 0x99) {
			break;
		}
		Status = BCTWriteBit(&nHandle, Mask, 0);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}
void PioBits(BCT_DEVICETYPE DevType, BCT_WORD chip)
{
	BCT_BYTE	Mask;
	long int LIoutval = 0;

	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}


	Status = BCTInit8255Modes(&nBoardId, chip, MODE_0, NOCARE, NOCARE, OUTOUT);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes0 failed with Status=%s\n", errtxt);
		return;
	}

	// Assume that the Ports have been properly initialised by the Loop
	Status = BCTOpen(&nHandle, &nBoardId, DevType, chip, BCT_PORT_C);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Bitwise Output On %d Port C\n\n", chip);
	while(1) {
		printf("Enter bit number in hex to set, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Mask = (BCT_BYTE) LIoutval; // This is required to keep VC++ 2005 runtime happy as scanf straight in to wOutVal causes buffer corruption.

		printf("Mask=%#x\n", Mask);
		if(Mask == 0x99) {
			break;
		}
		Status = BCTWriteBit(&nHandle, Mask, 1);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}

		printf("Enter bit number in hex to clear, 0x99 to stop\n");
		scanf_s("%x", &LIoutval);
		Mask = (BCT_BYTE) LIoutval; // This is required to keep VC++ 2005 runtime happy as scanf straight in to wOutVal causes buffer corruption.
		printf("Mask=%#x\n", Mask);
		if(Mask == 0x99) {
			break;
		}
		Status = BCTWriteBit(&nHandle, Mask, 0);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void ADCBits(BCT_DEVICETYPE DevType, BCT_WORD chip)
{
	BCT_BYTE	Mask;

	Status = BCTGetBoardId(&nBoardId, PCI_ADC, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	// Assume that the Ports have been properly initialised by the Loop
	Status = BCTOpen(&nHandle, &nBoardId, DevType, chip, BCT_PORT_C);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Bitwise Output On %d Port C\n\n", chip);
	while(1) {
		printf("Enter bit number in hex to set, 0x99 to stop\n");
		scanf_s("%x", &Mask);
		printf("Mask=%#x\n", Mask);
		if(Mask == 0x99) {
			break;
		}
		Status = BCTWriteBit(&nHandle, Mask, 1);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}

		printf("Enter bit number in hex to clear, 0x99 to stop\n");
		scanf_s("%x", &Mask);
		printf("Mask=%#x\n", Mask);
		if(Mask == 0x99) {
			break;
		}
		Status = BCTWriteBit(&nHandle, Mask, 0);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopPio00AB()
{
	/*	Note that our test cable deliberately "twists" the connection so we need to 
		untwist the result!

		Also the DIO is 1 for off and 0 for on and so we will also invert the bit pattern

	*/
	BCT_WORD	Bits;

	Status = BCTGetBoardId(&nBoardId, PCI_PIO, 0);	// always 0
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the 8255 for 0 in Mode 0, Port A, B Input
	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, INPUT, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes1 failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Digital Input On 8255_0 Ports AB, hit any key to stop\n\n");
	while(!_kbhit()) {
		Status = BCTReadPort(&nHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}

		Status = BCTReadPort(&nHandle2, &bValIn2);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		Bits	= ((~UnTwist(bValIn)) & 0xff)<<8;
		Bits	|= ((~UnTwist(bValIn2)) & 0xff);

		printf("Read %#04x    \r", Bits);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopDio0A()
{
	/*	Note that our test cable deliberately "twists" the connection so we need to 
		untwist the result!

		Also the DIO is 1 for off and 0 for on and so we will also invert the bit pattern

	*/
	BCT_WORD	Bits;

	Status = BCTGetBoardId(&nBoardId, PCI_DIO, 0);	// always 0
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the DIO for 0 in Mode 0, Port A Input
	Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, INPUT, NOCARE, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitIsoDigModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Digital Input On ISODIG - A, hit any key to stop\n\n");
	while(!_kbhit()) {
		Status = BCTReadPort(&nHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}

		Bits	= UnTwist(bValIn);

		printf("Read %#04x    \r", Bits);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopDio0B()
{
	/*	Note that our test cable deliberately "twists" the connection so we need to 
		untwist the result!

		Also the DIO is 1 for off and 0 for on and so we will also invert the bit pattern

	*/
	BCT_WORD	Bits;

	Status = BCTGetBoardId(&nBoardId, PCI_DIO, 0);	// always 0
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the DIO for 0 in Mode 0, Port B Input
	Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, NOCARE, INPUT, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitIsoDigModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Digital Input On ISODIG-B, hit any key to stop\n\n");
	while(!_kbhit()) {
		Status = BCTReadPort(&nHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}

		Bits	= UnTwist(bValIn);

		printf("Read %#04x    \r", Bits);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopDio0CX(BCT_WORD Board, BOOL Detwist)
{
	/*	Note that our test cable deliberately "twists" the connection so we need to 
		untwist the result!

		Also the DIO is 1 for off and 0 for on and so we will also invert the bit pattern

		This routine also tests the new BCTInitPCIDio function
	*/
	BCT_WORD	Bits;

	Status = BCTGetBoardId(&nBoardId, PCI_DIO, Board);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the DIO for 0 in Mode 0, Port C Input
	Status = BCTInitPCIDio(&nBoardId, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitIsoDigModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_ISO);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Digital Input On ISODIG, hit any key to stop\n\n");
	while(!_kbhit()) {
		Status = BCTReadPort16(&nHandle, &wValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}

		if(Detwist)
		{
			Bits	= UnTwist16(wValIn);
		}
		else
		{
			Bits	= wValIn;
		}

		printf("Read %#04x    \r", Bits);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopRLY0CX(BCT_WORD Board, BOOL Detwist)
{
	/*	Note that our test cable deliberately "twists" the connection so we need to 
		untwist the result!

		Also the DIO is 1 for off and 0 for on and so we will also invert the bit pattern

		This routine also tests the new BCTInitPCIDio function
	*/
	BCT_WORD	Bits;

	Status = BCTGetBoardId(&nBoardId, PCI_RLY, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPCIRelay(&nBoardId, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPCIRelay failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_RLY, 0, BCT_RLY_OPTO_IN);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Digital Input On BCT_RLY, hit any key to stop\n\n");
	while(!_kbhit()) {
		Status = BCTReadPort16(&nHandle, &wValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}

		if(Detwist)
		{
			Bits	= UnTwist16(wValIn);
		}
		else
		{
			Bits	= wValIn;
		}

		printf("Read %#04x    \r", Bits);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopDio0C()
{
	/*	Note that our test cable deliberately "twists" the connection so we need to 
		untwist the result!

		Also the DIO is 1 for off and 0 for on and so we will also invert the bit pattern

	*/
	BCT_WORD	Bits;

	Status = BCTGetBoardId(&nBoardId, PCI_DIO, 0);	// always 0
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the DIO for 0 in Mode 0, Port C Input
	Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, NOCARE, NOCARE, INPUT);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitIsoDigModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_C);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Digital Input On ISODIG, hit any key to stop\n\n");
	while(!_kbhit()) {
		Status = BCTReadPort16(&nHandle, &wValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}

		Bits	= UnTwist16(wValIn);

		printf("Read %#04x    \r", Bits);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}


void LoopPio1B()
{
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the 8255 for 1 in Mode 0, Port B Input, C Output
	Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, NOCARE, INPUT, OUTOUT);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes1 failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 1, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen(BCT_8255_0, BCT_PORT_A) failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Digital Input On 8255_1 Port B, hit any key to stop\n\n");
	while(!_kbhit()) {
		Status = BCTReadPort(&nHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read %#03x  \r", bValIn);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopAdc0B()
{
	Status = BCTGetBoardId(&nBoardId, PCI_ADC, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, INPUT, OUTOUT);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Digital Input On 8255_0 Port B, hit any key to stop\n\n");
	while(!_kbhit()) {
		Status = BCTReadPort(&nHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read %#03x  \r", bValIn);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopPio1A(BCT_WORD Direction)
{
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the 8255 for 1 in Mode 0, Port A Input
	Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, INPUT, NOCARE, NOCARE);
	if(Status != BCT_OK) 
	{
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes1 failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the 8255 for 0 in Mode 0, Port C Output
	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, NOCARE, NOCARE, Direction);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes0 failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 1, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen(BCT_8255_0, BCT_PORT_A) failed with Status=%s\n", errtxt);
		return;
	}

	printf("Set 8255_0 Port C as direction %d\n", Direction);
	printf("Starting Digital Input On 8255_1 Port A, hit any key to stop\n\n");
	while(!_kbhit()) {
		Status = BCTReadPort(&nHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read %#03x  \r", bValIn);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopPio0C()
{
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the 8255 for 1 in Mode 0, Port A Output
	Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, OUTPUT, NOCARE, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes1 failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the 8255 for 0 in Mode 0, Port C Input
	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, NOCARE, NOCARE, ININ);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes0 failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_C);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen(BCT_8255_0, BCT_PORT_A) failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Digital Input On 8255_0 Port C, hit any key to stop\n\n");
	while(!_kbhit()) {
		Status = BCTReadPort(&nHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read %#03x  \r", bValIn);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPio1C_1B(BOOL Direction)
{
	PBCT_HANDLE	pInHandle, pOutHandle;

	//	If direction is FALSE make a reverse connection
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	if(Direction) {
		//	Init the 8255 for 1 in Mode 0, Port C out
		//	Init the 8255 for 1 in Mode 0, Port B input
		Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, NOCARE, INPUT, OUTOUT);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		//	Init the 8255 for 1 in Mode 0, Port C in
		//	Init the 8255 for 1 in Mode 0, Port B output
		Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, NOCARE, OUTPUT, ININ);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 1, BCT_PORT_C);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen(BCT_8255_0, BCT_PORT_A) failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 1, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	if(Direction) {
		pInHandle	= &nHandle2;
		pOutHandle	= &nHandle;
		printf("Writing on C1, Reading on B1\n");
	}
	else {
		pInHandle	= &nHandle;
		pOutHandle	= &nHandle2;
		printf("Writing on B1, Reading on C1\n");
	}

	//	Initialised the 8255 start writing/reading to it
	bValOut = 0;
	printf("Starting Digital Input/Output Loopback Test, hit any key to stop\n\n");
	while(!_kbhit()) {
		printf("\rSending %03d, ", bValOut);
//		printf("hit a key\n"); _getch();

		Status = BCTWritePort(pOutHandle, bValOut);
		if(Status == BCT_IO_PENDING) Status = BCTWait(pOutHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWritePort failed with Status=%s\n", errtxt);
			break;
		}

		printf("..., ");
//		printf("about to read hit a key\n"); _getch();

		Status = BCTReadPort(pInHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(pInHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read %03d, Difference=%#02x", bValIn, bValIn-bValOut);
//		printf("hit a key\n"); _getch();
		
		if(bValOut!=bValIn) {
			printf("\nRead Failed %d != %d\n", bValIn, bValOut);
			break;
		}

		bValOut++;
		
//		if(sema) {
//			printf("Clock Interrupted - hit any key\n");
//			sema=0;
//			_getch();
//		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}

}

void TestPio0C_1A(BOOL Direction)
{
	PBCT_HANDLE	pInHandle, pOutHandle;

	//	If direction is FALSE make a reverse connection
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	if(Direction) {
		//	Init the 8255 for 0 in Mode 0, Port C out
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, NOCARE, NOCARE, OUTOUT);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
		//	Init the 8255 for 1 in Mode 0, Port A input
		Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, INPUT, NOCARE, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		//	Init the 8255 for 0 in Mode 0, Port C in
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, NOCARE, NOCARE, ININ);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
		//	Init the 8255 for 1 in Mode 0, Port A output
		Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, OUTPUT, NOCARE, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_C);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 1, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	if(Direction) {
		pInHandle	= &nHandle2;
		pOutHandle	= &nHandle;
		printf("Writing on C0, Reading on A1\n");
	}
	else {
		pInHandle	= &nHandle;
		pOutHandle	= &nHandle2;
		printf("Writing on A1, Reading on C0\n");
	}

	//	Initialised the 8255 start writing/reading to it
	bValOut = 0;
	printf("Starting Digital Input/Output Loopback Test, hit any key to stop\n\n");
	while(!_kbhit()) {
		printf("\rSending %03d, ", bValOut);
//		printf("hit a key\n"); _getch();

		Status = BCTWritePort(pOutHandle, bValOut);
		if(Status == BCT_IO_PENDING) Status = BCTWait(pOutHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWritePort failed with Status=%s\n", errtxt);
			break;
		}

		printf("..., ");
//		printf("about to read hit a key\n"); _getch();

		Status = BCTReadPort(pInHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(pInHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read %03d, Difference=%#02x", bValIn, bValIn-bValOut);
//		printf("hit a key\n"); _getch();
		
		if(bValOut!=bValIn) {
			printf("\nRead Failed %d != %d\n", bValIn, bValOut);
			break;
		}

		bValOut++;
		
//		if(sema) {
//			printf("Clock Interrupted - hit any key\n");
//			sema=0;
//			_getch();
//		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}

}

void TestPio0A_0B(BOOL Direction)
{
	PBCT_HANDLE	pInHandle, pOutHandle;

	//	If direction is FALSE make a reverse connection
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	if(Direction) {
		//	Init the 8255 in Mode 0, Port A out, Port B input
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, OUTPUT, INPUT, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		//	Init the 8255 in Mode 0, Port B out, Port A input
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, OUTPUT, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	if(Direction) {
		pInHandle	= &nHandle2;
		pOutHandle	= &nHandle;
		printf("Writing on A0, Reading on B0\n");
	}
	else {
		pInHandle	= &nHandle;
		pOutHandle	= &nHandle2;
		printf("Writing on B0, Reading on A0\n");
	}

	//	Initialised the 8255 start writing/reading to it
	bValOut = 0;
	printf("Starting Digital Input/Output Loopback Test, hit any key to stop\n\n");
	while(!_kbhit()) {
		printf("\rSending %03d, ", bValOut);
//		printf("hit a key\n"); _getch();

		Status = BCTWritePort(pOutHandle, bValOut);
		if(Status == BCT_IO_PENDING) Status = BCTWait(pOutHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWritePort failed with Status=%s\n", errtxt);
			break;
		}

		printf("..., ");
//		printf("about to read hit a key\n"); _getch();

		Status = BCTReadPort(pInHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(pInHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read %03d, Difference=%#02x", bValIn, bValIn-bValOut);
//		printf("hit a key\n"); _getch();
		
		if(bValOut!=bValIn) {
			printf("\nRead Failed %d != %d\n", bValIn, bValOut);
			break;
		}

		bValOut++;
		
//		if(sema) {
//			printf("Clock Interrupted - hit any key\n");
//			sema=0;
//			_getch();
//		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}

}

void TestAdc0A_0B(BOOL Direction)
{
	PBCT_HANDLE	pInHandle, pOutHandle;

	//	If direction is FALSE make a reverse connection
	Status = BCTGetBoardId(&nBoardId, PCI_ADC, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	if(Direction) {
		//	Init the 8255 in Mode 0, Port A out, Port B input
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, OUTPUT, INPUT, ININ);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		//	Init the 8255 in Mode 0, Port B out, Port A input
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, OUTPUT, ININ);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	if(Direction) {
		pInHandle	= &nHandle2;
		pOutHandle	= &nHandle;
		printf("Writing on A0, Reading on B0\n");
	}
	else {
		pInHandle	= &nHandle;
		pOutHandle	= &nHandle2;
		printf("Writing on B0, Reading on A0\n");
	}

	//	Initialised the 8255 start writing/reading to it
	bValOut = 0;
	printf("Starting Digital Input/Output Loopback Test, hit any key to stop\n\n");
	while(!_kbhit()) {
		printf("\rSending %03d, ", bValOut);
//		printf("hit a key\n"); _getch();

		Status = BCTWritePort(pOutHandle, bValOut);
		if(Status == BCT_IO_PENDING) Status = BCTWait(pOutHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWritePort failed with Status=%s\n", errtxt);
			break;
		}

		printf("..., ");
//		printf("about to read hit a key\n"); _getch();

		Status = BCTReadPort(pInHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(pInHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read %03d, Difference=%#02x", bValIn, bValIn-bValOut);
//		printf("hit a key\n"); _getch();
		
		if(bValOut!=bValIn) {
			printf("\nRead Failed %d != %d\n", bValIn, bValOut);
			break;
		}

		bValOut++;
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}

}

void TestAdc0B_0C(BOOL Direction)
{
	PBCT_HANDLE	pInHandle, pOutHandle;

	//	If direction is FALSE make a reverse connection
	Status = BCTGetBoardId(&nBoardId, PCI_ADC, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	if(Direction) {
		//	Init the 8255 in Mode 0, Port B out, Port C input
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, OUTPUT, ININ);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		//	Init the 8255 in Mode 0, Port C out, Port B input
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, INPUT, OUTOUT);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 0, BCT_PORT_C);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	if(Direction) {
		pInHandle	= &nHandle2;
		pOutHandle	= &nHandle;
		printf("Writing on B0, Reading on C0\n");
	}
	else {
		pInHandle	= &nHandle;
		pOutHandle	= &nHandle2;
		printf("Writing on C0, Reading on B0\n");
	}

	//	Initialised the 8255 start writing/reading to it
	bValOut = 0;
	printf("Starting Digital Input/Output Loopback Test, hit any key to stop\n\n");
	while(!_kbhit()) {
		printf("\rSending %03d, ", bValOut);
//		printf("hit a key\n"); _getch();

		Status = BCTWritePort(pOutHandle, bValOut);
		if(Status == BCT_IO_PENDING) Status = BCTWait(pOutHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWritePort failed with Status=%s\n", errtxt);
			break;
		}

		printf("..., ");
//		printf("about to read hit a key\n"); _getch();

		Status = BCTReadPort(pInHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(pInHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read %03d, Difference=%#02x", bValIn, bValIn-bValOut);
//		printf("hit a key\n"); _getch();
		
		if(bValOut!=bValIn) {
			printf("\nRead Failed %d != %d\n", bValIn, bValOut);
			break;
		}

		bValOut++;
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}

}

void TestClock(DWORD dev)
{
	BCT_DWORD	nSecs;
	char		val;

	Status = BCTGetBoardId(&nBoardId, dev, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK)
	{
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	//	Start Pacer clock at 100 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 100);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		return;
	}

	nSecs = 0;
	printf("Testing Pacer Clock enter a single digit number of seconds to update clock at, 9 to stop\n\n");
	while(nSecs != 9) {
		dwVal	= nSecs*10L;
		Status = BCTAddPacerFunction(&nBoardId, READ_PACER, &dwVal);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTAddPacerFunction failed with Status=%s\n", errtxt);
			return;
		}

		printf("\rClock = %08d interrupts, Interval=%03d seconds", dwVal, nSecs);
		if(_kbhit()) 
		{
			val	= _getch();
			if((val >= '0') && (val <= '9')) nSecs = val - '0';
		}
	}
	printf("\n");

	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerDIOSingleWrite(BCT_WORD Port)
{
	Status = BCTGetBoardId(&nBoardId, PCI_DIO, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTGetBoardId(&nBoardId2, PCI_PIO, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}
	if(Port == BCT_PORT_A) {
		printf("Single Block Pacing 256 out on A 128 in on PIO 0-0B Twisted\n");

		//	Init the 8255 in Mode 0, Port B input
		Status = BCTInit8255Modes(&nBoardId2, 0, MODE_0, NOCARE, INPUT, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
		//	Init the DIO in Mode 0, Port A output
		Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, OUTPUT, NOCARE, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
		Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_A);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTOpen() failed with Status=%s\n", errtxt);
			return;
		}

		Status = BCTOpen(&nHandle2, &nBoardId2, BCT_8255, 0, BCT_PORT_B);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTOpen() failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		printf("Single Block Pacing 256 out on B 128 in on PIO 0-0A Twisted\n");

		//	Init the 8255 in Mode 0, Port A input
		Status = BCTInit8255Modes(&nBoardId2, 0, MODE_0, INPUT, NOCARE, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
		//	Init the DIO in Mode 0, Port B output
		Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, NOCARE, OUTPUT, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
		Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_B);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTOpen() failed with Status=%s\n", errtxt);
			return;
		}

		Status = BCTOpen(&nHandle2, &nBoardId2, BCT_8255, 0, BCT_PORT_A);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTOpen() failed with Status=%s\n", errtxt);
			return;
		}
	}

	{
		int i;
		for(i=0; i<512; i++) {
			pBuffer1->Buffer[i] = i;
			pBuffer2->Buffer[i] = 42;
		}
	}
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_SINGLE_WRITE, pBuffer1, NULL, 256, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	Status = BCTAddPacerBlockIo(&nHandle2, &nBoardId, BLOCK_SINGLE_READ, pBuffer2, NULL, 128, 1);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle2, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait2 failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	/*	Unlink the DIO-DIO Case there is a 2.4ms Latency in output on the
		DIO so the 8255 will read the "last" value we wrote on the DIO
		i.e. 0, 1, 2, 3 will arrive as 0, 2, 4, ...

		except
	*/
	{
		int			i;
		BOOL		Errors = FALSE;
		BCT_BYTE	ValIn, ValOut;
		for(i=0; i<128; i++) {
			ValOut = pBuffer1->Buffer[(i*2)];
			ValIn  = ~UnTwist(pBuffer2->Buffer[i]);
			if(ValOut != ValIn) {
				printf("Pacer Error:Buffer1[%d] = %d, Buffer2[%d]=%d\n", 
				(i*2), ValOut, i, ValIn);
				Errors = TRUE;
			}
		}
		if(!Errors) printf("Paced Single Block Read and Write successfull\n");
	}

	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerDIOSingleRead(BCT_WORD Board, BCT_WORD Port)
{
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, Board);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTGetBoardId(&nBoardId2, PCI_DIO, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}
	if(Port == BCT_PORT_A) {
		printf("Single Block Pacing 256 out on PIO 1-1B 128 in on DIO A Twisted\n");

		//	Init the 8255 in Mode 0, Port B output
		Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, NOCARE, OUTPUT, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
		//	Init the DIO in Mode 0, Port A input
		Status = BCTInitIsoDigModes(&nBoardId2, 0, MODE_0, INPUT, NOCARE, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitIsoDigModes failed with Status=%s\n", errtxt);
			return;
		}
		Status = BCTOpen(&nHandle2, &nBoardId2, BCT_ISODIG, 0, BCT_PORT_A);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTOpen() failed with Status=%s\n", errtxt);
			return;
		}

		Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 1, BCT_PORT_B);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTOpen() failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		printf("Single Block Pacing 256 out PIO 1-1 A 128 in on DIO 0-0B Twisted\n");

		//	Init the 8255 in Mode 0, Port A input
		Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, OUTPUT, NOCARE, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
			return;
		}
		//	Init the DIO in Mode 0, Port B output
		Status = BCTInitIsoDigModes(&nBoardId2, 0, MODE_0, NOCARE, INPUT, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitIsoDigModes failed with Status=%s\n", errtxt);
			return;
		}
		Status = BCTOpen(&nHandle2, &nBoardId2, BCT_ISODIG, 0, BCT_PORT_B);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTOpen() failed with Status=%s\n", errtxt);
			return;
		}

		Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 1, BCT_PORT_A);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTOpen() failed with Status=%s\n", errtxt);
			return;
		}
	}

	{
		int i;
		for(i=0; i<512; i++) {
			pBuffer1->Buffer[i] = i;
			pBuffer2->Buffer[i] = 42;
		}
	}
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_SINGLE_WRITE, pBuffer1, NULL, 256, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	Status = BCTAddPacerBlockIo(&nHandle2, &nBoardId, BLOCK_SINGLE_READ, pBuffer2, NULL, 128, 1);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle2, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait2 failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	/*	Unlink the PIO-PIO Case there is a "short" Latency in input on the
		DIO so the DIO "may" read the "last" value we wrote on the PIO
		i.e. 0, 1, 2, 3 will arrive as 0, 2, 4, ...

		In fact it does read the last value EXCEPT for that as the PIO
		outputs its last value (255) the Handler completes that I/O which
		takes significantly longer and in practice long enough so that
		it's longer than the input Latency on the DIO (which is present 
		but considerably shorted than the 2.4ms output latency!)
	*/
	{
		int			i;
		BOOL		Errors = FALSE;
		BCT_BYTE	ValIn, ValOut;
		for(i=0; i<128; i++) {
			ValOut = pBuffer1->Buffer[(i*2)];
			ValIn  = UnTwist(pBuffer2->Buffer[i]);
			if(ValOut != ValIn) {
				printf("Pacer Error:Buffer1[%d] = %d, Buffer2[%d]=%d\n", 
				(i*2), ValOut, i, ValIn);
				if((ValOut==254) && (ValIn == 255)) {
					printf("Due to DIO input latencies, this is quite possible, so it is not an error\n");
				}
				else Errors = TRUE;
			}
		}
		if(!Errors) printf("Paced Single Block Read and Write successfull\n");
	}

	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerRLYSingleRead()
{
	int i;
	BCT_WORD * pwBuf2;

	Status = BCTGetBoardId(&nBoardId, PCI_RLY, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Single Block Pacing 64 out on RLY port and in on RLY opto's\n");

	//	Init the relay board
	Status = BCTInitPCIRelay(&nBoardId, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPCIRelay failed with Status=%s\n", errtxt);
		return;
	}
	
	Status = BCTOpen(&nHandle, &nBoardId, BCT_RLY, 0, BCT_RLY_RLY_OUT);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_RLY, 0, BCT_RLY_OPTO_IN);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}
	
	
	for(i=0; i<64; i++) {
		pBuffer1->Buffer[i] = i;
		pBuffer2->Buffer[i] = 42;
	}
	pwBuf2	= (WORD *)pBuffer2->Buffer;


	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_SINGLE_WRITE, pBuffer1, NULL, 64, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) 
	{
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	Status = BCTAddPacerBlockIo(&nHandle2, &nBoardId, BLOCK_SINGLE_READ, pBuffer2, NULL, 128, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle2, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait2 failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	/*	Unlink the PIO-PIO Case there is a "short" Latency in input on the
		DIO so the DIO "may" read the "last" value we wrote on the PIO
		i.e. 0, 1, 2, 3 will arrive as 0, 2, 4, ...

		In fact it does read the last value EXCEPT for that as the PIO
		outputs its last value (255) the Handler completes that I/O which
		takes significantly longer and in practice long enough so that
		it's longer than the input Latency on the DIO (which is present 
		but considerably shorted than the 2.4ms output latency!)
	*/
	{
		int			i;
		BOOL		Errors = FALSE;
		BCT_BYTE	ValOut;
		BCT_WORD    ValIn;
		for(i=0; i<64; i++) {
			ValOut = pBuffer1->Buffer[i];
			ValIn  = (BCT_WORD) pwBuf2[i];
			if(ValOut != ValIn) {
				printf("Pacer Error:Buffer1[%d] = %#2x, Buffer2[%d]=%#4x\n", 
				i, ValOut, i, ValIn);
				if((ValOut==254) && (ValIn == 255)) {
					printf("Due to RLY input latencies, this is quite possible, so it is not an error\n");
				}
				else Errors = TRUE;
			}
		}
		if(!Errors) printf("Paced Single Block Read and Write successfull\n");
	}

	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}
void TestPacerRLYdblbuffRead()
{
	int i;
	BCT_WORD * pinBuf2;
	BCT_WORD * pinBuf1;
	PBCT_BUFFER pinBuffer1;
	PBCT_BUFFER pinBuffer2;

	Status	= BCTAllocate(&pinBuffer1, 2048);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAllocate1 failed with Status=%s\n", errtxt);
		return;
	}
	Status	= BCTAllocate(&pinBuffer2, 2048);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAllocate2 failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTGetBoardId(&nBoardId, PCI_RLY, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Double Buffering 128 out on RLY port and in on RLY opto's\n");

	//	Init the relay board
	Status = BCTInitPCIRelay(&nBoardId, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPCIRelay failed with Status=%s\n", errtxt);
		return;
	}
	
	Status = BCTOpen(&nHandle, &nBoardId, BCT_RLY, 0, BCT_RLY_RLY_OUT);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_RLY, 0, BCT_RLY_OPTO_IN);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}
	
	pinBuf1	= (WORD *)pinBuffer1->Buffer;
	pinBuf2	= (WORD *)pinBuffer2->Buffer;

	for(i=0; i<64; i++) {
		pBuffer1->Buffer[i] = i;
		pBuffer2->Buffer[i] = 64 + i;
		pinBuf1[i] = 0;
		pinBuf2[i] = 0;
	}

	pBuffer1->Sema = 0;
	pBuffer2->Sema = 0;
	pinBuffer1->Sema = 0;
	pinBuffer2->Sema = 0;

	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_DOUBLE_BUFFER_WRITE, pBuffer1, pBuffer2, 64, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) 
	{
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	Status = BCTAddPacerBlockIo(&nHandle2, &nBoardId, BLOCK_DOUBLE_BUFFER_READ, pinBuffer1, pinBuffer2, 128, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(pBuffer1->Sema == 0) {Sleep(10);}
	while(pBuffer2->Sema == 0) {Sleep(10);}
	while(pinBuffer1->Sema == 0) {Sleep(10);}
	while(pinBuffer2->Sema == 0) {Sleep(10);}

	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	/*	Unlink the PIO-PIO Case there is a "short" Latency in input on the
		DIO so the DIO "may" read the "last" value we wrote on the PIO
		i.e. 0, 1, 2, 3 will arrive as 0, 2, 4, ...

		In fact it does read the last value EXCEPT for that as the PIO
		outputs its last value (255) the Handler completes that I/O which
		takes significantly longer and in practice long enough so that
		it's longer than the input Latency on the DIO (which is present 
		but considerably shorted than the 2.4ms output latency!)
	*/
	{
		int			i;
		BOOL		Errors = FALSE;
		BCT_BYTE	ValOut;
		BCT_WORD    ValIn;
		for(i=0; i<64; i++) 
		{
			ValOut = pBuffer1->Buffer[i];
			ValIn  = (BCT_WORD) pinBuf1[i];
			if(ValOut != ValIn) {
				printf("Pacer Error:Buffer out 1[%d] = %#0.2x, Buffer in 1[%d]=%#0.4x\n", 
				i, ValOut, i, ValIn);
				if((ValOut==254) && (ValIn == 255)) {
					printf("Due to RLY input latencies, this is quite possible, so it is not an error\n");
				}
				else Errors = TRUE;
			}
		}

		for(i=0; i<64; i++) 
		{
			ValOut = pBuffer2->Buffer[i];
			ValIn  = (BCT_WORD) pinBuf2[i];
			if(ValOut != ValIn) {
				printf("Pacer Error:Buffer out 2[%d] = %#0.2x, Buffer in 2[%d]=%#0.4x\n", 
				i, ValOut, i, ValIn);
				if((ValOut==254) && (ValIn == 255)) {
					printf("Due to RLY input latencies, this is quite possible, so it is not an error\n");
				}
				else Errors = TRUE;
			}
		}
		if(!Errors) printf("Paced Single Block Read and Write successfull\n");
	}

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}
void TestPacerDIO2SingleRead()
{
	BCT_WORD *pwBuf1, *pwBuf2;
	int i;
	BOOL		Errors = FALSE;
	BCT_WORD	wValIn, wValOut;

	Status = BCTGetBoardId(&nBoardId, PCI_DIO, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTGetBoardId(&nBoardId2, PCI_DIO, 1);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}
	printf("Single Block Pacing 256 out on DIO 0-C 128 in on DIO 1-C\n");

	Status = BCTInitPCIDio(&nBoardId, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitIsoDigModes 0 failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPCIDio(&nBoardId2, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitIsoDigModes 1 failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_ISO);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() 0 failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId2, BCT_ISODIG, 0, BCT_PORT_ISO);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() 1 failed with Status=%s\n", errtxt);
		return;
	}

	//	We need 16-bit pointers!
	pwBuf1	= (WORD *)pBuffer1->Buffer;
	pwBuf2	= (WORD *)pBuffer2->Buffer;
	{
		int i;
		for(i=0; i<256; i++) {
			pBuffer2->Buffer[i] = 42;	// This fix's a wierd compiler bug, it serves no other purpose
			pwBuf1[i] = i;
			pwBuf2[i] = 42;
		}
	}

	//	Note that as we are talking words the byte count is twice the size!
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_SINGLE_WRITE, pBuffer1, NULL, 256<<1, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	Status = BCTAddPacerBlockIo(&nHandle2, &nBoardId, BLOCK_SINGLE_READ, pBuffer2, NULL, 128<<1, 1);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle2, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait2 failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	/*	Unlink the PIO-PIO Case there is a "short" Latency in input on the
		DIO so the DIO "may" read the "last" value we wrote on the PIO
		i.e. 0, 1, 2, 3 will arrive as 0, 2, 4, ...

		In fact it does read the last value EXCEPT for that as the PIO
		outputs its last value (255) the Handler completes that I/O which
		takes significantly longer and in practice long enough so that
		it's longer than the input Latency on the DIO (which is present 
		but considerably shorted than the 2.4ms output latency!)
	*/

		for(i=0; i<128; i++)
		{
			wValIn  = pwBuf2[i];
			wValOut = pwBuf1[i*2];
			if(wValOut != wValIn)
			{
				printf("Pacer Error:Buffer1[%d]=%d, Buffer2[%d]=%d\n", 
						(i*2), wValOut, i, wValIn);
				if((wValOut==254) && (wValIn == 255))
				{
					printf("Due to DIO input latencies, this is quite possible, so it is not an error\n");
				}
				else Errors = TRUE;
			}
		}
		if(!Errors) printf("Paced Single Block Read and Write successfull\n");

	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacer1()
{
	printf("Single Block Pacing 256 out on a 128 in on B\n");
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the 8255 in Mode 0, Port A out, Port B input
	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, OUTPUT, INPUT, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen(BCT_8255_0, BCT_PORT_A) failed with Status=%s\n", errtxt);
		return;
	}

	{
		int i;
		for(i=0; i<512; i++) {
			pBuffer1->Buffer[i] = i;
			pBuffer2->Buffer[i] = ~i;
		}
	}
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_SINGLE_WRITE, pBuffer1, NULL, 256, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	Status = BCTAddPacerBlockIo(&nHandle2, &nBoardId, BLOCK_SINGLE_READ, pBuffer2, NULL, 128, 1);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) 
	{
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle2, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait2 failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Notes that since we skip 1 pacer for the read it will have alternate
	//	values from the source, starting at the 2nd value sent (1st was skipped)
	{
		int		i;
		BOOL	Errors = FALSE;
		for(i=0; i<128; i++) {
			if(pBuffer1->Buffer[(i*2)+1] != pBuffer2->Buffer[i]) 
			{
				printf("Pacer Error:Buffer1[%d] = %d, Buffer2[%d]=%d\n", 
				(i*2)+1, pBuffer1->Buffer[(i*2)+1], i, pBuffer2->Buffer[i]);
				Errors = TRUE;
			}
		}
		if(!Errors) printf("Paced Single Block Read and Write successfull\n");
	}

	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacer2()
{
	printf("Single Block Pacing 256 out on a 128 in on B\n");
	Status = BCTGetBoardId(&nBoardId, PCI_ADC, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the 8255 in Mode 0, Port A out, Port B input
	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, OUTPUT, INPUT, ININ);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen(BCT_8255_0, BCT_PORT_A) failed with Status=%s\n", errtxt);
		return;
	}

	{
		int i;
		for(i=0; i<512; i++) {
			pBuffer1->Buffer[i] = i;
			pBuffer2->Buffer[i] = ~i;
		}
	}
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_SINGLE_WRITE, pBuffer1, NULL, 256, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	Status = BCTAddPacerBlockIo(&nHandle2, &nBoardId, BLOCK_SINGLE_READ, pBuffer2, NULL, 128, 1);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle2, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait2 failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Notes that since we skip 1 pacer for the read it will have alternate
	//	values from the source, starting at the 2nd value sent (1st was skipped)
	{
		int		i;
		BOOL	Errors = FALSE;
		for(i=0; i<128; i++) {
			if(pBuffer1->Buffer[(i*2)+1] != pBuffer2->Buffer[i]) {
				printf("Pacer Error:Buffer1[%d] = %d, Buffer2[%d]=%d\n", 
				(i*2)+1, pBuffer1->Buffer[(i*2)+1], i, pBuffer2->Buffer[i]);
				Errors = TRUE;
			}
		}
		if(!Errors) printf("Paced Single Block Read and Write successfull\n");
	}

	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopAdc8255(BCT_WORD Port)
{
	Status = BCTGetBoardId(&nBoardId, PCI_ADC, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	if(Port == BCT_PORT_A) {
		printf("ADC Looping in on PortA, Pacing Out on B, hit any key to stop\n");
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, OUTPUT, ININ);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes1 failed with Status=%s\n", errtxt);
			return;
		}
	}
	else if(Port == BCT_PORT_B) {
		printf("ADC Looping in on PortB, Pacing Out on C, hit any key to stop\n");
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, INPUT, OUTOUT);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes1 failed with Status=%s\n", errtxt);
			return;
		}
	}
	else if(Port == BCT_PORT_C) {
		printf("ADC Looping in on PortC, Pacing Out on B, hit any key to stop\n");
		Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, OUTPUT, ININ);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInit8255Modes1 failed with Status=%s\n", errtxt);
			return;
		}
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, Port);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;	
	}

	while(!_kbhit()) {
		Status = BCTReadPort(&nHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read %#03x  \r", bValIn);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopPio0A()
{
	//	Note that we will also program B for output
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the 8255 for 1 in Mode 0, Port A Input, B Output
	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, OUTPUT, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes1 failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Digital Input On 8255_0 Port A, hit any key to stop\n\n");
	while(!_kbhit()) {
		Status = BCTReadPort(&nHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read %#03x  \r", bValIn);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopPio0B()
{
	//	Note that we will also program A for output
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Init the 8255 for 1 in Mode 0, Port A Output, B Input
	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, OUTPUT, INPUT, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes1 failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Digital Input On 8255_0 Port B, hit any key to stop\n\n");
	while(!_kbhit()) {
		Status = BCTReadPort(&nHandle, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read %#03x  \r", bValIn);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerDIODblBufWrite(BCT_WORD Port)
{
	int i;

	printf("Double Buffered Pacing out on DIO %d, hit any key to stop!\n", Port);
	Status = BCTGetBoardId(&nBoardId, PCI_DIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Set Port to output
	if(Port == BCT_PORT_A) {
		Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, OUTPUT, NOCARE, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, NOCARE, OUTPUT, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, Port);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	//	We will send 32 from each buffer (making 64 the pair)
	for(i=0; i<32; i++) {
		pBuffer1->Buffer[i] = i;
		pBuffer2->Buffer[i] = i+32;
	}

	pBuffer1->Sema	= 0;		// Clear the sema
	pBuffer2->Sema	= 0;		// Clear the sema

	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_DOUBLE_BUFFER_WRITE, pBuffer1, pBuffer2, 32, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 100 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 100);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) {
		while(pBuffer1->Sema == 0) {
			printf("Waiting for Buffer 1 to be sent\n");
		}
		printf("Got Buffer1, filling\n");
		for(i=0; i<32; i++) {
			pBuffer1->Buffer[i] +=64;
		}
		pBuffer1->Sema	= 0;	// Signal Done

		while(pBuffer2->Sema == 0) {
			printf("Waiting for Buffer 2 to be sent\n");
		}
		printf("Got Buffer2, filling\n");
		for(i=0; i<32; i++) {
			pBuffer2->Buffer[i] +=64;
		}
		pBuffer2->Sema	= 0;	// Signal Done
	}
	
	_getch();

	if(Port == BCT_PORT_A) {
		//	This should dump the unwanted repeated activity
		printf("Hit any key to Close handle (should dump pacer)\n"); _getch();
		Status = BCTClose(&nHandle);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTClose failed with Status=%s\n", errtxt);
			return;
		}
	
		printf("Hit any key to stop the pacer\n"); _getch();
		Status = BCTStopPacer(&nBoardId);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTStopPacer failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		//	This should dump the unwanted repeated activity
		printf("Hit any key to stop the pacer\n"); _getch();
		Status = BCTStopPacer(&nBoardId);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTStopPacer failed with Status=%s\n", errtxt);
			return;
		}

		printf("Hit any key to Close handle (should dump pacer)\n"); _getch();
		Status = BCTClose(&nHandle);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTClose failed with Status=%s\n", errtxt);
			return;
		}
	}
	printf("Hit any key to release the board\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerDIO2DblBufWrite()
{
	int i;
	BCT_WORD *pwBuf1, *pwBuf2;

	printf("Double Buffered Pacing out on DIO, hit any key to stop!\n");
	Status = BCTGetBoardId(&nBoardId, PCI_DIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPCIDio(&nBoardId, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitIsoDigModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_ISO);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	//	We will send 32 from each buffer (making 64 the pair)
	pwBuf1	= (WORD *)pBuffer1->Buffer;
	pwBuf2	= (WORD *)pBuffer2->Buffer;
	for(i=0; i<32; i++) {
		pwBuf1[i] = i;
		pwBuf2[i] = i+32;
	}

	pBuffer1->Sema	= 0;		// Clear the sema
	pBuffer2->Sema	= 0;		// Clear the sema

	//	Warning twice as many bytes for a 16-bit port!
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_DOUBLE_BUFFER_WRITE, pBuffer1, pBuffer2, 32<<1, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 100 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 100);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) {
		while(pBuffer1->Sema == 0) {
			printf("Waiting for Buffer 1 to be sent\n");
		}
		printf("Got Buffer1, filling\n");
		for(i=0; i<32; i++) {
			pwBuf1[i] +=64;
		}
		pBuffer1->Sema	= 0;	// Signal Done

		while(pBuffer2->Sema == 0) {
			printf("Waiting for Buffer 2 to be sent\n");
		}
		printf("Got Buffer2, filling\n");
		for(i=0; i<32; i++) {
			pwBuf2[i] +=64;
		}
		pBuffer2->Sema	= 0;	// Signal Done
	}
	
	_getch();

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}
	
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerDblWritePio0A()
{
	int i;
	PBCT_BUFFER readbuf1;
	PBCT_BUFFER readbuf2;
	int flag = 1;

	Status	= BCTAllocate(&readbuf1, 2048);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAllocate1 failed with Status=%s\n", errtxt);
		return;
	}
	Status	= BCTAllocate(&readbuf2, 2048);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAllocate2 failed with Status=%s\n", errtxt);
		return;
	}

	for(i=0; i<64; i++) 
	{
		readbuf1->Buffer[i]=0;
		readbuf2->Buffer[i]=0;
	}

	printf("Double Buffered Pacing out on PIO A\n");
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, OUTPUT, INPUT, NOCARE);
	if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	//	We will send 32 from each buffer (making 64 the pair)
	for(i=0; i<32; i++) {
		pBuffer1->Buffer[i] = i;
		pBuffer2->Buffer[i] = i+32;
	}

	pBuffer1->Sema	= 0;		// Clear the sema
	pBuffer2->Sema	= 0;		// Clear the sema
	readbuf1->Sema  = 0;
	readbuf2->Sema  = 0;

	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_DOUBLE_BUFFER_WRITE, pBuffer1, pBuffer2, 32, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	Status = BCTAddPacerBlockIo(&nHandle2, &nBoardId, BLOCK_DOUBLE_BUFFER_READ, readbuf1, readbuf2, 32, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(pBuffer1->Sema == 0) 
	{
		printf("Waiting for Buffer 1 to be sent\n");
	}
	printf("Got Buffer1, filling\n");
	pBuffer1->Sema	= 0;	// Signal Done

	while(pBuffer2->Sema == 0) 
	{
		printf("Waiting for Buffer 2 to be sent\n");
	}
	printf("Got Buffer2, filling\n");
	pBuffer2->Sema	= 0;	// Signal Done
	
	printf("Double Buffered Pacing in on PIO B\n");

	while(readbuf1->Sema == 0) 
	{
		printf("Waiting for Buffer 1 to be read\n");
	}
	printf("Got Buffer1\n");
	readbuf1->Sema = 0;

	while(readbuf2->Sema == 0) 
	{
		printf("Waiting for Buffer 2 to be read\n");
	}
	printf("Got Buffer2\n");
	readbuf1->Sema = 0;
	

	

	for(i = 0;i<32;i++)
	{
		if(pBuffer1->Buffer[i] != readbuf1->Buffer[i] || pBuffer2->Buffer[i] != readbuf2->Buffer[i])
		{
			printf("Data didnt match!\n");
			printf("write buffer 1 char%d = %d\n",i,pBuffer1->Buffer[i]);
			printf("read buffer 1 char%d = %d\n",i,readbuf1->Buffer[i]);
			printf("write buffer 2 char%d = %d\n",i,pBuffer2->Buffer[i]);
			printf("read buffer 2 char%d = %d\n",i,readbuf2->Buffer[i]);
			flag = 0;
			break;
		}
	}
	if(flag == 1)
	{
		printf("Data written and read successfully\n");
	}

	_getch();

	//	This should dump the unwanted repeated activity
	printf("Hit any key to Close handle (should dump pacer)\n"); _getch();
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to stop the pacer\n"); _getch();
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to release the board\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerDblWriteAdc8255(BCT_WORD Port)
{
	int i;

	printf("Double Buffered Pacing out on ADC 8255 %d, hit any key to stop!\n", Port);
	Status = BCTGetBoardId(&nBoardId, PCI_ADC, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, Port);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	//	We will send 32 from each buffer (making 64 the pair)
	for(i=0; i<32; i++) {
		pBuffer1->Buffer[i] = i;
		pBuffer2->Buffer[i] = i+32;
	}

	pBuffer1->Sema	= 0;		// Clear the sema
	pBuffer2->Sema	= 0;		// Clear the sema

	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_DOUBLE_BUFFER_WRITE, pBuffer1, pBuffer2, 32, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 100 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 100);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) {
		while(pBuffer1->Sema == 0) {
			printf("Waiting for Buffer 1 to be sent\n");
		}
		printf("Got Buffer1, filling\n");
		for(i=0; i<32; i++) {
			pBuffer1->Buffer[i] +=64;
		}
		pBuffer1->Sema	= 0;	// Signal Done

		while(pBuffer2->Sema == 0) {
			printf("Waiting for Buffer 2 to be sent\n");
		}
		printf("Got Buffer2, filling\n");
		for(i=0; i<32; i++) {
			pBuffer2->Buffer[i] +=64;
		}
		pBuffer2->Sema	= 0;	// Signal Done
	}
	
	_getch();

	//	This should dump the unwanted repeated activity
	printf("Hit any key to Close handle (should dump pacer)\n"); _getch();
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to stop the pacer\n"); _getch();
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to release the board\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}



void TestPacerDIODblBufRead(BCT_WORD Port)
{
	printf("Double Buffered Pacing in on DIO %d, hit any key to stop!\n", Port);
	Status = BCTGetBoardId(&nBoardId, PCI_DIO, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	if(Port == BCT_PORT_A) {
		Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, INPUT, NOCARE, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, NOCARE, INPUT, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, Port);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	{
		int i;
		for(i=0; i<64; i++) {
			pBuffer1->Buffer[i]=0;
			pBuffer2->Buffer[i]=0;
		}
	}
	pBuffer1->Sema	= 0;		// Clear the sema
	pBuffer2->Sema	= 0;		// Clear the sema

	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_DOUBLE_BUFFER_READ, pBuffer1, pBuffer2, 32, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 100 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 100);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) {
		while(pBuffer1->Sema == 0) {
			printf("Waiting for Buffer 1 to be read, Buffer1[0]=%#x, Buffer2[0]=%#x\n",
					UnTwist(pBuffer1->Buffer[0]), UnTwist(pBuffer2->Buffer[0]));
		}
		pBuffer1->Sema	= 0;	// Signal Done

		while(pBuffer2->Sema == 0) {
			printf("Waiting for Buffer 2 to be read, Buffer1[0]=%#x, Buffer2[0]=%#x\n",
					UnTwist(pBuffer1->Buffer[0]), UnTwist(pBuffer2->Buffer[0]));
		}
		pBuffer2->Sema	= 0;	// Signal Done
	}
	
	_getch();

	//	This should dump the unwanted repeated activity
	printf("Hit any key to Close handle (should dump pacer)\n"); _getch();
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to stop the pacer\n"); _getch();
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to release the board\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerDIO2DblBufRead()
{
	BCT_WORD *pwBuf1, *pwBuf2;

	printf("Double Buffered Pacing in on DIO, hit any key to stop!\n");
	Status = BCTGetBoardId(&nBoardId, PCI_DIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPCIDio(&nBoardId, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitIsoDigModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_ISO);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}
	pwBuf1	= (WORD *)pBuffer1->Buffer;
	pwBuf2	= (WORD *)pBuffer2->Buffer;

	{
		int i;
		for(i=0; i<64; i++) {
			pwBuf1[i]=0;
			pwBuf2[i]=0;
		}
	}
	pBuffer1->Sema	= 0;		// Clear the sema
	pBuffer2->Sema	= 0;		// Clear the sema

	/*	Warning twice as many bytes for word transfers */
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_DOUBLE_BUFFER_READ, pBuffer1, pBuffer2, 64<<1, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 100 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 100);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) {
		while(pBuffer1->Sema == 0) {
			printf("Waiting for Buffer 1 to be read, Buffer1[0]=%#x, Buffer2[0]=%#x\n",
					pwBuf1[0], pwBuf2[0]);
		}
		pBuffer1->Sema	= 0;	// Signal Done

		while(pBuffer2->Sema == 0) {
			printf("Waiting for Buffer 2 to be read, Buffer1[0]=%#x, Buffer2[0]=%#x\n",
					pwBuf1[0], pwBuf2[0]);
		}
		pBuffer2->Sema	= 0;	// Signal Done
	}
	
	_getch();

	//	This should dump the unwanted repeated activity
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerDblReadPio0B()
{
	printf("Double Buffered Pacing in on PIO B, hit any key to stop!\n");
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}


		
	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, NOCARE, INPUT, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);		
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	pBuffer1->Sema	= 0;		// Clear the sema
	pBuffer2->Sema	= 0;		// Clear the sema

	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_DOUBLE_BUFFER_READ, pBuffer1, pBuffer2, 32, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 100 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 100);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) {
		while(pBuffer1->Sema == 0) {
			printf("Waiting for Buffer 1 to be read, Buffer1[0]=%#x, Buffer2[0]=%#x\n",
					pBuffer1->Buffer[0], pBuffer2->Buffer[0]);
		}
		pBuffer1->Sema	= 0;	// Signal Done

		while(pBuffer2->Sema == 0) {
			printf("Waiting for Buffer 2 to be read, Buffer1[0]=%#x, Buffer2[0]=%#x\n",
					pBuffer1->Buffer[0], pBuffer2->Buffer[0]);
		}
		pBuffer2->Sema	= 0;	// Signal Done
	}
	
	_getch();

	//	This should dump the unwanted repeated activity
	printf("Hit any key to Close handle (should dump pacer)\n"); _getch();
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to stop the pacer\n"); _getch();
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to release the board\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerDblWritePio0B()
{
	int i;

	printf("Double Buffered Pacing out on PIO B, hit any key to stop!\n");
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	//	The 8255 B was set to output by the Loop on A routine!
//	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, OUTPUT, INPUT, NOCARE);
//	if(Status != BCT_OK) {
//		BCTErr2Txt(Status, errtxt);
//		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
//		return;
//	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	//	We will send 60 from each buffer (making 120 the pair)
	for(i=0; i<60; i++) {
		pBuffer1->Buffer[i] = i;
		pBuffer2->Buffer[i] = i+120;
	}

	pBuffer1->Sema	= 0;		// Clear the sema
	pBuffer2->Sema	= 0;		// Clear the sema

	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_DOUBLE_BUFFER_WRITE, pBuffer1, pBuffer2, 60, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) {
		while(pBuffer1->Sema == 0) {
			printf("Waiting for Buffer 1 to be sent\n");
		}
		printf("Got Buffer1, filling\n");
		for(i=0; i<60; i++) {
			pBuffer1->Buffer[i] +=120;
		}
		pBuffer1->Sema	= 0;	// Signal Done

		while(pBuffer2->Sema == 0) {
			printf("Waiting for Buffer 2 to be sent\n");
		}
		printf("Got Buffer2, filling\n");
		for(i=0; i<60; i++) {
			pBuffer2->Buffer[i] +=120;
		}
		pBuffer2->Sema	= 0;	// Signal Done
	}
	
	_getch();

	//	This should dump the unwanted repeated activity
	printf("Hit any key to Close handle (should dump pacer)\n"); _getch();
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to stop the pacer\n"); _getch();
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to release the board\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerDIORepeatedWrite(BCT_WORD Port)
{
	printf("Repeated Paced 256 out on DIO %d\n", Port);
	Status = BCTGetBoardId(&nBoardId, PCI_DIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Set Port to output
	if(Port == BCT_PORT_A) {
		Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, OUTPUT, NOCARE, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}
	else {
		Status = BCTInitIsoDigModes(&nBoardId, 0, MODE_0, NOCARE, OUTPUT, NOCARE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}
	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, Port);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	{
		int i;
		for(i=0; i<256; i++) {
			pBuffer1->Buffer[i] = i;
		}
	}
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_REPEATED_WRITE, pBuffer1, NULL, 256, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Wait for the Pacer function to finish
	printf("Hit any key to finish\n"); _getch();

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerDIO2RepeatedWrite()
{
	WORD *pwBuf1;

	printf("Repeated Paced 256 out on DIO\n");
	Status = BCTGetBoardId(&nBoardId, PCI_DIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	//	Set Port to output
	Status = BCTInitPCIDio(&nBoardId, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitIsoDigModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_ISODIG, 0, BCT_PORT_ISO);
	if(Status != BCT_OK)
	{
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	//	We need 16-bit pointers!
	pwBuf1	= (WORD *)pBuffer1->Buffer;
	{
		int i;
		for(i=0; i<256; i++)
		{
			pwBuf1[i] = i | ((~i<<8)&0xff00);
		}
	}
	/*	Warning send twice as many bytes for 16-bit ports */
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_REPEATED_WRITE, pBuffer1, NULL, 256<<1, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Wait for the Pacer function to finish
	printf("Hit any key to finish\n"); _getch();

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerRepBlockPio0A()
{
	printf("Repeated Block Pacing 256 out on PIO A, hit any key to stop!\n");
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, OUTPUT, INPUT, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	{
		int i;
		for(i=0; i<256; i++) 
		{
			pBuffer1->Buffer[i] = i;
		}
	}

	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_REPEATED_WRITE, pBuffer1, NULL, 256, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	printf("Started pacer\n");
	while(!_kbhit()) 
	{
		Status = BCTReadPort(&nHandle2, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle2, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) 
		{
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read Port PI0 B: %#03x  \r", bValIn);
	}
	_getch();

	//	This should dump the unwanted repeated activity
	printf("Hit any key to Close handle (should dump pacer)\n"); _getch();
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to stop the pacer\n"); _getch();
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to release the board\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerRepBlockPio0B()
{
	printf("Repeated Block Pacing 256 out on PIO B, hit any key to stop!\n");
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}


	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, OUTPUT, NOCARE);
	if(Status != BCT_OK) 
	{
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_B);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

		Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	{
		int i;
		for(i=0; i<256; i++) {
			pBuffer1->Buffer[i] = i;
		}
	}
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_REPEATED_WRITE, pBuffer1, NULL, 256, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) 
	{
		Status = BCTReadPort(&nHandle2, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle2, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read Port PI0 A: %#03x  \r", bValIn);
	}
	_getch();

	//	This should dump the unwanted repeated activity
	printf("hit a key to stop pacer\n"); _getch();
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("hit a key to close\n"); _getch();
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	printf("hit a key to release\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerRepBlockPio0C()
{
	printf("Repeated Block Pacing 256 out on PIO C, hit any key to stop!\n");
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, NOCARE, NOCARE, OUTOUT);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, INPUT, NOCARE, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
		return;
	}
	

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_C);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 1, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	{
		int i;
		for(i=0; i<256; i++) {
			pBuffer1->Buffer[i] = i;
		}
	}
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_REPEATED_WRITE, pBuffer1, NULL, 256, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) 
	{
		Status = BCTReadPort(&nHandle2, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle2, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) 
		{
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read Port PI1 A: %#03x  \r", bValIn);
	}
	_getch();

	//	This should dump the unwanted repeated activity
	printf("hit a key to stop pacer\n"); _getch();
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("hit a key to close\n"); _getch();
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	printf("hit a key to release\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerRepBlockPio1A()
{
	printf("Repeated Block Pacing 256 out on PIO 1A, hit any key to stop!\n");
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, OUTPUT, NOCARE, NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, NOCARE, NOCARE, ININ);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 1, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_8255, 0, BCT_PORT_C);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	{
		int i;
		for(i=0; i<256; i++) {
			pBuffer1->Buffer[i] = i;
		}
	}
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_REPEATED_WRITE, pBuffer1, NULL, 256, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) 
	{
		Status = BCTReadPort(&nHandle2, &bValIn);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle2, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) 
		{
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPort failed with Status=%s\n", errtxt);
			break;
		}
		printf("Read Port PI0 C: %#03x  \r", bValIn);
	}
	_getch();

	//	This should dump the unwanted repeated activity
	printf("hit a key to stop pacer\n"); _getch();
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("hit a key to close\n"); _getch();
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	printf("hit a key to release\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerRepBlockAdc8255(BCT_WORD Port)
{
	printf("Repeated Block Pacing 256 out on ADC 8255 port %d, hit any key to stop!\n", Port);
	Status = BCTGetBoardId(&nBoardId, PCI_ADC, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, Port);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	{
		int i;
		for(i=0; i<256; i++) {
			pBuffer1->Buffer[i] = i;
		}
	}
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_REPEATED_WRITE, pBuffer1, NULL, 256, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) {
	}
	_getch();

	//	This should dump the unwanted repeated activity
	printf("hit a key to stop pacer\n"); _getch();
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("hit a key to close\n"); _getch();
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	printf("hit a key to release\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestBits()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("Test Bits 1	- Bit Output PIO 8255_0C (to PIO 8255_1A)\n");
		printf("Test Bits 2	- PIO 8255_1A Continuous Input\n");
		printf("Test Bits 3	- Bit Output PIO 8255_1C (to PIO 8255_1B)\n");
		printf("Test Bits 4	- PIO 8255_1B Continuous Input\n");
		printf("Test Bits 5	- Bit Output ADC 8255_0C (to ADC 8255_0B)\n");
		printf("Test Bits 6	- ADC 8255_0B Continuous Input\n");
		printf("Test Bits 7	- Bit Output to Relay card\n");
		printf("         99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:	PioBits(BCT_8255, 0);	break;
			case 2:	LoopPio1A(OUTOUT);		break;
			case 3:	PioBits(BCT_8255, 1);	break;
			case 4:	LoopPio1B();			break;
			case 5:	ADCBits(BCT_8255, 0);	break;
			case 6:	LoopAdc0B();			break;
			case 7:	RelayBits();			break;
			case 99: Done = TRUE;			break;
		}
	}
}

void DIO_PIO_RLYInputs()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("DIO_PIO_RLY 1  - Loop Input on PIO 0-0 AB\n");
		printf("DIO_PIO_RLY 2  - Loop Input on DIO 0A\n");
		printf("DIO_PIO_RLY 3  - Loop Input on DIO 0B\n");
		printf("DIO_PIO_RLY 4  - Loop Input on DIO 0C\n");
		printf("DIO_PIO_RLY 5  - Loop Input on DIO 0C using BCTInitPCIDio\n");
		printf("DIO_PIO_RLY 6  - Loop Input on RLY using BCTInitPCIRelay\n");
		printf("       99 - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:		LoopPio00AB();			break;
			case 2:		LoopDio0A();			break;
			case 3:		LoopDio0B();			break;
			case 4:		LoopDio0C();			break;
			case 5:		LoopDio0CX(0, FALSE);	break;
			case 6:		LoopRLY0CX(0, FALSE);	break;
			case 99: Done = TRUE;			break;
		}
	}
}

void DIO_PIO_RLYOutputs()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("DIO_PIO_RLY 1  - Bit Output on DIO 0A\n");
		printf("DIO_PIO_RLY 2  - Bit Output on DIO 0B\n");
		printf("DIO_PIO_RLY 3  - Bit Output on DIO 0C\n");
		printf("DIO_PIO_RLY 4  - Byte Output on DIO 0A\n");
		printf("DIO_PIO_RLY 5  - Byte Output on DIO 0B\n");
		printf("DIO_PIO_RLY 6  - Byte Output on DIO 0C\n");
		printf("DIO_PIO_RLY 7  - Byte Output on PIO 1-1 A\n");
		printf("DIO_PIO_RLY 8  - Byte Output on PIO 1-1 B\n");
		printf("DIO_PIO_RLY 9  - Byte Output on PIO 0-1 A\n");
		printf("DIO_PIO_RLY 10 - Byte Output on PIO 0-1 B\n");
		printf("DIO_PIO_RLY 11 - Byte Output on RLY\n");
		printf("       99 - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:		DioBitsA();				break;
			case 2:		DioBitsB();				break;
			case 3:		DioBitsC();				break;
			case 4:		DioOutA();				break;
			case 5:		DioOutB();				break;
			case 6:		DioOutC();				break;
			case 7:		OutPio11(1,BCT_PORT_A);	break;
			case 8:		OutPio11(1,BCT_PORT_B);	break;
			case 9:		OutPio11(0,BCT_PORT_A);	break;
			case 10:	OutPio11(0,BCT_PORT_B);	break;
			case 11:	RLYOutA();				break;
			case 99:	Done = TRUE;			break;
		}
	}
}

void AdcLoopBacks()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("ADC Loopback 1	- ADC 8255_0A - 8255_0B\n");
		printf("ADC Loopback 2	- ADC 8255_0A - 8255_0B, reverse\n");
		printf("ADC Loopback 3	- ADC 8255_0B - 8255_0C\n");
		printf("ADC Loopback 4	- ADC 8255_0B - 8255_0C, reverse\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:	TestAdc0A_0B(TRUE);		break;
			case 2:	TestAdc0A_0B(FALSE);	break;
			case 3:	TestAdc0B_0C(TRUE);		break;
			case 4:	TestAdc0B_0C(FALSE);	break;
			case 99: Done = TRUE;			break;
		}
	}
}

void ReadPortTests()
{
	BCT_WORD	Val;
	BCT_BYTE	Gain, Mode, Chan;
	BOOL		Done;
	char		DoWhat;

	Status = BCTGetBoardId(&nBoardId, PCI_ADC, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_AIN, 0, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Enter Channel ");
	scanf_s("%d", &Chan);
	
	Done = FALSE;
	while(!Done) {
		printf("Enter Gain (1, 10, 100, 1000) ");
		scanf_s("%d", &Val);
		switch(Val) {
			case 1:		Gain = PCIADC_AIN_GAIN_1; Done = TRUE; break;
			case 10:	Gain = PCIADC_AIN_GAIN_10; Done = TRUE; break;
			case 100:	Gain = PCIADC_AIN_GAIN_100; Done = TRUE; break;
			case 1000:	Gain = PCIADC_AIN_GAIN_1000; Done = TRUE; break;
			break;
		}
	}
	
	printf("Enter Y[es] to specify Single Ended, N[o] for Differential\n");
	DoWhat	= _getch();
	if((DoWhat == 'Y') || (DoWhat == 'y')) {
		printf("Single Ended\n");
		Mode	= PCIADC_AIN_MODE_SINGLE;
	}
	else {
		printf("Differential\n");
		Mode	= PCIADC_AIN_MODE_DIFFERENTIAL;
	}
	
	printf("Reading Input On Channel %d, hit any key to finish\n", Chan);
	while(!_kbhit()) {
		Status = BCTReadPortAin(&nHandle, Chan, Gain, Mode, &Val);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTReadPortAin failed with Status=%s\n", errtxt);
			break;
		}
		if(((Val & 0xf000)>>12) != Chan) {
			printf("Convert didn't get the chan we expected, got %d, expected %d, RawVal=%#x\n",
					(Val & 0xf000)>>12, Chan, Val);
			break;
		}
		printf("Val=%#x           \r", Val&0xfff);
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void AutocalAin()
{
	BCT_WORD	Val;
	BCT_BYTE	Gain;
	BOOL		Done;
	BCT_WORD	MeanZero, MeanFsd;

	Status = BCTGetBoardId(&nBoardId, PCI_ADC, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_AIN, 0, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	Done = FALSE;
	while(!Done) {
		printf("Enter Gain (1, 10, 100, 1000) ");
		scanf_s("%d", &Val);
		switch(Val) {
			case 1:		Gain = PCIADC_AIN_GAIN_1; Done = TRUE; break;
			case 10:	Gain = PCIADC_AIN_GAIN_10; Done = TRUE; break;
			case 100:	Gain = PCIADC_AIN_GAIN_100; Done = TRUE; break;
			case 1000:	Gain = PCIADC_AIN_GAIN_1000; Done = TRUE; break;
			break;
		}
	}
	
	Status = BCTAutoCalAin(&nHandle, Gain, &MeanZero, &MeanFsd);
	if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAutoCalAin failed with Status=%s\n", errtxt);
		return;
	}
	printf("MeanZero=%#x, Mean 90%% FSD=%#x\n", MeanZero, MeanFsd);
	printf("Hit any Key\n"); _getch();
	
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void ReadPortBlockTests()
{
	BCT_WORD	Val, Speed;
	BCT_BYTE	Gain, Mode, Chan;
	BOOL		Done;
	char		DoWhat;
	int			i;
	BCT_WORD	*pBuf;

	Status = BCTGetBoardId(&nBoardId, PCI_ADC, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTAcquireAPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAcquireAPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_AIN, 0, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Enter Channel ");
	scanf_s("%d", &Chan);
	
	printf("Enter Clock speed in uSecs ");
	scanf_s("%d", &Speed);
	
	Done = FALSE;
	while(!Done) {
		printf("Enter Gain (1, 10, 100, 1000) ");
		scanf_s("%d", &Val);
		switch(Val) {
			case 1:		Gain = PCIADC_AIN_GAIN_1; Done = TRUE; break;
			case 10:	Gain = PCIADC_AIN_GAIN_10; Done = TRUE; break;
			case 100:	Gain = PCIADC_AIN_GAIN_100; Done = TRUE; break;
			case 1000:	Gain = PCIADC_AIN_GAIN_1000; Done = TRUE; break;
			break;
		}
	}
	
	printf("Enter Y[es] to specify Single Ended, N[o] for Differential\n");
	DoWhat	= _getch();
	if((DoWhat == 'Y') || (DoWhat == 'y')) {
		printf("Single Ended\n");
		Mode	= PCIADC_AIN_MODE_SINGLE;
	}
	else {
		printf("Differential\n");
		Mode	= PCIADC_AIN_MODE_DIFFERENTIAL;
	}
	printf("Enter Y[es] to specify Single Channel, N[o] for Range of Channels\n");
	DoWhat	= _getch();
	if((DoWhat == 'Y') || (DoWhat == 'y')) {
		printf("Single Channel\n");
	}
	else {
		printf("Multiple Channels\n");
		Mode	|= PCIADC_AIN_MULTI_CHANNEL;
	}
	
	printf("Reading 1000 Samples from Channel %d\n", Chan);
	Status = BCTReadBlockAin(&nBoardId, &nHandle, Chan, Gain, Mode, 
							pBuffer1, 1000, Speed);
	if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReadBlockAin failed with Status=%s\n", errtxt);
		return;
	}

	pBuf	= (BCT_WORD *)pBuffer1->Buffer;
	for(i=0; i<10; i++) {
		printf("Sample[%d]=%#x\n", i, pBuf[i]);
	}
	printf("Hit any key to continue\n"); _getch();

	pBuf	= (BCT_WORD *)pBuffer1->Buffer;
	{
		int counts[16];
		int Total[16], Min[16], Max[16];
		int indx, val;

		for(i=0; i<16; i++) {
			counts[i]	= 0;
			Min[i]		= 0x1fff;
			Max[i]		= 0;
			Total[i]	= 0;
		}
		for(i=0; i<1000; i++) {
			indx	= pBuf[i]>>12;
			val		= pBuf[i]&0xfff;
			if(indx>15) printf("Index too big data[%d]=%#x\n", i, pBuf[i]);
			else counts[indx]++;

			Total[indx]	+= val;
			if(val<Min[indx]) Min[indx]=val;
			if(val>Max[indx]) Max[indx]=val;
		}
		printf("Counts=");
		for(i=0; i<15; i++) printf("%d, ", counts[i]);
		printf("\nMins=");
		for(i=0; i<15; i++) 
			if(Min[i] == 0x1fff)	printf("0, ");
			else					printf("%#x, ", Min[i]);
		printf("\nMaxs=");
		for(i=0; i<15; i++) printf("%#x, ", Max[i]);
		printf("\nAvgs=");
		for(i=0; i<15; i++) 
			if(counts[i]>0) printf("%#x, ", Total[i]/counts[i]);
			else printf("0, ");
		printf("\nPress any key to continue\n"); _getch();
	}
		
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseAPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseAPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void WritePortAout(BCT_WORD Chan)
{
	BCT_WORD	Val;
	char		DoVolts;

	Status = BCTGetBoardId(&nBoardId, PCI_ADC, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	printf("Enter Y[es] to specify Constant Voltage, N[o] for Constant Current\n");
	DoVolts	= _getch();
	if((DoVolts == 'Y') || (DoVolts == 'y')) {
		printf("Constant Voltage\n");
		Status = BCTInitAOutModes(&nBoardId, 0, BCT_AOUT_VOLTAGE, 
					BCT_AOUT_VOLTAGE, BCT_AOUT_VOLTAGE, BCT_AOUT_VOLTAGE);
	}
	else {
		printf("Constant Current\n");
		Status = BCTInitAOutModes(&nBoardId, 0, BCT_AOUT_CURRENT, 
					BCT_AOUT_CURRENT, BCT_AOUT_CURRENT, BCT_AOUT_CURRENT);
	}
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitAOutModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_AOUT, 0, Chan);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	printf("Starting Output On Channel %d\n\n", Chan);
	while(1) {
		printf("Enter value as a Hex Number, 99 to exit\n"); 
		scanf_s("%x", &Val);
		if(Val == 0x99) {
			break;
		}
		Status = BCTWritePort16(&nHandle, Val);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTWriteBit failed with Status=%s\n", errtxt);
			break;
		}
	}
	printf("\n");

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void WriteSBPortAout(BCT_WORD Chan)
{
	char		DoVolts;
	int			i, npoints;
	double		pi = 3.1415926535;
	double		step, val;
//	double		vals[1024];
	BCT_WORD	*pBuf;

	Status = BCTGetBoardId(&nBoardId, PCI_ADC, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Enter Y[es] to specify Constant Voltage, N[o] for Constant Current\n");
	DoVolts	= _getch();
	if((DoVolts == 'Y') || (DoVolts == 'y')) {
		printf("Constant Voltage\n");
		Status = BCTInitAOutModes(&nBoardId, 0, BCT_AOUT_VOLTAGE, 
					BCT_AOUT_VOLTAGE, BCT_AOUT_VOLTAGE, BCT_AOUT_VOLTAGE);
	}
	else {
		printf("Constant Current\n");
		Status = BCTInitAOutModes(&nBoardId, 0, BCT_AOUT_CURRENT, 
					BCT_AOUT_CURRENT, BCT_AOUT_CURRENT, BCT_AOUT_CURRENT);
	}
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitAOutModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_AOUT, 0, Chan);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	npoints		= 1000;
	step		= 2.0*pi/(npoints);	//	so we can join them together
	val			= 0.0;

	//	The buffer is 2KB long so there is space for 1024 16 bit vals
	pBuf		= (BCT_WORD *)pBuffer1->Buffer;

	for(i=0; i<npoints; i++) {
		*pBuf++		= (BCT_WORD)(((1+sin(val))/2.0)*0xfff);
//		vals[i] = val;
		val += step;
	}

//	printf("val[0]=%f, sin=%f, val[767]=%f, sin=%f, val[1023]=%f, sin=%f\n", 
//			vals[0], sin(vals[0]), vals[767], sin(vals[767]), vals[1023], sin(vals[1023]));
//	pBuf		= (BCT_WORD *)pBuffer1->Buffer;
//	printf("val[0]=%#x, val[511]=%#x, val[1023]=%#x\n", 
//			pBuf[0], pBuf[511], pBuf[1023]);

	printf("Sending a a single Sine Wave On Channel %d\n\n", Chan);

	//	twice as many bytes as points!
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_SINGLE_WRITE, pBuffer1, NULL, npoints*2, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals, so with 1000 points
	//	should take 10 seconds to display?
	Status = BCTStartPacer(&nBoardId, 10);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Wait for the Pacer function to finish
	Status = BCTWait(&nHandle, INFINITE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTWait failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void WriteRBPortAout2(BCT_WORD Chan, BCT_WORD Chan2)
{
	char		DoVolts;
	int			i, npoints;
	double		pi = 3.1415926535;
	double		step, val;
//	double		vals[1024];
	BCT_WORD	*pBuf, *pBuf1;

	Status = BCTGetBoardId(&nBoardId, PCI_ADC, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Enter Y[es] to specify Constant Voltage, N[o] for Constant Current\n");
	DoVolts	= _getch();
	if((DoVolts == 'Y') || (DoVolts == 'y')) {
		printf("Constant Voltage\n");
		Status = BCTInitAOutModes(&nBoardId, 0, BCT_AOUT_VOLTAGE, 
					BCT_AOUT_VOLTAGE, BCT_AOUT_VOLTAGE, BCT_AOUT_VOLTAGE);
	}
	else {
		printf("Constant Current\n");
		Status = BCTInitAOutModes(&nBoardId, 0, BCT_AOUT_CURRENT, 
					BCT_AOUT_CURRENT, BCT_AOUT_CURRENT, BCT_AOUT_CURRENT);
	}
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitAOutModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_AOUT, 0, Chan);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle2, &nBoardId, BCT_AOUT, 0, Chan2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen2 failed with Status=%s\n", errtxt);
		return;
	}

	npoints		= 1000;
	step		= 2.0*pi/(npoints);	//	so we can join them together
	val			= 0.0;

	//	The buffer is 2KB long so there is space for 1024 16 bit vals
	pBuf		= (BCT_WORD *)pBuffer1->Buffer;
	pBuf1		= (BCT_WORD *)pBuffer2->Buffer;

	for(i=0; i<npoints; i++)
	{
		*pBuf++		= (BCT_WORD)(((1+sin(val))/2.0)*0xfff);
		*pBuf1++	= (BCT_WORD)(((1+cos(val))/2.0)*0xfff);
		val += step;
	}

//	printf("val[0]=%f, sin=%f, val[511]=%f, sin=%f, val[1023]=%f, sin=%f\n", 
//			vals[0], sin(vals[0]), vals[511], sin(vals[511]), vals[1023], sin(vals[1023]));
//	pBuf		= (BCT_WORD *)pBuffer1->Buffer;
//	printf("val[0]=%#x, val[511]=%#x, val[1023]=%#x\n", 
//			pBuf[0], pBuf[511], pBuf[1023]);

	printf("Repeatedly Sending a single Sine Wave On Channel %d and Cosine on %d\n\n", Chan, Chan2);

	//	twice as many bytes as points!
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_REPEATED_WRITE, pBuffer1, NULL, npoints*2, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	Status = BCTAddPacerBlockIo(&nHandle2, &nBoardId, BLOCK_REPEATED_WRITE, pBuffer2, NULL, npoints*2, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo2 failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo2 returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals, so with 1000 points
	//	should take 10 seconds to display?
	Status = BCTStartPacer(&nBoardId, 1);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Wait for the Pacer function to finish, as it never does
	printf("Hit any key to finish\n"); _getch();


	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose2 failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void WriteRBPortAout(BCT_WORD Chan)
{
	char		DoVolts;
	int			i, npoints;
	double		pi = 3.1415926535;
	double		step, val;
//	double		vals[1024];
	BCT_WORD	*pBuf;

	Status = BCTGetBoardId(&nBoardId, PCI_ADC, 0);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Enter Y[es] to specify Constant Voltage, N[o] for Constant Current\n");
	DoVolts	= _getch();
	if((DoVolts == 'Y') || (DoVolts == 'y')) {
		printf("Constant Voltage\n");
		Status = BCTInitAOutModes(&nBoardId, 0, BCT_AOUT_VOLTAGE, 
					BCT_AOUT_VOLTAGE, BCT_AOUT_VOLTAGE, BCT_AOUT_VOLTAGE);
	}
	else {
		printf("Constant Current\n");
		Status = BCTInitAOutModes(&nBoardId, 0, BCT_AOUT_CURRENT, 
					BCT_AOUT_CURRENT, BCT_AOUT_CURRENT, BCT_AOUT_CURRENT);
	}
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitAOutModes failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_AOUT, 0, Chan);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen failed with Status=%s\n", errtxt);
		return;
	}

	npoints		= 1000;
	step		= 2.0*pi/(npoints);	//	so we can join them together
	val			= 0.0;

	//	The buffer is 2KB long so there is space for 1024 16 bit vals
	pBuf		= (BCT_WORD *)pBuffer1->Buffer;

	for(i=0; i<npoints; i++) {
		*pBuf++		= (BCT_WORD)(((1+sin(val))/2.0)*0xfff);
//		vals[i] = val;
		val += step;
	}

//	printf("val[0]=%f, sin=%f, val[511]=%f, sin=%f, val[1023]=%f, sin=%f\n", 
//			vals[0], sin(vals[0]), vals[511], sin(vals[511]), vals[1023], sin(vals[1023]));
//	pBuf		= (BCT_WORD *)pBuffer1->Buffer;
//	printf("val[0]=%#x, val[511]=%#x, val[1023]=%#x\n", 
//			pBuf[0], pBuf[511], pBuf[1023]);

	printf("Repeatedly Sending a single Sine Wave On Channel %d\n\n", Chan);

	//	twice as many bytes as points!
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_REPEATED_WRITE, pBuffer1, NULL, npoints*2, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 10 mSecond Intervals, so with 1000 points
	//	should take 10 seconds to display?
	Status = BCTStartPacer(&nBoardId, 1);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Wait for the Pacer function to finish, as it never does
	printf("Hit any key to finish\n"); _getch();


	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void RBlockWriteTests()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("ADC WritePortTests 1 - Repeat Block Channel 0\n");
		printf("ADC WritePortTests 2 - Repeat Block Channel 1\n");
		printf("ADC WritePortTests 3 - Repeat Block Channel 2\n");
		printf("ADC WritePortTests 4 - Repeat Block Channel 3\n");
		printf("ADC WritePortTests 5 - Repeat Block Channel 0,1\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:	WriteRBPortAout(0);		break;
			case 2:	WriteRBPortAout(1);		break;
			case 3:	WriteRBPortAout(2);		break;
			case 4:	WriteRBPortAout(3);		break;
			case 5:	WriteRBPortAout2(0,1);	break;
			case 99: Done = TRUE;			break;
		}
	}
}

void SBlockWriteTests()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("ADC WritePortTests 1 - Single Block Channel 0\n");
		printf("ADC WritePortTests 2 - Single Block Channel 1\n");
		printf("ADC WritePortTests 3 - Single Block Channel 2\n");
		printf("ADC WritePortTests 4 - Single Block Channel 3\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:	WriteSBPortAout(0);		break;
			case 2:	WriteSBPortAout(1);		break;
			case 3:	WriteSBPortAout(2);		break;
			case 4:	WriteSBPortAout(3);		break;
			case 99: Done = TRUE;			break;
		}
	}
}

void WritePortTests()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("ADC WritePortTests 1 - Channel 0\n");
		printf("ADC WritePortTests 2 - Channel 1\n");
		printf("ADC WritePortTests 3 - Channel 2\n");
		printf("ADC WritePortTests 4 - Channel 3\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:	WritePortAout(0);		break;
			case 2:	WritePortAout(1);		break;
			case 3:	WritePortAout(2);		break;
			case 4:	WritePortAout(3);		break;
			case 99: Done = TRUE;			break;
		}
	}
}

void AdcTests()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("ADC Tests 1	- WritePortTests\n");
		printf("ADC Tests 2	- Single Block Write Tests\n");
		printf("ADC Tests 3	- Repeated Block Write Tests\n");
		printf("ADC Tests 4	- ReadPortTests\n");
		printf("ADC Tests 5	- ReadPortBlockTests\n");
		printf("ADC Tests 6	- AutoCal\n");
		printf("         99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:	WritePortTests();		break;
			case 2:	SBlockWriteTests();		break;
			case 3:	RBlockWriteTests();		break;
			case 4:	ReadPortTests();		break;
			case 5:	ReadPortBlockTests();	break;
			case 6:	AutocalAin();			break;
			case 99: Done = TRUE;			break;
		}
	}
}

void PioLoopBacks()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("Pio Loopback 1	- PIO 8255_0A - 8255_0B\n");
		printf("Pio Loopback 2	- PIO 8255_0A - 8255_0B, reverse\n");
		printf("Pio Loopback 3	- PIO 8255_0C - 8255_1A\n");
		printf("Pio Loopback 4	- PIO 8255_0C - 8255_1A, reverse\n");
		printf("Pio Loopback 5	- PIO 8255_1C - 8255_1B\n");
		printf("Pio Loopback 6	- PIO 8255_1C - 8255_1B, reverse\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:	TestPio0A_0B(TRUE);		break;
			case 2:	TestPio0A_0B(FALSE);	break;
			case 3:	TestPio0C_1A(TRUE);		break;
			case 4:	TestPio0C_1A(FALSE);	break;
			case 5:	TestPio1C_1B(TRUE);		break;
			case 6:	TestPio1C_1B(FALSE);	break;
			case 99: Done = TRUE;			break;
		}
	}
}

void TestPacerDioInputs()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("TestPacerDioIn 1  - Loop input on Pio0A\n");
		printf("TestPacerDioIn 2  - Loop input on Pio1A\n");
		printf("TestPacerDioIn 3  - Loop input on Pio0B\n");
		printf("TestPacerDioIn 4  - Loop input on Pio0C\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: LoopPio0A();				break;
			case 2: LoopPio1A(OUTOUT);			break;
			case 3: LoopPio0B();				break;
			case 4: LoopPio0C();				break;
			case 99: Done = TRUE;				break;
		}
	}
}

void TestPacerPioInputs()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("TestPacerPioIn 1  - Loop input on Pio0A\n");
		printf("TestPacerPioIn 2  - Loop input on Pio1A\n");
		printf("TestPacerPioIn 3  - Loop input on Pio0B\n");
		printf("TestPacerPioIn 4  - Loop input on Pio0C\n");
		printf("              99  - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: LoopPio0A();				break;
			case 2: LoopPio1A(OUTOUT);			break;
			case 3: LoopPio0B();				break;
			case 4: LoopPio0C();				break;
			case 99: Done = TRUE;				break;
		}
	}
}

void TestPacerAdcInputs()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("TestPacerAdcIn 1  - Loop input on ADC0A\n");
		printf("TestPacerAdcIn 2  - Loop input on ADC0B\n");
		printf("TestPacerPioIn 3  - Loop input on ADC0C\n");
		printf("              99  - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: LoopAdc8255(BCT_PORT_A);	break;
			case 2: LoopAdc8255(BCT_PORT_B);	break;
			case 3: LoopAdc8255(BCT_PORT_C);	break;
			case 99: Done = TRUE;				break;
		}
	}
}

void TestPacerDioReads()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("PacerDioRd 1  - Single Block Read on A (Writing on PIO 1)\n");
		printf("PacerDioRd 2  - Single Block Read on B (Writing on PIO 1)\n");
		printf("PacerDioRd 3  - Single Block Read on A (Writing on PIO 0)\n");
		printf("PacerDioRd 4  - Single Block Read on B (Writing on PIO 0)\n");
		printf("PacerDioRd 5  - DblBuf Read Dio 0A\n");
		printf("PacerDioRd 6  - DblBuf Read Dio 0B\n");
		printf("PacerDioRd 7  - Single Write on PIO11-A\n");
		printf("PacerDioRd 8  - Single Write on PIO11-B\n");
		printf("PacerDioRd 9  - Single Write on PIO01-A\n");
		printf("PacerDioRd 10 - Single Write on PIO01-B\n");
		printf("           99 - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: TestPacerDIOSingleRead(1,BCT_PORT_A);	break;
			case 2: TestPacerDIOSingleRead(1,BCT_PORT_B);	break;
			case 3: TestPacerDIOSingleRead(0,BCT_PORT_A);	break;
			case 4: TestPacerDIOSingleRead(0,BCT_PORT_B);	break;
			case 5: TestPacerDIODblBufRead(BCT_PORT_A);		break;
			case 6: TestPacerDIODblBufRead(BCT_PORT_B);		break;
			case 7:	OutPio11(1,BCT_PORT_A);					break;
			case 8:	OutPio11(1,BCT_PORT_B);					break;
			case 9:	OutPio11(0,BCT_PORT_A);					break;
			case 10:OutPio11(0,BCT_PORT_B);					break;
			case 99:Done = TRUE;							break;
		}
	}
}

void TestPacerDioWrites()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("PacerDioWr 1  - Single Block Write on A\n");
		printf("PacerDioWr 2  - Single Block Write on B\n");
		printf("PacerDioWr 3  - Repeat Write Dio 0A\n");
		printf("PacerDioWr 4  - Repeat Write Dio 0B\n");
		printf("PacerDioWr 5  - DblBuf Write Dio 0A\n");
		printf("PacerDioWr 6  - DblBuf Write Dio 0B\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: TestPacerDIOSingleWrite(BCT_PORT_A);	break;
			case 2: TestPacerDIOSingleWrite(BCT_PORT_B);	break;
			case 3: TestPacerDIORepeatedWrite(BCT_PORT_A);	break;
			case 4: TestPacerDIORepeatedWrite(BCT_PORT_B);	break;
			case 5: TestPacerDIODblBufWrite(BCT_PORT_A);	break;
			case 6: TestPacerDIODblBufWrite(BCT_PORT_B);	break;
			case 99: Done = TRUE;				break;
		}
	}
}

void TestPacerPioRepeatBlkWrite()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("PacerPioRepBlkWr 1  - Repeated Write Pio 0A\n");
		printf("PacerPioRepBlkWr 2  - Repeated Write Pio 1A\n");
		printf("PacerPioRepBlkWr 3  - Repeated Write Pio 0B\n");
		printf("PacerPioRepBlkWr 4  - Repeated Write Pio 0C\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: TestPacerRepBlockPio0A();	break;
			case 2: TestPacerRepBlockPio1A();	break;
			case 3: TestPacerRepBlockPio0B();	break;
			case 4: TestPacerRepBlockPio0C();	break;
			case 99: Done = TRUE;				break;
		}
	}
}

void TestPacerAdcRepeatBlkWrite()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("PacerAdcRepBlkWr 1  - Repeated Write Pio 0A\n");
		printf("PacerAdcRepBlkWr 2  - Repeated Write Pio 0B\n");
		printf("PacerAdcRepBlkWr 3  - Repeated Write Pio 0C\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: TestPacerRepBlockAdc8255(BCT_PORT_A);	break;
			case 2: TestPacerRepBlockAdc8255(BCT_PORT_B);	break;
			case 3: TestPacerRepBlockAdc8255(BCT_PORT_C);	break;
			case 99: Done = TRUE;				break;
		}
	}
}

void TestPacerDblReadPio0A()
{
	printf("Double Buffered Pacing in on PIO A, hit any key to stop!\n");
	Status = BCTGetBoardId(&nBoardId, PCI_PIO, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInit8255Modes(&nBoardId, 0, MODE_0, INPUT, NOCARE , NOCARE);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInit8255Modes failed with Status=%s\n", errtxt);		
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, BCT_PORT_A);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	pBuffer1->Sema	= 0;		// Clear the sema
	pBuffer2->Sema	= 0;		// Clear the sema

	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_DOUBLE_BUFFER_READ, pBuffer1, pBuffer2, 32, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 100 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 100);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) {
		while(pBuffer1->Sema == 0) {
			printf("Waiting for Buffer 1 to be read, Buffer1[0]=%#x, Buffer2[0]=%#x\n",
					pBuffer1->Buffer[0], pBuffer2->Buffer[0]);
		}
		pBuffer1->Sema	= 0;	// Signal Done

		while(pBuffer2->Sema == 0) {
			printf("Waiting for Buffer 2 to be read, Buffer1[0]=%#x, Buffer2[0]=%#x\n",
					pBuffer1->Buffer[0], pBuffer2->Buffer[0]);
		}
		pBuffer2->Sema	= 0;	// Signal Done
	}
	
	_getch();

	//	This should dump the unwanted repeated activity
	printf("Hit any key to Close handle (should dump pacer)\n"); _getch();
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to stop the pacer\n"); _getch();
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to release the board\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerDblReadAdc8255(BCT_WORD Port)
{
	printf("Double Buffered Pacing in on ADC 8255 Port %d, hit any key to stop!\n", Port);
	Status = BCTGetBoardId(&nBoardId, PCI_ADC, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTInitPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitPacer failed with Status=%s\n", errtxt);
		return;
	}

	Status = BCTOpen(&nHandle, &nBoardId, BCT_8255, 0, Port);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTOpen() failed with Status=%s\n", errtxt);
		return;
	}

	pBuffer1->Sema	= 0;		// Clear the sema
	pBuffer2->Sema	= 0;		// Clear the sema

	{
		int i;
		for(i=0; i<512; i++) {
			pBuffer1->Buffer[i] = 0;
			pBuffer2->Buffer[i] = 0;
		}
	}
	Status = BCTAddPacerBlockIo(&nHandle, &nBoardId, BLOCK_DOUBLE_BUFFER_READ, pBuffer1, pBuffer2, 32, 0);
	if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAddPacerBlockIo failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}
	if(Status == BCT_OK) {
		printf("BCTAddPacerBlockIo returned Ok, that's not what we expected!\n");
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	//	Start Pacer clock at 100 mSecond Intervals
	Status = BCTStartPacer(&nBoardId, 100);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStartPacer failed with Status=%s\n", errtxt);
		Status = BCTStopPacer(&nBoardId);
		return;
	}

	while(!_kbhit()) {
		while(pBuffer1->Sema == 0) {
			printf("Waiting for Buffer 1 to be read, Buffer1[0]=%#x, Buffer2[0]=%#x\n",
					pBuffer1->Buffer[0], pBuffer2->Buffer[0]);
		}
		pBuffer1->Sema	= 0;	// Signal Done

		while(pBuffer2->Sema == 0) {
			printf("Waiting for Buffer 2 to be read, Buffer1[0]=%#x, Buffer2[0]=%#x\n",
					pBuffer1->Buffer[0], pBuffer2->Buffer[0]);
		}
		pBuffer2->Sema	= 0;	// Signal Done
	}
	
	_getch();

	//	This should dump the unwanted repeated activity
	printf("Hit any key to Close handle (should dump pacer)\n"); _getch();
	Status = BCTClose(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTClose failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to stop the pacer\n"); _getch();
	Status = BCTStopPacer(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTStopPacer failed with Status=%s\n", errtxt);
		return;
	}

	printf("Hit any key to release the board\n"); _getch();
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void TestPacerPioDblBufBlkWrite()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("PacerPioDblBufBlkWr 1  - Put On Pio 0A\n");
		printf("PacerPioDblBufBlkWr 2  - Put On Pio 0B\n");
		printf("                   99  - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: TestPacerDblWritePio0A();	break;
			case 2: TestPacerDblWritePio0B();	break;
			case 99: Done = TRUE;				break;
		}
	}
}

void TestPacerAdcDblBufBlkWrite()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("PacerAdcDblBufBlkWr 1  - Put On Pio 0A\n");
		printf("PacerAdcDblBufBlkWr 2  - Put On Pio 0B\n");
		printf("PacerAdcDblBufBlkWr 3  - Put On Pio 0C\n");
		printf("                   99  - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: TestPacerDblWriteAdc8255(BCT_PORT_A);	break;
			case 2: TestPacerDblWriteAdc8255(BCT_PORT_B);	break;
			case 3: TestPacerDblWriteAdc8255(BCT_PORT_C);	break;
			case 99: Done = TRUE;				break;
		}
	}
}

void TestPacerPioDblBufBlkRead()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("PacerPioDblBufBlkRd 1  - Get From Pio 0A\n");
		printf("PacerPioDblBufBlkRd 2  - Get From Pio 0B\n");
		printf("PacerPioDblBufBlkRd 3  - Write a value on 0A\n");
		printf("PacerPioDblBufBlkRd 4  - Write a value on 0B\n");
		printf("                   99  - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: TestPacerDblReadPio0A();	break;
			case 2: TestPacerDblReadPio0B();	break;
			case 3:	OutPio00(BCT_PORT_A);		break;
			case 4:	OutPio00(BCT_PORT_B);		break;
			case 99: Done = TRUE;				break;
		}
	}
}

void TestPacerAdcDblBufBlkRead()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("PacerAdcDblBufBlkRd 1  - Get From 8255 0A\n");
		printf("PacerAdcDblBufBlkRd 2  - Get From 8255 0B\n");
		printf("PacerAdcDblBufBlkRd 3  - Get From 8255 0C\n");
		printf("PacerPioDblBufBlkRd 4  - Write a value on 8255 0A\n");
		printf("PacerPioDblBufBlkRd 5  - Write a value on 8255 0B\n");
		printf("PacerPioDblBufBlkRd 6  - Write a value on 8255 0C\n");
		printf("                   99  - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: TestPacerDblReadAdc8255(BCT_PORT_A);	break;
			case 2: TestPacerDblReadAdc8255(BCT_PORT_B);	break;
			case 3: TestPacerDblReadAdc8255(BCT_PORT_C);	break;
			case 4:	OutAdc8255(BCT_PORT_A);		break;
			case 5:	OutAdc8255(BCT_PORT_B);		break;
			case 6:	OutAdc8255(BCT_PORT_C);		break;
			case 99: Done = TRUE;				break;
		}
	}
}

void TestPacerPio()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("TestPacerPio 1  - Inputs\n");
		printf("TestPacerPio 2  - Single Block Write/Read PIO Pio A-B\n");
		printf("TestPacerPio 3  - Repeat Block Write\n");
		printf("TestPacerPio 4  - Double Buffered Write\n");
		printf("TestPacerPio 5  - Double Buffered Read\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) 
		{
			case 1:	TestPacerPioInputs();			break;
			case 2:	TestPacer1(TRUE);				break;
			case 3:	TestPacerPioRepeatBlkWrite();	break;
			case 4: TestPacerPioDblBufBlkWrite();	break;
			case 5: TestPacerPioDblBufBlkRead();	break;
			case 99: Done = TRUE;					break;
		}
	}
}

void TestPacerAdc()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("TestPacerAdc 1  - Inputs\n");
		printf("TestPacerAdc 2  - Single Block Write/Read ADC 8255 A-B\n");
		printf("TestPacerAdc 3  - Repeat Block Write\n");
		printf("TestPacerAdc 4  - Double Buffered Write\n");
		printf("TestPacerAdc 5  - Double Buffered Read\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:	TestPacerAdcInputs();			break;
			case 2:	TestPacer2(TRUE);				break;
			case 3:	TestPacerAdcRepeatBlkWrite();	break;
			case 4: TestPacerAdcDblBufBlkWrite();	break;
			case 5: TestPacerAdcDblBufBlkRead();	break;
			case 99: Done = TRUE;					break;
		}
	}
}

void TestPacerDio()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("TestPacerDio 1  - Inputs\n");
		printf("TestPacerDio 2  - Writes\n");
		printf("TestPacerDio 3  - Reads\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:	DIO_PIO_RLYInputs();			break;
			case 2:	TestPacerDioWrites();			break;
			case 3:	TestPacerDioReads();			break;
			case 99: Done = TRUE;					break;
		}
	}
}

void TestPacerDio2()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("TestPacerDio2 1  - Single Block Write(0)/Read(1)\n");
		printf("TestPacerDio2 2  - DblBuf Read\n");
		printf("TestPacerDio2 3  - Repeat Write\n");
		printf("TestPacerDio2 4  - DblBuf Write\n");
		printf("TestPacerDio2 5  - Loop Input on DIO C (no Twist)\n");
		printf("TestPacerDio2 6  - Output on DIO C (no Twist)\n");
		printf("             99  - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply)
		{
			case 1: TestPacerDIO2SingleRead();		break;
			case 2: TestPacerDIO2DblBufRead();		break;
			case 3: TestPacerDIO2RepeatedWrite();	break;
			case 4: TestPacerDIO2DblBufWrite();		break;
			case 5:	LoopDio0CX(BoardNo, FALSE);		break;
			case 6: DioOutC();						break;
			case 99: Done = TRUE;					break;
		}
	}
}

void TestPacerClocks()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("Test Clocks 1	- Test Clock Interrupt Counting on PIO\n");
		printf("Test Clocks 2	- Test Clock Interrupt Counting on DIO\n");
		printf("Test Clocks 3	- Test Clock Interrupt Counting on ADC\n");
		printf("Test Clocks 4	- Test Clock Interrupt Counting on RLY\n");
		printf("            99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:	TestClock(PCI_PIO);		break;
			case 2:	TestClock(PCI_DIO);		break;
			case 3:	TestClock(PCI_ADC);		break;
			case 4:	TestClock(PCI_RLY);		break;
			case 99: Done = TRUE;			break;
		}
	}
}

void TestPacers()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("TestPacers 1    - Test Pacers on PIO\n");
		printf("TestPacers 2    - Test Pacers on DIO\n");
		printf("TestPacers 3    - Test Pacers on ADC\n");
		printf("TestPacers 4    - Test Pacers on Dual DIOs\n");
		printf("TestPacers 5    - Test Single block write/read Pacer on Relay\n");
		printf("TestPacers 6    - Test Double buffered write/read Pacer on Relay\n");
		printf("           99   - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:	TestPacerPio();			break;
			case 2:	TestPacerDio();			break;
			case 3:	TestPacerAdc();			break;
			case 4:	TestPacerDio2();		break;
			case 5: TestPacerRLYSingleRead(); break;
			case 6:	TestPacerRLYdblbuffRead();  break;
			case 99: Done = TRUE;			break;
		}
	}
}

void TestSerialNos()
{
	BCT_DWORD		Status;
	BCT_BOARDTYPE	BoardType;
	BCT_WORD		Board, i;
	BCT_DWORD		nSerial;

	BOOL	Done = FALSE;
	int		reply;

	while(!Done)
	{
		printf("TestSerialNos 1	- Look Up Serial Number\n");
		printf("TestSerialNos 2	- Look Up Board Number\n");
		printf("TestSerialNos 3	- Enumerate All Boards\n");
		printf("             99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply)
		{
			case 1:
				while(1)
				{
					printf("Enter Serial number to find, 99 to exit\n");
					scanf_s("%x", &nSerial);
					if(nSerial == 0x99) break;

					Status = BCTFindSerialNo(nSerial, &BoardType, &Board);
					if(Status != BCT_OK)
					{
						BCTErr2Txt(Status, errtxt);
						printf("BCTFindSerialNo failed with Status=%s\n", errtxt);
					}
					else
					{
						printf("Found a ");
						switch(BoardType)
						{
							case PCI_PIO:	printf("PCI_PIO, "); break;
							case PCI_DIO:	printf("PCI_DIO, "); break;
							case PCI_ADC:	printf("PCI_ADC, "); break;
							case PCI_WDT:	printf("PCI_WDT, "); break;
							case PCI_RLY:	printf("PCI_RLY, "); break;
							default:		printf("Unknown(%d), ", BoardType); break;
						}
						printf("Board No %d\n", Board);
					}
				}
			break;
			
			case 2:
				while(1)
				{
					printf("Enter Board number to find, 99 to exit\n");
					scanf_s("%x", &nSerial);
					if(nSerial == 0x99) break;

					Status = BCTFindBoardNo(nSerial, &BoardType, &Board);
					if(Status != BCT_OK)
					{
						BCTErr2Txt(Status, errtxt);
						printf("BCTFindSerialNo failed with Status=%s\n", errtxt);
					}
					else
					{
						printf("Found a ");
						switch(BoardType)
						{
							case PCI_PIO:	printf("PCI_PIO, "); break;
							case PCI_DIO:	printf("PCI_DIO, "); break;
							case PCI_ADC:	printf("PCI_ADC, "); break;
							case PCI_WDT:	printf("PCI_WDT, "); break;
							case PCI_RLY:	printf("PCI_RLY, "); break;
							default:		printf("Unknown(%d), ", BoardType); break;
						}
						printf("Board No %d\n", Board);
					}
				}
			break;
			
			case 3:
				for(i=0; i<1000; i++)
				{
					Status	= BCTEnumerateBoards(i, &BoardType, &Board, &nSerial);
					if(Status != BCT_OK)
					{
						BCTErr2Txt(Status, errtxt);
						printf("BCTEnumerateBoards says %s\n", errtxt);
						break;
					}
					printf("Board %d, Type", i);
					switch(BoardType)
					{
						case PCI_PIO:	printf("PCI_PIO, "); break;
						case PCI_DIO:	printf("PCI_DIO, "); break;
						case PCI_ADC:	printf("PCI_ADC, "); break;
						case PCI_WDT:	printf("PCI_WDT, "); break;
						case PCI_RLY:	printf("PCI_RLY, "); break;
						default:		printf("Unknown(%d), ", BoardType); break;
					}
					printf("Index:%d, Serial:%#x\n", Board, nSerial);
				}
			break;

			case 99: Done = TRUE;			break;
		}
	}
}

void LoopCounters(BCT_WORD BoardType)
{
	char		DoWhat;
	BCT_BYTE	Counter, Source;
	BCT_WORD	Val;
	
	Status = BCTGetBoardId(&nBoardId, BoardType, BoardNo);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTGetBoardId failed with Status=%s\n", errtxt);
		return;
	}

	if(BoardType == PCI_PIO) {
		Status = BCTInit8255Modes(&nBoardId, 1, MODE_0, INPUT, INPUT, ININ);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTInitISOModes failed with Status=%s\n", errtxt);
			return;
		}
	}

	while(1) {
		printf("Enter Counter to use \n");
		scanf_s("%d", &Counter);
		if(Counter == 99) break;
		Status = BCTOpen(&nHandle, &nBoardId, BCT_8254, 0, Counter);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTOpen failed with Status=%s\n", errtxt);
			return;
		}

		printf("Enter 1 to specify Input 1, anything else for Input 2\n");
		DoWhat	= _getch();
		if(DoWhat == '1') {
			printf("Input 1\n");
			Source	= BCT_EXTERN_COUNTER_INPUT1;
		}
		else {
			printf("Input 2\n");
			Source	= BCT_EXTERN_COUNTER_INPUT2;
		}

		Status = BCTProgramCounter(&nHandle, Source);
		if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTProgramCounter failed with Status=%s\n", errtxt);
			return;
		}

		printf("Spinning on Counter %d on Board %d, hit any key to stop\n", Counter, BoardType);
		while(!_kbhit()) {
			Status = BCTReadPort16(&nHandle, &Val);
			if(Status == BCT_IO_PENDING) Status = BCTWait(&nHandle, INFINITE);
			if((Status != BCT_OK) && (Status != BCT_IO_PENDING)) {
				BCTErr2Txt(Status, errtxt);
				printf("BCTReadPort failed with Status=%s\n", errtxt);
				break;
			}
			printf("Counter=%#6x\r", Val);
		}
		printf("\n");
		Status = BCTClose(&nHandle);
		if(Status != BCT_OK) {
			BCTErr2Txt(Status, errtxt);
			printf("BCTClose failed with Status=%s\n", errtxt);
			return;
		}
	}
	Status = BCTReleaseBoardId(&nBoardId);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTReleaseBoardId failed with Status=%s\n", errtxt);
		return;
	}
}

void LoopCounter()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("LoopCounter 1 - PIO\n");
		printf("LoopCounter 2 - DIO\n");
		printf("LoopCounter 3 - ADC\n");
		printf("           99 - Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: LoopCounters(PCI_PIO);		break;
			case 2: LoopCounters(PCI_DIO);		break;
			case 3: LoopCounters(PCI_ADC);		break;
			case 99: Done = TRUE;				break;
		}
	}
}

void MiscTests()
{
	BOOL	Done = FALSE;
	int		reply;

	while(!Done) {
		printf("Misc Tests 1	- Loop Pio1A, Set PIO 0C OUTOUT\n");
		printf("Misc Tests 2	- Loop Pio1A, Set PIO 0C OUTIN\n");
		printf("Misc Tests 3	- Loop Pio1A, Set PIO 0C INOUT\n");
		printf("Misc Tests 4	- Loop Pio1A, Set PIO 0C ININ\n");
		printf("Misc Tests 5	- Loop Reading Counters\n");
		printf("Misc Tests 6	- A Test\n");
		printf("          99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1: LoopPio1A(OUTOUT);		break;
			case 2: LoopPio1A(OUTIN);		break;
			case 3: LoopPio1A(INOUT);		break;
			case 4: LoopPio1A(ININ);		break;
			case 5:	LoopCounter();			break;
			case 6:	ATest();				break;
			case 99: Done = TRUE;			break;
		}
	}
}


void main(int argc, char *argv[])
{
	BOOL	Done = FALSE;
	int		reply;

	if(argc>1) BoardNo=atoi(argv[1]);
	printf("Using Board %d\n", BoardNo);

	BCTInitHandle(&nHandle);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitHandle failed with Status=%s\n", errtxt);
		return;
	}
	BCTInitHandle(&nHandle2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTInitHandle2 failed with Status=%s\n", errtxt);
		return;
	}
	Status	= BCTAllocate(&pBuffer1, 2048);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAllocate1 failed with Status=%s\n", errtxt);
		return;
	}
	Status	= BCTAllocate(&pBuffer2, 2048);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTAllocate2 failed with Status=%s\n", errtxt);
		return;
	}

	while(!Done) {
		printf("Please select Test:  1	- PIO Loopback Tests\n");
		printf("                     2	- Test Bit Setting Operations\n");
		printf("                     3	- DIO-PIO-RLY Tests - Inputs\n");
		printf("                     4	- DIO-PIO-RLY Tests - Outputs\n");
		printf("                     5	- Test Clock Interrupt Counting\n");
		printf("                     6	- Test Pacers\n");
		printf("                     7	- ADC Loopbacks\n");
		printf("                     8	- ADC Tests\n");
		printf("                     9	- Serial Number Tests\n");
		printf("                     10	- TestWdt\n");
		printf("                     11	- Misc Tests\n");
		printf("                     99	- Exit\n");
		reply = 0;
		scanf_s("%d", &reply);
		switch(reply) {
			case 1:		PioLoopBacks();			break;
			case 2:		TestBits();				break;
			case 3:		DIO_PIO_RLYInputs();	break;
			case 4:		DIO_PIO_RLYOutputs();	break;
			case 5:		TestPacerClocks();		break;
			case 6:		TestPacers();			break;
			case 7:		AdcLoopBacks();			break;
			case 8:		AdcTests();				break;
			case 9:		TestSerialNos();		break;
			case 10:	TestWdt();				break;
			case 11:	MiscTests();			break;
			case 99:	Done = TRUE;			break;
		}
	}

	Status	= BCTRelease(&pBuffer1);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTRelease1 failed with Status=%s\n", errtxt);
		return;
	}
	Status	= BCTRelease(&pBuffer2);
	if(Status != BCT_OK) {
		BCTErr2Txt(Status, errtxt);
		printf("BCTRelease2 failed with Status=%s\n", errtxt);
		return;
	}
	exit(0);
}
